@@ -15,7 +15,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
     As a special exception, permission is given to link this program
     with any edition of Qt, and distribute the resulting executable,
@@ -28,6 +28,11 @@
 #include <qapplication.h>
 #include <qiconset.h>
 #include <qclipboard.h>
+#include <qmap.h>
+#include <qptrdict.h>
+#include <qstring.h>
+#include <qtoolbutton.h>
+#include <qtooltip.h>
 
 #include <kapplication.h>
 #include <kdebug.h>
@@ -40,24 +45,50 @@
 #include <khtml_part.h>
 #include <kiconloader.h>
 #include <kurl.h>
+#include <kurldrag.h>
+#include <kmimetype.h>
 
+#include "actionmanager.h"
+#include "frame.h"
 #include "akregatorconfig.h"
 
-using namespace Akregator;
+namespace Akregator {
+
+class TabWidget::TabWidgetPrivate
+{
+    public:
+    QPtrDict<Frame> frames;
+    uint CurrentMaxLength;
+    QWidget* currentItem;
+    QToolButton* tabsClose;
+};
 
 TabWidget::TabWidget(QWidget * parent, const char *name)
-        :KTabWidget(parent, name), m_CurrentMaxLength(30)
+        :KTabWidget(parent, name), d(new TabWidgetPrivate)
 {
+    d->CurrentMaxLength = 30;
     setMinimumSize(250,150);
     setTabReorderingEnabled(false);
     connect( this, SIGNAL( currentChanged(QWidget *) ), this,
             SLOT( slotTabChanged(QWidget *) ) );
     connect(this, SIGNAL(closeRequest(QWidget*)), this, SLOT(slotCloseRequest(QWidget*)));
     setHoverCloseButton(Settings::closeButtonOnTabs());
+
+    d->tabsClose = new QToolButton(this);
+    d->tabsClose->setAccel(QKeySequence("Ctrl+W"));
+    connect( d->tabsClose, SIGNAL( clicked() ), this,
+            SLOT( slotRemoveCurrentFrame() ) );
+
+    d->tabsClose->setIconSet( SmallIconSet( "tab_remove" ) );
+    d->tabsClose->adjustSize();
+    QToolTip::add(d->tabsClose, i18n("Close the current tab"));
+    setCornerWidget( d->tabsClose, TopRight );
 }
 
 TabWidget::~TabWidget()
 {
+    delete d;
+    d = 0;
 }
 
 void TabWidget::slotSettingsChanged()
@@ -66,45 +97,81 @@ void TabWidget::slotSettingsChanged()
         setHoverCloseButton(Settings::closeButtonOnTabs());
 }
 
+void TabWidget::slotNextTab()
+{
+    setCurrentPage((currentPageIndex()+1) % count());
+}
+
+void TabWidget::slotPreviousTab()
+{
+    if (currentPageIndex() == 0)
+        setCurrentPage(count()-1);
+    else
+        setCurrentPage(currentPageIndex()-1);
+}
+
 void TabWidget::addFrame(Frame *f)
 {
-    if (!f || !f->widget()) return;
-    m_frames.insert(f->widget(), f);
+    if (!f || !f->widget()) 
+        return;
+    d->frames.insert(f->widget(), f);
     addTab(f->widget(), f->title());
+    connect(f, SIGNAL(titleChanged(Frame*, const QString& )), this, SLOT(slotSetTitle(Frame*, const QString& )));
+    slotSetTitle(f, f->title());
 }
 
 Frame *TabWidget::currentFrame()
 {
-    QWidget *w=currentPage();
-    if (!w) return 0;
-    return m_frames[w];
+    QWidget* w = currentPage();
+    
+    return w ? d->frames[w] : 0;
+}
+
+QPtrList<Frame> TabWidget::frames() const
+{
+    QPtrList<Frame> result;
+    QPtrDictIterator<Frame> it(d->frames);
+    while (it.current())
+    {
+        result.append(it.current());
+        ++it;
+    }
+
+    return result;
 }
 
 void TabWidget::slotTabChanged(QWidget *w)
 {
-    emit currentFrameChanged(m_frames[w]);
+    // FIXME: Don't hardcode the tab position of main frame
+    d->tabsClose->setDisabled(currentPageIndex() == 0);
+    emit currentFrameChanged(d->frames[w]);
+}
+
+void TabWidget::slotRemoveCurrentFrame()
+{
+    removeFrame(currentFrame());
 }
 
 void TabWidget::removeFrame(Frame *f)
 {
     f->setCompleted();
-    m_frames.remove(f->widget());
+    d->frames.remove(f->widget());
     removePage(f->widget());
     delete f;
     setTitle( currentFrame()->title(), currentPage() );
 }
 
 // copied wholesale from KonqFrameTabs
-unsigned int TabWidget::tabBarWidthForMaxChars( uint maxLength )
+uint TabWidget::tabBarWidthForMaxChars( uint maxLength )
 {
     int hframe, overlap;
-    hframe    = tabBar()->style().pixelMetric( QStyle::PM_TabBarTabHSpace, this );
+    hframe = tabBar()->style().pixelMetric( QStyle::PM_TabBarTabHSpace, this );
     overlap = tabBar()->style().pixelMetric( QStyle::PM_TabBarTabOverlap, this );
 
     QFontMetrics fm = tabBar()->fontMetrics();
     int x = 0;
     for( int i=0; i < count(); ++i ) {
-        Frame *f=m_frames[page(i)];
+        Frame *f=d->frames[page(i)];
         QString newTitle=f->title();
         if ( newTitle.length() > maxLength )
             newTitle = newTitle.left( maxLength-3 ) + "...";
@@ -120,14 +187,15 @@ unsigned int TabWidget::tabBarWidthForMaxChars( uint maxLength )
     return x;
 }
 
+void TabWidget::slotSetTitle(Frame* frame, const QString& title)
+{
+    setTitle(title, frame->widget());
+}
+
 void TabWidget::setTitle( const QString &title , QWidget* sender)
 {
     removeTabToolTip( sender );
-
-    Frame *f=m_frames[sender];
-    if (f)
-        f->setTitle(title);
-
+   
     uint lcw=0, rcw=0;
     int tabBarHeight = tabBar()->sizeHint().height();
     if ( cornerWidget( TopLeft ) && cornerWidget( TopLeft )->isVisible() )
@@ -137,7 +205,8 @@ void TabWidget::setTitle( const QString &title , QWidget* sender)
     uint maxTabBarWidth = width() - lcw - rcw;
 
     uint newMaxLength=30;
-    for ( ; newMaxLength > 3; newMaxLength-- ) {
+    for ( ; newMaxLength > 3; newMaxLength-- ) 
+{
         if ( tabBarWidthForMaxChars( newMaxLength ) < maxTabBarWidth )
             break;
     }
@@ -152,11 +221,11 @@ void TabWidget::setTitle( const QString &title , QWidget* sender)
     if ( tabLabel( sender ) != newTitle )
         changeTab( sender, newTitle );
 
-    if( newMaxLength != m_CurrentMaxLength )
+    if( newMaxLength != d->CurrentMaxLength )
     {
         for( int i = 0; i < count(); ++i)
         {
-            Frame *f=m_frames[page(i)];
+            Frame *f=d->frames[page(i)];
             newTitle=f->title();
             removeTabToolTip( page( i ) );
             if ( newTitle.length() > newMaxLength )
@@ -169,66 +238,93 @@ void TabWidget::setTitle( const QString &title , QWidget* sender)
             if ( newTitle != tabLabel( page( i ) ) )
                     changeTab( page( i ), newTitle );
         }
-        m_CurrentMaxLength = newMaxLength;
+        d->CurrentMaxLength = newMaxLength;
     }
 }
 
 void TabWidget::contextMenu(int i, const QPoint &p)
 {
-   currentItem = page(i);
-   KPopupMenu popup;
-   //popup.insertTitle(tabLabel(currentItem));
-   int detachTab = popup.insertItem( SmallIcon("tab_breakoff"), i18n("Detach Tab"), this, SLOT( slotDetachTab() ) );
-   int copyLink = popup.insertItem( i18n("Copy Link Address"), this, SLOT( slotCopyLinkAddress() ) );
-   //popup.insertSeparator();
-   int closeTab = popup.insertItem( SmallIcon("tab_remove"), i18n("Close Tab"), this, SLOT( slotCloseTab() ) );
-   if(indexOf(currentItem) == 0) { // you can't detach or close articles tab..
-      popup.setItemEnabled(detachTab, false);
-      popup.setItemEnabled(closeTab, false);
-      popup.setItemEnabled(copyLink, false);
-   }
-   popup.exec(p);
+    QWidget* w = ActionManager::getInstance()->container("tab_popup");
+    d->currentItem = page(i);
+    //kdDebug() << indexOf(d->currentItem) << endl;
+    if (w && indexOf(d->currentItem) != 0)
+        static_cast<QPopupMenu *>(w)->exec(p);
+    d->currentItem = 0;
 }
 
 void TabWidget::slotDetachTab()
 {
-   if(!currentItem) return;
-   KURL url;
-   if (KHTMLView *view = dynamic_cast<KHTMLView*>(currentItem)) url = view->part()->url();
-   else return;
-   kapp->invokeBrowser(url.url(), "0");
-   if (m_frames.find(currentItem) != NULL)
-       removeFrame(m_frames.find(currentItem));
-   delete currentItem;
-   currentItem = 0;
+    if (!d->currentItem || indexOf(d->currentItem) == -1) 
+        d->currentItem = currentPage();
+
+    if (indexOf(d->currentItem) == 0) 
+        return;
+
+    KURL url;
+    KHTMLView* view = dynamic_cast<KHTMLView*>(d->currentItem);
+    
+    if (!view)
+        return;
+
+    url = view->part()->url();
+
+    kapp->invokeBrowser(url.url(), "0");
+    slotCloseTab();
 }
 
 void TabWidget::slotCopyLinkAddress()
 {
-    if(!currentItem) return;
+    if(!d->currentItem || indexOf(d->currentItem) == -1) 
+        d->currentItem = currentPage();
+    if(indexOf(d->currentItem) == 0) 
+        return;
+
     KURL url;
-    if (KHTMLView *view = dynamic_cast<KHTMLView*>(currentItem)) url = view->part()->url();
-    else return;
-    QClipboard *cb = QApplication::clipboard();
+    KHTMLView* view = dynamic_cast<KHTMLView*>(d->currentItem);
+    
+    if (!view)
+        return;
+
+    url = view->part()->url();
+    
     kapp->clipboard()->setText(url.prettyURL(), QClipboard::Selection);
     kapp->clipboard()->setText(url.prettyURL(), QClipboard::Clipboard);
 }
 
 void TabWidget::slotCloseTab()
 {
-   if(!currentItem) return;
-   if (m_frames.find(currentItem) != NULL)
-       removeFrame(m_frames.find(currentItem));
-   delete currentItem;
-   currentItem = 0;
+    if (!d->currentItem || indexOf(d->currentItem) == -1) 
+        d->currentItem = currentPage();
+    if (indexOf(d->currentItem) == 0) 
+        return;
+    if (d->frames.find(d->currentItem) != NULL)
+        removeFrame(d->frames.find(d->currentItem));
+    delete d->currentItem;
+    d->currentItem = 0;
+}
+
+void TabWidget::initiateDrag(int tab)
+{
+    if (tab == 0) // don't initiate drag for the main tab
+        return;
+        
+    Frame* frame = d->frames[page(tab)];
+  
+    if (frame != 0)
+    {
+        KURL::List lst;
+        lst.append( frame->part()->url() );
+        KURLDrag* drag = new KURLDrag( lst, this );
+        drag->setPixmap( KMimeType::pixmapForURL( lst.first(), 0, KIcon::Small ) );
+        drag->dragCopy();
+    }
 }
 
 void TabWidget::slotCloseRequest(QWidget* widget)
 {
-    if (m_frames.find(widget) != NULL)
-        removeFrame(m_frames.find(widget));
+    if (d->frames.find(widget) != NULL)
+        removeFrame(d->frames.find(widget));
 }
+} // namespace Akregator
+
 #include "tabwidget.moc"
-
-
-// vim: set et ts=4 sts=4 sw=4:
