@@ -16,7 +16,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
     In addition, as a special exception, the copyright holders give
     permission to link the code of this program with any edition of
@@ -58,6 +58,7 @@
 #include <kleo/keyfiltermanager.h>
 #include <kleo/hierarchicalkeylistjob.h>
 #include <kleo/refreshkeysjob.h>
+#include <kleo/cryptoconfig.h>
 
 #include <ui/progressdialog.h>
 #include <ui/progressbar.h>
@@ -95,12 +96,10 @@
 // other
 #include <algorithm>
 #include <assert.h>
-
-static const bool startWithHierarchicalKeyListing = false;
-
+#include <kdepimmacros.h>
 namespace {
 
-  class DisplayStrategy : public Kleo::KeyListView::DisplayStrategy{
+  class KDE_EXPORT DisplayStrategy : public Kleo::KeyListView::DisplayStrategy{
   public:
     ~DisplayStrategy() {}
 
@@ -122,7 +121,7 @@ namespace {
     }
   };
 
-  class ColumnStrategy : public Kleo::KeyListView::ColumnStrategy {
+  class KDE_EXPORT ColumnStrategy : public Kleo::KeyListView::ColumnStrategy {
   public:
     ~ColumnStrategy() {}
 
@@ -171,10 +170,11 @@ CertManager::CertManager( bool remote, const QString& query, const QString & imp
     mFindAction( 0 ),
     mImportCertFromFileAction( 0 ),
     mImportCRLFromFileAction( 0 ),
-    mNextFindRemote( false ),
+    mNextFindRemote( remote ),
     mRemote( remote ),
     mDirMngrFound( false )
 {
+  readConfig( query.isEmpty() );
   createStatusBar();
   createActions();
 
@@ -183,8 +183,6 @@ CertManager::CertManager( bool remote, const QString& query, const QString & imp
 
   // Main Window --------------------------------------------------
   mKeyListView = new CertKeyListView( new ColumnStrategy(), new DisplayStrategy(), this, "mKeyListView" );
-  mKeyListView->setHierarchical( startWithHierarchicalKeyListing );
-  mKeyListView->setRootIsDecorated( startWithHierarchicalKeyListing );
   mKeyListView->setSelectionMode( QListView::Extended );
   setCentralWidget( mKeyListView );
 
@@ -207,15 +205,33 @@ CertManager::CertManager( bool remote, const QString& query, const QString & imp
   if ( !import.isEmpty() )
     slotImportCertFromFile( KURL( import ) );
 
+  slotToggleHierarchicalView( mHierarchicalView );
   updateStatusBarLabels();
   slotSelectionChanged(); // initial state for selection-dependent actions
 }
 
 CertManager::~CertManager() {
+  writeConfig();
   delete mDirmngrProc; mDirmngrProc = 0;
   delete mHierarchyAnalyser; mHierarchyAnalyser = 0;
 }
 
+void CertManager::readConfig( bool noQueryGiven ) {
+  KConfig config( "kleopatrarc" );
+  config.setGroup( "Display Options" );
+  mHierarchicalView = config.readBoolEntry( "hierarchicalView", false );
+  if ( noQueryGiven ) {
+    mNextFindRemote = config.readBoolEntry( "startInRemoteMode", false );
+  }
+}
+
+void CertManager::writeConfig() {
+  KConfig config( "kleopatrarc" );
+  config.setGroup( "Display Options" );
+  config.writeEntry( "hierarchicalView", mKeyListView->hierarchical() );
+  config.writeEntry( "startInRemoteMode", mNextFindRemote );
+}
+
 void CertManager::createStatusBar() {
   KStatusBar * bar = statusBar();
   mProgressBar = new Kleo::ProgressBar( bar, "mProgressBar" );
@@ -261,11 +277,9 @@ void CertManager::createActions() {
   action = new KAction( i18n("Expand All"), 0, CTRL+Key_Period,
 			this, SLOT(slotExpandAll()),
 			actionCollection(), "view_expandall" );
-  action->setEnabled( startWithHierarchicalKeyListing );
   action = new KAction( i18n("Collapse All"), 0, CTRL+Key_Comma,
 			this, SLOT(slotCollapseAll()),
 			actionCollection(), "view_collapseall" );
-  action->setEnabled( startWithHierarchicalKeyListing );
 
   (void)   new KAction( i18n("Refresh CRLs"), 0, 0,
 			this, SLOT(slotRefreshKeys()),
@@ -346,7 +360,7 @@ void CertManager::createActions() {
   QStringList lst;
   lst << i18n("In Local Certificates") << i18n("In External Certificates");
   mComboAction = new ComboAction( lst, actionCollection(), this, SLOT( slotToggleRemote(int) ),
-                                  "location_combo_action");
+                                  "location_combo_action", mNextFindRemote? 1 : 0 );
 
   mFindAction = new KAction( i18n("Find"), "find", 0, this, SLOT(slotSearch()),
 			     actionCollection(), "find" );
@@ -380,7 +394,18 @@ void CertManager::slotConfigureGpgME() {
   Kleo::CryptoConfig* config = Kleo::CryptoBackendFactory::instance()->config();
   if ( config ) {
     Kleo::CryptoConfigDialog dlg( config );
-    dlg.exec();
+
+    int result = dlg.exec();
+
+    // Forget all data parsed from gpgconf, so that we show updated information
+    // when reopening the configuration dialog.
+    config->clear();
+
+    if ( result == QDialog::Accepted )
+    {
+      // Tell other apps (e.g. kmail) that the gpgconf data might have changed
+      kapp->dcopClient()->emitDCOPSignal( "KPIM::CryptoConfig", "changed()", QByteArray() );
+    }
   }
 }
 
@@ -394,12 +419,17 @@ void CertManager::slotToggleRemote( int idx ) {
 }
 
 void CertManager::slotToggleHierarchicalView( bool hier ) {
+  mHierarchicalView = hier;
   mKeyListView->setHierarchical( hier );
   mKeyListView->setRootIsDecorated( hier );
   if ( KAction * act = action("view_expandall") )
     act->setEnabled( hier );
   if ( KAction * act = action("view_collapseall" ) )
     act->setEnabled( hier );
+  if ( KToggleAction * act = 
+      static_cast<KToggleAction*>( action("view_hierarchical") ) )
+    act->setChecked( hier );
+
   if ( hier && !mCurrentQuery.isEmpty() )
     startRedisplay( false );
 }
