@@ -14,7 +14,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
     As a special exception, permission is given to link this program
     with any edition of Qt, and distribute the resulting executable,
@@ -26,6 +26,7 @@
 #include <qlayout.h>
 #include <qpainter.h>
 #include <qpushbutton.h>
+#include <qvalidator.h>
 #include <qstring.h>
 #include <qtoolbutton.h>
 #include <qtooltip.h>
@@ -36,12 +37,24 @@
 #include <kdebug.h>
 #include <kdialog.h>
 #include <kiconloader.h>
+#include <kinputdialog.h>
 #include <klineedit.h>
 #include <klocale.h>
 #include <kmessagebox.h>
 
 #include "emaileditwidget.h"
 
+class EmailValidator : public QRegExpValidator
+{
+  public:
+    EmailValidator()
+      : QRegExpValidator( 0, "EmailValidator" )
+    {
+      QRegExp rx( ".*@.*\\.[A-Za-z]+" );
+      setRegExp( rx );
+    }
+};
+
 class EmailItem : public QListBoxText
 {
   public:
@@ -83,6 +96,7 @@ EmailEditWidget::EmailEditWidget( QWidget *parent, const char *name )
   topLayout->addWidget( label, 0, 0 );
 
   mEmailEdit = new KLineEdit( this );
+  mEmailEdit->setValidator( new EmailValidator );
   connect( mEmailEdit, SIGNAL( textChanged( const QString& ) ),
            SLOT( textChanged( const QString& ) ) );
   connect( mEmailEdit, SIGNAL( textChanged( const QString& ) ),
@@ -161,26 +175,11 @@ EmailEditDialog::EmailEditDialog( const QStringList &list, QWidget *parent,
                                   const char *name )
   : KDialogBase( KDialogBase::Plain, i18n( "Edit Email Addresses" ),
                  KDialogBase::Ok | KDialogBase::Cancel, KDialogBase::Help,
-                 parent, name, true ), mIsEdit( false )
+                 parent, name, true )
 {
   QWidget *page = plainPage();
 
-  QGridLayout *topLayout = new QGridLayout( page, 4, 3, marginHint(),
-                                            spacingHint() );
-
-  QLabel *label = new QLabel( i18n( "Email address:" ), page );
-  topLayout->addWidget( label, 0, 0 );
-
-  mEmailEdit = new KLineEdit( page );
-  label->setBuddy( mEmailEdit );
-  topLayout->addWidget( mEmailEdit, 0, 1 );
-  connect( mEmailEdit, SIGNAL( textChanged( const QString& ) ),
-           SLOT( emailChanged() ) );
-
-  mAddButton = new QPushButton( i18n( "Add" ), page );
-  mAddButton->setEnabled( false );
-  connect( mAddButton, SIGNAL( clicked() ), SLOT( add() ) );
-  topLayout->addWidget( mAddButton, 0, 2 );
+  QGridLayout *topLayout = new QGridLayout( page, 4, 3, 0, spacingHint() );
 
   mEmailListBox = new QListBox( page );
 
@@ -190,9 +189,13 @@ EmailEditDialog::EmailEditDialog( const QStringList &list, QWidget *parent,
            SLOT( selectionChanged( int ) ) );
   connect( mEmailListBox, SIGNAL( selected( int ) ),
            SLOT( edit() ) );
-  topLayout->addMultiCellWidget( mEmailListBox, 1, 3, 0, 1 );
+  topLayout->addMultiCellWidget( mEmailListBox, 0, 3, 0, 1 );
 
-  mEditButton = new QPushButton( i18n( "Change" ), page );
+  mAddButton = new QPushButton( i18n( "Add..." ), page );
+  connect( mAddButton, SIGNAL( clicked() ), SLOT( add() ) );
+  topLayout->addWidget( mAddButton, 0, 2 );
+
+  mEditButton = new QPushButton( i18n( "Edit..." ), page );
   connect( mEditButton, SIGNAL( clicked() ), SLOT( edit() ) );
   topLayout->addWidget( mEditButton, 1, 2 );
 
@@ -212,7 +215,7 @@ EmailEditDialog::EmailEditDialog( const QStringList &list, QWidget *parent,
   else
     mChanged = false;
 
-  QStringList::Iterator it;
+  QStringList::ConstIterator it;
   bool preferred = true;
   for ( it = items.begin(); it != items.end(); ++it ) {
     new EmailItem( mEmailListBox, *it, preferred );
@@ -221,10 +224,9 @@ EmailEditDialog::EmailEditDialog( const QStringList &list, QWidget *parent,
 
   // set default state
   selectionChanged( -1 );
-  mEmailEdit->setFocus();
   KAcceleratorManager::manage( this );
 
-  actionButton( Ok )->setDefault( true );
+  setInitialSize( QSize( 400, 200 ) );
 }
 
 EmailEditDialog::~EmailEditDialog()
@@ -248,37 +250,52 @@ QStringList EmailEditDialog::emails() const
 
 void EmailEditDialog::add()
 {
+  EmailValidator *validator = new EmailValidator;
+  bool ok = false;
+
+  QString email = KInputDialog::getText( i18n( "Add Email" ), i18n( "New Email:" ),
+                                         QString::null, &ok, this, "EmailEditDialog",
+                                         validator );
+
+  if ( !ok )
+    return;
+
   // check if item already available, ignore if so...
   for ( uint i = 0; i < mEmailListBox->count(); ++i ) {
-    if ( mEmailListBox->text( i ) == mEmailEdit->text() ) {
-      mEmailEdit->clear();
-      mEmailEdit->setFocus();
+    if ( mEmailListBox->text( i ) == email )
       return;
-    }
   }
 
-  if ( !mIsEdit ) {
-    new EmailItem( mEmailListBox, mEmailEdit->text(),
-                   (mEmailListBox->count() == 0) );
-  } else {
-    EmailItem *item = static_cast<EmailItem*>( mEmailListBox->item( mEditPos ) );
-    item->setText( mEmailEdit->text() );
-    mIsEdit = false;
-    mEmailListBox->triggerUpdate( true );
-  }
-
-  mEmailEdit->clear();
-  mEmailEdit->setFocus();
+  new EmailItem( mEmailListBox, email, (mEmailListBox->count() == 0) );
 
   mChanged = true;
 }
 
 void EmailEditDialog::edit()
 {
-  mIsEdit = true;
-  mEditPos = mEmailListBox->currentItem();
-  mEmailEdit->setText( mEmailListBox->currentText() );
-  mEmailEdit->setFocus();
+  EmailValidator *validator = new EmailValidator;
+  bool ok = false;
+
+  int editPos = mEmailListBox->currentItem();
+
+  QString email = KInputDialog::getText( i18n( "Edit Email" ), i18n( "Email:" ),
+                                         mEmailListBox->text( editPos ), &ok, this,
+                                         "EmailEditDialog", validator );
+
+  if ( !ok )
+    return;
+
+  // check if item already available, ignore if so...
+  for ( uint i = 0; i < mEmailListBox->count(); ++i ) {
+    if ( mEmailListBox->text( i ) == email )
+      return;
+  }
+
+  EmailItem *item = static_cast<EmailItem*>( mEmailListBox->item( editPos ) );
+  item->setText( email );
+  mEmailListBox->triggerUpdate( true );
+
+  mChanged = true;
 }
 
 void EmailEditDialog::remove()
@@ -293,12 +310,12 @@ void EmailEditDialog::remove()
 
     bool preferred = item->preferred();
     mEmailListBox->removeItem( mEmailListBox->currentItem() );
-    mEmailEdit->clear();
     if ( preferred ) {
       item = dynamic_cast<EmailItem*>( mEmailListBox->item( 0 ) );
       if ( item )
         item->setPreferred( true );
     }
+
     mChanged = true;
   }
 }
@@ -332,19 +349,4 @@ void EmailEditDialog::selectionChanged( int index )
   mStandardButton->setEnabled( value );
 }
 
-void EmailEditDialog::emailChanged()
-{
-  bool state = mEmailEdit->text().contains( '@' );
-
-  mAddButton->setEnabled( state );
-
-  if ( state ) {
-    actionButton( Ok )->setDefault( false );
-  } else {
-    actionButton( Ok )->setDefault( true );
-  }
-
-  mAddButton->setDefault( state );
-}
-
 #include "emaileditwidget.moc"
