@@ -14,7 +14,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
     As a special exception, permission is given to link this program
     with any edition of Qt, and distribute the resulting executable,
@@ -55,7 +55,7 @@ KABC::AddresseeList KDE2XXPort::importContacts( const QString& ) const
 
   int result = KMessageBox::questionYesNoCancel( parentWidget(),
       i18n( "Override previously imported entries?" ),
-      i18n( "Import KDE 2 Addressbook" ) );
+      i18n( "Import KDE 2 Addressbook" ), i18n("Import"), i18n("Do Not Import") );
 
   if ( !result ) return KABC::AddresseeList();
 
