@@ -374,24 +374,23 @@ void Daemon::enableAutoStart(bool enable)
 	// Tell the alarm daemon in case it is running.
 	AlarmDaemonIface_stub s(DAEMON_APP_NAME, DAEMON_DCOP_OBJECT);
 	s.enableAutoStart(enable);
-	if (!s.ok())
-	{
-		// Failure - the daemon probably isn't running, so rewrite its config file for it
-		KConfig adconfig(locate("config", DAEMON_APP_NAME"rc"));
-		adconfig.setGroup(QString::fromLatin1(DAEMON_AUTOSTART_SECTION));
-		adconfig.writeEntry(QString::fromLatin1(DAEMON_AUTOSTART_KEY), enable);
-		adconfig.sync();
-	}
+
+	// The return status doesn't report failure even if the daemon isn't running,
+	// so in case of failure, rewrite the config file in any case.
+	KConfig adconfig(locate("config", DAEMON_APP_NAME"rc"));
+	adconfig.setGroup(QString::fromLatin1(DAEMON_AUTOSTART_SECTION));
+	adconfig.writeEntry(QString::fromLatin1(DAEMON_AUTOSTART_KEY), enable);
+	adconfig.sync();
 }
 
 /******************************************************************************
 * Read the alarm daemon's autostart-at-login setting.
 */
-bool Daemon::autoStart(bool defaultAutoStart)
+bool Daemon::autoStart()
 {
 	KConfig adconfig(locate("config", DAEMON_APP_NAME"rc"));
 	adconfig.setGroup(QString::fromLatin1(DAEMON_AUTOSTART_SECTION));
-	return adconfig.readBoolEntry(QString::fromLatin1(DAEMON_AUTOSTART_KEY), defaultAutoStart);
+	return adconfig.readBoolEntry(QString::fromLatin1(DAEMON_AUTOSTART_KEY), true);
 }
 
 /******************************************************************************
@@ -677,9 +676,10 @@ void NotificationHandler::registered(bool reregister, int result)
 =============================================================================*/
 
 AlarmEnableAction::AlarmEnableAction(int accel, QObject* parent, const char* name)
-	: KToggleAction(QString::null, accel, parent, name),
+	: KToggleAction(i18n("Enable &Alarms"), accel, parent, name),
 	  mInitialised(false)
 {
+	setCheckedState(i18n("Disable &Alarms"));
 	setCheckedActual(false);    // set the correct text
 	mInitialised = true;
 }
@@ -692,7 +692,6 @@ void AlarmEnableAction::setCheckedActual(bool running)
 	kdDebug(5950) << "AlarmEnableAction::setCheckedActual(" << running << ")\n";
 	if (running != isChecked()  ||  !mInitialised)
 	{
-		setText(running ? i18n("&Alarms Enabled") : i18n("Enable &Alarms"));
 		KToggleAction::setChecked(running);
 		emit switched(running);
 	}
