@@ -1,7 +1,7 @@
 /*
  *  find.cpp  -  search facility 
  *  Program:  kalarm
- *  (C) 2005 by David Jarvie <software@astrojar.org.uk>
+ *  Copyright © 2005,2006 by David Jarvie <software@astrojar.org.uk>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -13,14 +13,13 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  You should have received a copy of the GNU General Public License along
+ *  with this program; if not, write to the Free Software Foundation, Inc.,
+ *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #include "kalarm.h"
 
-#ifdef FIND
 #include <qlayout.h>
 #include <qwhatsthis.h>
 #include <qgroupbox.h>
@@ -31,6 +30,7 @@
 #include <kseparator.h>
 #include <kwin.h>
 #include <klocale.h>
+#include <kmessagebox.h>
 #include <kdebug.h>
 
 #include "alarmlistview.h"
@@ -46,7 +46,7 @@ enum {
 	FIND_COMMAND = KFindDialog::MinimumUserOption << 4,
 	FIND_EMAIL   = KFindDialog::MinimumUserOption << 5
 };
-static long FIND_KALARM_OPTIONS = FIND_LIVE | FIND_EXPIRED;
+static long FIND_KALARM_OPTIONS = FIND_LIVE | FIND_EXPIRED | FIND_MESSAGE | FIND_FILE | FIND_COMMAND | FIND_EMAIL;
 
 
 Find::Find(EventListViewBase* parent)
@@ -58,6 +58,13 @@ Find::Find(EventListViewBase* parent)
 {
 }
 
+Find::~Find()
+{
+	delete mDialog;    // automatically set to 0
+	delete mFind;
+	mFind = 0;
+}
+
 /******************************************************************************
 *  Display the Find dialog.
 */
@@ -66,20 +73,22 @@ void Find::display()
 	if (!mOptions)
 		// Set defaults the first time the Find dialog is activated
 		mOptions = FIND_LIVE | FIND_EXPIRED | FIND_MESSAGE | FIND_FILE | FIND_COMMAND | FIND_EMAIL;
-	bool noExpired = !Preferences::instance()->expiredKeepDays();
+	bool noExpired = !Preferences::expiredKeepDays();
 	bool showExpired = mListView->isA("AlarmListView") && ((AlarmListView*)mListView)->showingExpired();
 	if (noExpired  ||  !showExpired)      // these settings could change between activations
 		mOptions &= ~FIND_EXPIRED;
 
 	if (mDialog)
 	{
-#warning Does the desktop need to be set - presumably it is automatically on same as main window?
-//		KWin::setOnDesktop(mDialog->winId(), KWin::currentDesktop());
 		KWin::activateWindow(mDialog->winId());
 	}
 	else
 	{
-		mDialog = new KFindDialog(false, mListView, "findDlg", mOptions, mHistory, (mListView->selectedCount() > 1));
+#ifdef MODAL_FIND
+		mDialog = new KFindDialog(mListView, "FindDlg", mOptions, mHistory, (mListView->selectedCount() > 1));
+#else
+		mDialog = new KFindDialog(false, mListView, "FindDlg", mOptions, mHistory, (mListView->selectedCount() > 1));
+#endif
 		mDialog->setHasSelection(false);
 		QWidget* kalarmWidgets = mDialog->findExtension();
 
@@ -87,7 +96,7 @@ void Find::display()
 		QBoxLayout* layout = new QVBoxLayout(kalarmWidgets, 0, KDialog::spacingHint());
 		QGroupBox* group = new QGroupBox(i18n("Alarm Type"), kalarmWidgets);
 		layout->addWidget(group);
-		QGridLayout* grid = new QGridLayout(group, 2, 2, marginKDE2 + KDialog::marginHint(), KDialog::spacingHint());
+		QGridLayout* grid = new QGridLayout(group, 2, 2, KDialog::marginHint(), KDialog::spacingHint());
 		grid->addRowSpacing(0, mDialog->fontMetrics().lineSpacing()/2);
 		grid->setColStretch(1, 1);
 
@@ -131,14 +140,14 @@ void Find::display()
 		// Set defaults
 		mLive->setChecked(mOptions & FIND_LIVE);
 		mExpired->setChecked(mOptions & FIND_EXPIRED);
-		mExpired->setEnabled(showExpired);
 		mMessageType->setChecked(mOptions & FIND_MESSAGE);
 		mFileType->setChecked(mOptions & FIND_FILE);
 		mCommandType->setChecked(mOptions & FIND_COMMAND);
 		mEmailType->setChecked(mOptions & FIND_EMAIL);
 
-		connect(mDialog, SIGNAL(okClicked()), this, SLOT(slotFind()) );
-		connect(mDialog, SIGNAL(destroyed()), this, SLOT(slotDlgDestroyed()) );
+#ifndef MODAL_FIND
+		connect(mDialog, SIGNAL(okClicked()), this, SLOT(slotFind()));
+#endif
 	}
 
 	// Only display active/expired options if expired alarms are being kept
@@ -155,20 +164,44 @@ void Find::display()
 		mActiveExpiredSep->show();
 	}
 
-	mDialog->setHasCursor(mListView->currentItem());
-	mDialog->show();
-}
+	// Disable options where no displayed alarms match them
+	bool live    = false;
+	bool expired = false;
+	bool text    = false;
+	bool file    = false;
+	bool command = false;
+	bool email   = false;
+	for (EventListViewItemBase* item = mListView->firstChild();  item;  item = item->nextSibling())
+	{
+		const KAEvent& event = item->event();
+		if (event.expired())
+			expired = true;
+		else
+			live = true;
+		switch (event.action())
+		{
+			case KAEvent::MESSAGE:  text    = true;  break;
+			case KAEvent::FILE:     file    = true;  break;
+			case KAEvent::COMMAND:  command = true;  break;
+			case KAEvent::EMAIL:    email   = true;  break;
+		}
+	}
+	mLive->setEnabled(live);
+	mExpired->setEnabled(expired);
+	mMessageType->setEnabled(text);
+	mFileType->setEnabled(file);
+	mCommandType->setEnabled(command);
+	mEmailType->setEnabled(email);
 
-/******************************************************************************
-*  Called when the find dialog is being destroyed.
-*/
-void Find::slotDlgDestroyed()
-{
-kdDebug()<<"slotDlgDestroyed()\n";
-#warning Should mFind be deleted here, or does it happen automatically?
-//	delete mFind;
-//	mFind   = 0;
-	mDialog = 0;
+	mDialog->setHasCursor(mListView->currentItem());
+#ifdef MODAL_FIND
+	if (mDialog->exec() == QDialog::Accepted)
+		slotFind();
+	else
+		delete mDialog;
+#else
+	mDialog->show();
+#endif
 }
 
 /******************************************************************************
@@ -179,31 +212,43 @@ void Find::slotFind()
 	if (!mDialog)
 		return;
 	mHistory = mDialog->findHistory();    // save search history so that it can be displayed again
-	mOptions &= ~FIND_KALARM_OPTIONS;
-	mOptions |= (mLive->isChecked()    ? FIND_LIVE : 0)
-	         |  (mExpired->isChecked() ? FIND_EXPIRED : 0)
-	         |  (mMessageType->isChecked() ? FIND_MESSAGE : 0)
-	         |  (mFileType->isChecked() ? FIND_FILE : 0)
-	         |  (mCommandType->isChecked() ? FIND_COMMAND : 0)
-	         |  (mEmailType->isChecked() ? FIND_EMAIL : 0);
+	mOptions = mDialog->options() & ~FIND_KALARM_OPTIONS;
+	mOptions |= (mLive->isEnabled()        && mLive->isChecked()        ? FIND_LIVE : 0)
+	         |  (mExpired->isEnabled()     && mExpired->isChecked()     ? FIND_EXPIRED : 0)
+	         |  (mMessageType->isEnabled() && mMessageType->isChecked() ? FIND_MESSAGE : 0)
+	         |  (mFileType->isEnabled()    && mFileType->isChecked()    ? FIND_FILE : 0)
+	         |  (mCommandType->isEnabled() && mCommandType->isChecked() ? FIND_COMMAND : 0)
+	         |  (mEmailType->isEnabled()   && mEmailType->isChecked()   ? FIND_EMAIL : 0);
+	if (!(mOptions & (FIND_LIVE | FIND_EXPIRED))
+	||  !(mOptions & (FIND_MESSAGE | FIND_FILE | FIND_COMMAND | FIND_EMAIL)))
+	{
+		KMessageBox::sorry(mDialog, i18n("No alarm types are selected to search"));
+		return;
+	}
 
 	// Supply KFind with only those options which relate to the text within alarms
 	long options = mOptions & (KFindDialog::WholeWordsOnly | KFindDialog::CaseSensitive | KFindDialog::RegularExpression);
 	if (mFind)
 	{
+		mFind->setPattern(mDialog->pattern());
 		mFind->setOptions(options);
+		delete mDialog;    // automatically set to 0
 		findNext(true, true, false);
 	}
 	else
 	{
+#ifdef MODAL_FIND
+		mFind = new KFind(mDialog->pattern(), options, mListView);
+#else
 		mFind = new KFind(mDialog->pattern(), options, mListView, mDialog);
+#endif
 		connect(mFind, SIGNAL(destroyed()), SLOT(slotKFindDestroyed()));
-		mFind->closeFindNextDialog();    // prevent 'Find Next' dialog appearing in addition to the Find dialog
+		delete mDialog;                  // close the Find dialogue. Automatically set to 0.
+		mFind->closeFindNextDialog();    // prevent 'Find Next' dialog appearing
 
 		// Set the starting point for the search
 		mListView->sort();     // ensure the whole list is sorted, not just the visible items
 		mStartID       = QString::null;
-		mFromMiddle    = false;
 		mNoCurrentItem = true;
 		bool fromCurrent = false;
 		EventListViewItemBase* item = 0;
@@ -213,14 +258,13 @@ void Find::slotFind()
 			if (item)
 			{
 				mStartID       = item->event().id();
-				mFromMiddle    = (mOptions & KFindDialog::FindBackwards) ? item->itemBelow() : item->itemAbove();
 				mNoCurrentItem = false;
 				fromCurrent    = true;
 			}
 		}
-if (item) kdDebug()<<"slotFind(): event="<<item->event().id()<<endl;
 
 		// Execute the search
+		mFound = false;
 		findNext(true, false, fromCurrent);
 		if (mFind)
 			emit active(true);
@@ -240,23 +284,24 @@ void Find::findNext(bool forward, bool sort, bool fromCurrent)
 	EventListViewItemBase* item = mNoCurrentItem ? 0 : mListView->currentItem();
 	if (!fromCurrent)
 		item = nextItem(item, forward);
-if (item) kdDebug()<<"findNext(): event="<<item->event().id()<<endl; else kdDebug()<<"findNext(): event=null\n";
 
 	// Search successive alarms until a match is found or the end is reached
 	bool found = false;
 	for ( ;  item;  item = nextItem(item, forward))
 	{
-if (item) kdDebug()<<"findNext() 2: event="<<item->event().id()<<endl; else kdDebug()<<"findNext() 2: event=null\n";
 		const KAEvent& event = item->event();
-		if (!mStartID.isNull()  &&  mStartID == event.id())
+		if (!fromCurrent  &&  !mStartID.isNull()  &&  mStartID == event.id())
 			break;    // we've wrapped round and reached the starting alarm again
-kdDebug()<<"findNext() 3\n";
+		fromCurrent = false;
+		bool live = !event.expired();
+		if (live  &&  !(mOptions & FIND_LIVE)
+		||  !live  &&  !(mOptions & FIND_EXPIRED))
+			continue;     // we're not searching this type of alarm
 		switch (event.action())
 		{
 			case KAEvent::MESSAGE:
 				if (!(mOptions & FIND_MESSAGE))
 					break;
-kdDebug()<<"findNext() 4: message="<<event.cleanText()<<endl;
 				mFind->setData(event.cleanText());
 				found = (mFind->find() == KFind::Match);
 				break;
@@ -299,11 +344,11 @@ kdDebug()<<"findNext() 4: message="<<event.cleanText()<<endl;
 	}
 
 	// Process the search result
-if (item) kdDebug()<<"findNext() end: item="<<item->event().id()<<endl; else kdDebug()<<"findNext(): end: event=null\n";
 	mNoCurrentItem = !item;
 	if (found)
 	{
 		// A matching alarm was found - highlight it and make it current
+		mFound = true;
 		mListView->clearSelection();
 		mListView->setSelected(item, true);
 		mListView->setCurrentItem(item);
@@ -312,20 +357,19 @@ if (item) kdDebug()<<"findNext() end: item="<<item->event().id()<<endl; else kdD
 	else
 	{
 		// No match was found
-		if (mFromMiddle)
+		if (mFound)
 		{
-			// We haven't yet searched all alarms, so ask user whether to wrap round
-			if (mFind->shouldRestart(false, false))
+			QString msg = forward ? i18n("End of alarm list reached.\nContinue from the beginning?")
+			                      : i18n("Beginning of alarm list reached.\nContinue from the end?");
+			if (KMessageBox::questionYesNo(mListView, msg, QString::null, KStdGuiItem::cont(), KStdGuiItem::cancel()) == KMessageBox::Yes)
 			{
-				mFromMiddle = false;
 				findNext(forward, false);
 				return;
 			}
 		}
 		else
 			mFind->displayFinalDialog();     // display "no match was found"
-		delete mFind;
-		mFind = 0;
+		mNoCurrentItem = false;    // restart from the currently highlighted alarm if Find Next etc selected
 	}
 }
 
@@ -343,6 +387,3 @@ EventListViewItemBase* Find::nextItem(EventListViewItemBase* item, bool forward)
 		it = item ? item->itemAbove() : mListView->lastItem();
 	return (EventListViewItemBase*)it;
 }
-
-#endif
-
