@@ -1,7 +1,7 @@
 /*
  *  functions.cpp  -  miscellaneous functions
  *  Program:  kalarm
- *  Copyright © 2001-2006 by David Jarvie <software@astrojar.org.uk>
+ *  Copyright © 2001-2007 by David Jarvie <software@astrojar.org.uk>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,6 +19,20 @@
  */
 
 #include "kalarm.h"
+#include "functions.h"
+
+#include "alarmcalendar.h"
+#include "alarmevent.h"
+#include "alarmlistview.h"
+#include "daemon.h"
+#include "kalarmapp.h"
+#include "kamail.h"
+#include "mainwindow.h"
+#include "messagewin.h"
+#include "preferences.h"
+#include "shellprocess.h"
+#include "templatelistview.h"
+#include "templatemenuaction.h"
 
 #include <qdeepcopy.h>
 #include <qdir.h>
@@ -41,20 +55,6 @@
 #include <libkpimidentities/identity.h>
 #include <libkcal/person.h>
 
-#include "alarmcalendar.h"
-#include "alarmevent.h"
-#include "alarmlistview.h"
-#include "daemon.h"
-#include "kalarmapp.h"
-#include "kamail.h"
-#include "mainwindow.h"
-#include "messagewin.h"
-#include "preferences.h"
-#include "shellprocess.h"
-#include "templatelistview.h"
-#include "templatemenuaction.h"
-#include "functions.h"
-
 
 namespace
 {
@@ -430,8 +430,8 @@ UpdateStatus reactivateEvent(KAEvent& event, AlarmListView* selectionView, bool
 		QDateTime now = QDateTime::currentDateTime();
 		if (event.occursAfter(now, true))
 		{
-			if (event.recurs())
-				event.setNextOccurrence(now, true);   // skip any recurrences in the past
+			if (event.recurs()  ||  event.repeatCount())
+				event.setNextOccurrence(now);   // skip any recurrences in the past
 			event.setArchive();    // ensure that it gets re-archived if it is deleted
 
 			// Save the event details in the calendar file, and get the new event ID
@@ -791,32 +791,30 @@ int getVersionNumber(const QString& version, QString* subVersion)
 	//      if the representation returned by this method changes.
 	if (subVersion)
 		*subVersion = QString::null;
-	QStringList nums = QStringList::split(QChar('.'), version, true);
-	int count = nums.count();
-	if (count < 2  ||  count > 3)
+	int count = version.contains('.') + 1;
+	if (count < 2)
 		return 0;
 	bool ok;
-	int vernum = nums[0].toInt(&ok) * 10000;    // major version
+	unsigned vernum = version.section('.', 0, 0).toUInt(&ok) * 10000;  // major version
 	if (!ok)
 		return 0;
-	int v = nums[1].toInt(&ok);                 // minor version
+	unsigned v = version.section('.', 1, 1).toUInt(&ok);               // minor version
 	if (!ok)
 		return 0;
 	vernum += (v < 99 ? v : 99) * 100;
-	if (count == 3)
+	if (count >= 3)
 	{
 		// Issue number: allow other characters to follow the last digit
-		QString issue = nums[2];
+		QString issue = version.section('.', 2);
 		if (!issue.at(0).isDigit())
 			return 0;
-		v = issue.toInt();   // issue number
-		vernum += (v < 99 ? v : 99);
+		int n = issue.length();
+		int i;
+		for (i = 0;  i < n && issue.at(i).isDigit();  ++i) ;
 		if (subVersion)
-		{
-			int i;
-			for (i = 1;  const_cast<const QString&>(issue).at(i).isDigit();  ++i) ;
 			*subVersion = issue.mid(i);
-		}
+		v = issue.left(i).toUInt();   // issue number
+		vernum += (v < 99 ? v : 99);
 	}
 	return vernum;
 }
