@@ -1,7 +1,7 @@
 /*
  *  kalarmapp.cpp  -  the KAlarm application object
  *  Program:  kalarm
- *  Copyright © 2001-2006 by David Jarvie <software@astrojar.org.uk>
+ *  Copyright © 2001-2007 by David Jarvie <software@astrojar.org.uk>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -67,8 +67,8 @@
 #include <netwm.h>
 
 
-static bool convWakeTime(const QCString timeParam, QDateTime&, bool& noTime);
-static bool convInterval(QCString timeParam, KARecurrence::Type&, int& timeInterval, bool allowMonthYear = true);
+static bool convWakeTime(const QCString& timeParam, QDateTime&, bool& noTime);
+static bool convInterval(const QCString& timeParam, KARecurrence::Type&, int& timeInterval, bool allowMonthYear = true);
 
 /******************************************************************************
 * Find the maximum number of seconds late which a late-cancel alarm is allowed
@@ -128,6 +128,7 @@ KAlarmApp::KAlarmApp()
 		mStartOfDay             = Preferences::startOfDay();
 		if (Preferences::hasStartOfDayChanged())
 			mStartOfDay.setHMS(100,0,0);    // start of day time has changed: flag it as invalid
+		DateTime::setStartOfDay(mStartOfDay);
 		mPrefsExpiredColour   = Preferences::expiredColour();
 		mPrefsExpiredKeepDays = Preferences::expiredKeepDays();
 		mPrefsShowTime        = Preferences::showAlarmTime();
@@ -1223,7 +1224,7 @@ bool KAlarmApp::scheduleEvent(KAEvent::Action action, const QString& text, const
 			execAlarm(event, event.firstAlarm(), false);
 		// If it's a recurring alarm, reschedule it for its next occurrence
 		if (!event.recurs()
-		||  event.setNextOccurrence(now, true) == KAEvent::NO_OCCURRENCE)
+		||  event.setNextOccurrence(now) == KAEvent::NO_OCCURRENCE)
 			return true;
 		// It has recurrences in the future
 	}
@@ -1297,8 +1298,8 @@ bool KAlarmApp::handleEvent(const QString& eventID, EventFunc function)
 				if (alarm.deferred()  &&  event.repeatCount()
 				&&  repeatDT.isValid()  &&  alarm.dateTime() > repeatDT)
 				{
-					// This deferral of a repeated alarm is later than the last occurrence
-					// of the main alarm, so use the deferral alarm instead.
+					// This deferral of a repeated alarm is later than the last previous
+					// occurrence of the main alarm, so use the deferral alarm instead.
 					// If the deferral is not yet due, this prevents the main alarm being
 					// triggered repeatedly. If the deferral is due, this triggers it
 					// in preference to the main alarm.
@@ -1307,11 +1308,8 @@ bool KAlarmApp::handleEvent(const QString& eventID, EventFunc function)
 					updateCalAndDisplay = false;
 				}
 				// Check if the alarm is due yet.
-				// Just in case it's an invalid time during a daylight savings time
-				// shift, check more carefully if it's today.
-				int secs = alarm.dateTime().secsTo(now);
-				if (secs < 0
-				&&  (alarm.date() != now.date() || alarm.time() > now.time()))
+				int secs = alarm.dateTime(true).secsTo(now);
+				if (secs < 0)
 				{
 					// This alarm is definitely not due yet
 					kdDebug(5950) << "KAlarmApp::handleEvent(): alarm " << alarm.type() << ": not due\n";
@@ -1332,20 +1330,9 @@ bool KAlarmApp::handleEvent(const QString& eventID, EventFunc function)
 					if (alarmToExecute.valid())
 						continue;
 
-					// Set the time to be shown if it's a display alarm
+					// Set the time to display if it's a display alarm
 					alarm.setTime(now);
 				}
-				if (event.repeatCount()  &&  alarm.type() == KAAlarm::MAIN_ALARM)
-				{
-					// Alarm has a simple repetition. Since its time in the calendr remains the same
-					// until its repetitions are finished, adjust its time to the correct repetition
-					KAEvent::OccurType type = event.previousOccurrence(now.addSecs(1), repeatDT, true);
-					if (type & KAEvent::OCCURRENCE_REPEAT)
-					{
-						alarm.setTime(repeatDT);
-						secs = repeatDT.secsTo(now);
-					}
-				}
 				if (alarm.lateCancel())
 				{
 					// Alarm is due, and it is to be cancelled if too late.
@@ -1375,7 +1362,7 @@ bool KAlarmApp::handleEvent(const QString& eventID, EventFunc function)
 									{
 										if (type == KAEvent::LAST_RECURRENCE
 										||  type == KAEvent::FIRST_OR_ONLY_OCCURRENCE && !event.recurs())
-											cancel = true;   // last ocurrence (and there are no repetitions)
+											cancel = true;   // last occurrence (and there are no repetitions)
 										else
 											late = true;
 									}
@@ -1407,7 +1394,7 @@ bool KAlarmApp::handleEvent(const QString& eventID, EventFunc function)
 									{
 										if (type == KAEvent::LAST_RECURRENCE
 										||  type == KAEvent::FIRST_OR_ONLY_OCCURRENCE && !event.recurs())
-											cancel = true;   // last ocurrence (and there are no repetitions)
+											cancel = true;   // last occurrence (and there are no repetitions)
 										else
 											late = true;
 									}
@@ -1532,8 +1519,7 @@ void KAlarmApp::alarmCompleted(const KAEvent& event)
 void KAlarmApp::rescheduleAlarm(KAEvent& event, const KAAlarm& alarm, bool updateCalAndDisplay)
 {
 	kdDebug(5950) << "KAlarmApp::rescheduleAlarm()" << endl;
-	bool update        = false;
-	bool updateDisplay = false;
+	bool update = false;
 	if (alarm.reminder()  ||  alarm.deferred())
 	{
 		// It's an advance warning alarm or an extra deferred alarm, so delete it
@@ -1548,36 +1534,33 @@ void KAlarmApp::rescheduleAlarm(KAEvent& event, const KAAlarm& alarm, bool updat
 	}
 	else
 	{
-		QDateTime now = QDateTime::currentDateTime();
-		if (event.repeatCount()  &&  event.mainEndRepeatTime() > now)
-			updateDisplay = true;    // there are more repetitions to come, so just update time in alarm list
-		else
+		// Reschedule the alarm for its next recurrence.
+		KAEvent::OccurType type = event.setNextOccurrence(QDateTime::currentDateTime());
+		switch (type)
 		{
-			// The alarm's repetitions (if any) are finished.
-			// Reschedule it for its next recurrence.
-			switch (event.setNextOccurrence(now))
-			{
-				case KAEvent::NO_OCCURRENCE:
-					// All repetitions are finished, so cancel the event
-					cancelAlarm(event, alarm.type(), updateCalAndDisplay);
+			case KAEvent::NO_OCCURRENCE:
+				// All repetitions are finished, so cancel the event
+				cancelAlarm(event, alarm.type(), updateCalAndDisplay);
+				break;
+			default:
+				if (!(type & KAEvent::OCCURRENCE_REPEAT))
 					break;
-				case KAEvent::RECURRENCE_DATE:
-				case KAEvent::RECURRENCE_DATE_TIME:
-				case KAEvent::LAST_RECURRENCE:
-					// The event is due by now and repetitions still remain, so rewrite the event
-					if (updateCalAndDisplay)
-						update = true;
-					else
-					{
-						event.cancelCancelledDeferral();
-						event.setUpdated();    // note that the calendar file needs to be updated
-					}
-					break;
-				case KAEvent::FIRST_OR_ONLY_OCCURRENCE:
-					// The first occurrence is still due?!?, so don't do anything
-				default:
-					break;
-			}
+				// Next occurrence is a repeat, so fall through to recurrence handling
+			case KAEvent::RECURRENCE_DATE:
+			case KAEvent::RECURRENCE_DATE_TIME:
+			case KAEvent::LAST_RECURRENCE:
+				// The event is due by now and repetitions still remain, so rewrite the event
+				if (updateCalAndDisplay)
+					update = true;
+				else
+				{
+					event.cancelCancelledDeferral();
+					event.setUpdated();    // note that the calendar file needs to be updated
+				}
+				break;
+			case KAEvent::FIRST_OR_ONLY_OCCURRENCE:
+				// The first occurrence is still due?!?, so don't do anything
+				break;
 		}
 		if (event.deferred())
 		{
@@ -1591,11 +1574,6 @@ void KAlarmApp::rescheduleAlarm(KAEvent& event, const KAAlarm& alarm, bool updat
 		event.cancelCancelledDeferral();
 		KAlarm::updateEvent(event, 0);     // update the window lists and calendar file
 	}
-	else if (updateDisplay)
-	{
-		Daemon::eventHandled(event.id(), false);
-		AlarmListView::modifyEvent(event, 0);
-	}
 }
 
 /******************************************************************************
@@ -1645,10 +1623,27 @@ void* KAlarmApp::execAlarm(KAEvent& event, const KAAlarm& alarm, bool reschedule
 		{
 			// Display a message or file, provided that the same event isn't already being displayed
 			MessageWin* win = MessageWin::findEvent(event.id());
-			if (!win  &&  !noPreAction  &&  !event.preAction().isEmpty()  &&  ShellProcess::authorised())
+			// Find if we're changing a reminder message to the real message
+			bool reminder = (alarm.type() & KAAlarm::REMINDER_ALARM);
+			bool replaceReminder = !reminder && win && (win->alarmType() & KAAlarm::REMINDER_ALARM);
+			if (!reminder  &&  !event.deferred()
+			&&  (replaceReminder || !win)  &&  !noPreAction
+			&&  !event.preAction().isEmpty()  &&  ShellProcess::authorised())
 			{
-				// There is no message window currently displayed for this alarm,
+				// It's not a reminder or a deferred alarm, and there is no message window
+				// (other than a reminder window) currently displayed for this alarm,
 				// and we need to execute a command before displaying the new window.
+				// Check whether the command is already being executed for this alarm.
+				for (QValueList<ProcData*>::Iterator it = mCommandProcesses.begin();  it != mCommandProcesses.end();  ++it)
+				{
+					ProcData* pd = *it;
+					if (pd->event->id() == event.id()  &&  (pd->flags & ProcData::PRE_ACTION))
+					{
+						kdDebug(5950) << "KAlarmApp::execAlarm(): already executing pre-DISPLAY command" << endl;
+						return pd->process;   // already executing - don't duplicate the action
+					}
+				}
+
 				QString command = event.preAction();
 				kdDebug(5950) << "KAlarmApp::execAlarm(): pre-DISPLAY command: " << command << endl;
 				int flags = (reschedule ? ProcData::RESCHEDULE : 0) | (allowDefer ? ProcData::ALLOW_DEFER : 0);
@@ -1660,7 +1655,7 @@ void* KAlarmApp::execAlarm(KAEvent& event, const KAAlarm& alarm, bool reschedule
 				delete win;        // event is disabled - close its window
 			else if (!win
 			     ||  !win->hasDefer() && !alarm.repeatAtLogin()
-			     ||  (win->alarmType() & KAAlarm::REMINDER_ALARM) && !(alarm.type() & KAAlarm::REMINDER_ALARM))
+			     ||  replaceReminder)
 			{
 				// Either there isn't already a message for this event,
 				// or there is a repeat-at-login message with no Defer
@@ -1738,6 +1733,7 @@ void* KAlarmApp::execAlarm(KAEvent& event, const KAAlarm& alarm, bool reschedule
 */
 ShellProcess* KAlarmApp::doShellCommand(const QString& command, const KAEvent& event, const KAAlarm* alarm, int flags)
 {
+	kdDebug(5950) << "KAlarmApp::doShellCommand(" << command << ", " << event.id() << ")" << endl;
 	KProcess::Communication comms = KProcess::NoCommunication;
 	QString cmd;
 	QString tmpXtermFile;
@@ -1918,7 +1914,7 @@ void KAlarmApp::slotCommandExited(ShellProcess* proc)
 					delete dialogs;
 					if (!pd->tempFile())
 					{
-						errmsg += "\n";
+						errmsg += '\n';
 						errmsg += proc->command();
 					}
 					KMessageBox::error(pd->messageBoxParent, errmsg);
@@ -2038,7 +2034,7 @@ bool KAlarmApp::initCheck(bool calendarOnly)
 *  The parameter is in the form [[[yyyy-]mm-]dd-]hh:mm or yyyy-mm-dd.
 *  Reply = true if successful.
 */
-static bool convWakeTime(const QCString timeParam, QDateTime& dateTime, bool& noTime)
+static bool convWakeTime(const QCString& timeParam, QDateTime& dateTime, bool& noTime)
 {
 	if (timeParam.length() > 19)
 		return false;
@@ -2129,46 +2125,47 @@ static bool convWakeTime(const QCString timeParam, QDateTime& dateTime, bool& no
 *  Convert a time interval command line parameter.
 *  Reply = true if successful.
 */
-static bool convInterval(QCString timeParam, KARecurrence::Type& recurType, int& timeInterval, bool allowMonthYear)
+static bool convInterval(const QCString& timeParam, KARecurrence::Type& recurType, int& timeInterval, bool allowMonthYear)
 {
+	QCString timeString = timeParam;
 	// Get the recurrence interval
 	bool ok = true;
 	uint interval = 0;
-	bool negative = (timeParam[0] == '-');
+	bool negative = (timeString[0] == '-');
 	if (negative)
-		timeParam = timeParam.right(1);
-	uint length = timeParam.length();
-	switch (timeParam[length - 1])
+		timeString = timeString.right(1);
+	uint length = timeString.length();
+	switch (timeString[length - 1])
 	{
 		case 'Y':
 			if (!allowMonthYear)
 				ok = false;
 			recurType = KARecurrence::ANNUAL_DATE;
-			timeParam = timeParam.left(length - 1);
+			timeString = timeString.left(length - 1);
 			break;
 		case 'W':
 			recurType = KARecurrence::WEEKLY;
-			timeParam = timeParam.left(length - 1);
+			timeString = timeString.left(length - 1);
 			break;
 		case 'D':
 			recurType = KARecurrence::DAILY;
-			timeParam = timeParam.left(length - 1);
+			timeString = timeString.left(length - 1);
 			break;
 		case 'M':
 		{
-			int i = timeParam.find('H');
+			int i = timeString.find('H');
 			if (i < 0)
 			{
 				if (!allowMonthYear)
 					ok = false;
 				recurType = KARecurrence::MONTHLY_DAY;
-				timeParam = timeParam.left(length - 1);
+				timeString = timeString.left(length - 1);
 			}
 			else
 			{
 				recurType = KARecurrence::MINUTELY;
-				interval = timeParam.left(i).toUInt(&ok) * 60;
-				timeParam = timeParam.mid(i + 1, length - i - 2);
+				interval = timeString.left(i).toUInt(&ok) * 60;
+				timeString = timeString.mid(i + 1, length - i - 2);
 			}
 			break;
 		}
@@ -2177,7 +2174,7 @@ static bool convInterval(QCString timeParam, KARecurrence::Type& recurType, int&
 			break;
 	}
 	if (ok)
-		interval += timeParam.toUInt(&ok);
+		interval += timeString.toUInt(&ok);
 	timeInterval = static_cast<int>(interval);
 	if (negative)
 		timeInterval = -timeInterval;
