@@ -1,7 +1,7 @@
 /*
  *  alarmdaemon.cpp  -  alarm daemon control routines
  *  Program:  KAlarm's alarm daemon (kalarmd)
- *  Copyright (c) 2001, 2004-2006 by David Jarvie <software@astrojar.org.uk>
+ *  Copyright © 2001,2004-2007 by David Jarvie <software@astrojar.org.uk>
  *  Based on the original, (c) 1998, 1999 Preston Brown
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -364,17 +364,20 @@ void AlarmDaemon::checkAlarms(ADCalendar* cal)
 	QValueList<KCal::Alarm*> alarms = cal->alarmsTo(now);
 	if (!alarms.count())
 		return;
+	QValueList<KCal::Event*> eventsDone;
 	for (QValueList<KCal::Alarm*>::ConstIterator it = alarms.begin();  it != alarms.end();  ++it)
 	{
 		KCal::Event* event = dynamic_cast<KCal::Event*>((*it)->parent());
-		if (!event)
-			continue;
+		if (!event  ||  eventsDone.find(event) != eventsDone.end())
+			continue;   // either not an event, or the event has already been processed
+		eventsDone += event;
 		const QString& eventID = event->uid();
 		kdDebug(5901) << "AlarmDaemon::checkAlarms(): event " << eventID  << endl;
 
 		// Check which of the alarms for this event are due.
 		// The times in 'alarmtimes' corresponding to due alarms are set.
 		// The times for non-due alarms are set invalid in 'alarmtimes'.
+		bool recurs = event->doesRecur();
 		QValueList<QDateTime> alarmtimes;
 		KCal::Alarm::List alarms = event->alarms();
 		for (KCal::Alarm::List::ConstIterator al = alarms.begin();  al != alarms.end();  ++al)
@@ -382,7 +385,24 @@ void AlarmDaemon::checkAlarms(ADCalendar* cal)
 			KCal::Alarm* alarm = *al;
 			QDateTime dt;
 			if (alarm->enabled())
+			{
+				QDateTime dt1;
+				if (recurs  &&  !alarm->hasTime())
+				{
+					// Find the latest recurrence for the alarm.
+					// Need to do this for alarms with offsets in order to detect
+					// reminders due for recurrences.
+					int offset = alarm->hasStartOffset() ? alarm->startOffset().asSeconds()
+					           : alarm->endOffset().asSeconds() + event->dtStart().secsTo(event->dtEnd());
+					if (offset)
+						dt1 = event->recurrence()->getPreviousDateTime(now1.addSecs(-offset));
+				}
 				dt = alarm->previousRepetition(now1);   // get latest due repetition (if any)
+				if (!dt.isValid())
+					dt = dt1;
+				else if (dt1.isValid()  &&  dt1 > dt)
+					dt = dt1;
+			}
 			alarmtimes.append(dt);
 		}
 		if (!cal->eventHandled(event, alarmtimes))
