@@ -1,7 +1,7 @@
 /*
  *  kamail.cpp  -  email functions
  *  Program:  kalarm
- *  (C) 2002 - 2004 by David Jarvie <software@astrojar.org.uk>
+ *  Copyright © 2002-2005 by David Jarvie <software@astrojar.org.uk>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -13,9 +13,9 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  You should have received a copy of the GNU General Public License along
+ *  with this program; if not, write to the Free Software Foundation, Inc.,
+ *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #include "kalarm.h"
@@ -50,9 +50,10 @@
 #include <kmime_header_parsing.h>
 
 #include "alarmevent.h"
-#include "preferences.h"
+#include "functions.h"
 #include "kalarmapp.h"
 #include "mainwindow.h"
+#include "preferences.h"
 #include "kamail.h"
 
 
@@ -103,10 +104,9 @@ KPIM::IdentityManager* KAMail::identityManager()
 bool KAMail::send(const KAEvent& event, QStringList& errmsgs, bool allowNotify)
 {
 	QString err;
-	Preferences* preferences = Preferences::instance();
 	QString from;
 	if (event.emailFromKMail().isEmpty())
-		from = preferences->emailAddress();
+		from = Preferences::emailAddress();
 	else
 	{
 		from = mIdentityManager->identityForName(event.emailFromKMail()).fullEmailAddr();
@@ -118,29 +118,28 @@ bool KAMail::send(const KAEvent& event, QStringList& errmsgs, bool allowNotify)
 	}
 	if (from.isEmpty())
 	{
-		QString progname = kapp->aboutData()->programName();
-		switch (preferences->emailFrom())
+		switch (Preferences::emailFrom())
 		{
 			case Preferences::MAIL_FROM_KMAIL:
-				errmsgs = errors(i18n("No 'From' email address is configured (no default KMail identity found)\nPlease set it in KMail or in the %1 Preferences dialog.").arg(progname));
+				errmsgs = errors(i18n("No 'From' email address is configured (no default KMail identity found)\nPlease set it in KMail or in the KAlarm Preferences dialog."));
 				break;
 			case Preferences::MAIL_FROM_CONTROL_CENTRE:
-				errmsgs = errors(i18n("No 'From' email address is configured.\nPlease set it in the KDE Control Center or in the %1 Preferences dialog.").arg(progname));
+				errmsgs = errors(i18n("No 'From' email address is configured.\nPlease set it in the KDE Control Center or in the KAlarm Preferences dialog."));
 				break;
 			case Preferences::MAIL_FROM_ADDR:
 			default:
-				errmsgs = errors(i18n("No 'From' email address is configured.\nPlease set it in the %1 Preferences dialog.").arg(progname));
+				errmsgs = errors(i18n("No 'From' email address is configured.\nPlease set it in the KAlarm Preferences dialog."));
 				break;
 		}
 		return false;
 	}
 	KAMailData data(event, from,
-	                (event.emailBcc() ? preferences->emailBccAddress() : QString::null),
+	                (event.emailBcc() ? Preferences::emailBccAddress() : QString::null),
 	                allowNotify);
 	kdDebug(5950) << "KAlarmApp::sendEmail(): To: " << event.emailAddresses(", ")
 	              << "\nSubject: " << event.emailSubject() << endl;
 
-	if (preferences->emailClient() == Preferences::SENDMAIL)
+	if (Preferences::emailClient() == Preferences::SENDMAIL)
 	{
 		// Use sendmail to send the message
 		QString textComplete;
@@ -169,7 +168,7 @@ bool KAMail::send(const KAEvent& event, QStringList& errmsgs, bool allowNotify)
 				command += KShellProcess::quote(data.bcc);
 			}
 
-			command += " ";
+			command += ' ';
 			command += event.emailAddresses(" "); // locally provided, okay
 		}
 
@@ -193,7 +192,7 @@ bool KAMail::send(const KAEvent& event, QStringList& errmsgs, bool allowNotify)
 		fwrite(textComplete.local8Bit(), textComplete.length(), 1, fd);
 		pclose(fd);
 
-		if (preferences->emailCopyToKMail())
+		if (Preferences::emailCopyToKMail())
 		{
 			// Create a copy of the sent email in KMail's 'Sent-mail' folder
 			err = addToKMailFolder(data, "sent-mail", true);
@@ -224,76 +223,52 @@ bool KAMail::send(const KAEvent& event, QStringList& errmsgs, bool allowNotify)
 */
 QString KAMail::sendKMail(const KAMailData& data)
 {
-	if (kapp->dcopClient()->isApplicationRegistered("kmail"))
-	{
-		// KMail is running - use a DCOP call.
-		// First, determine which DCOP call to use.
-		bool useSend = false;
-		QCString sendFunction = "sendMessage(QString,QString,QString,QString,QString,QString,KURL::List)";
-		QCStringList funcs = kapp->dcopClient()->remoteFunctions("kmail", "MailTransportServiceIface");
-		for (QCStringList::Iterator it=funcs.begin();  it != funcs.end() && !useSend;  ++it)
-		{
-			QCString func = DCOPClient::normalizeFunctionSignature(*it);
-			if (func.left(5) == "bool ")
-			{
-				func = func.mid(5);
-				func.replace(QRegExp(" [0-9A-Za-z_:]+"), "");
-				useSend = (func == sendFunction);
-			}
-		}
+	QString err = KAlarm::runKMail(true);
+	if (!err.isNull())
+		return err;
 
-		QByteArray  callData;
-		QDataStream arg(callData, IO_WriteOnly);
-		kdDebug(5950) << "KAMail::sendKMail(): using " << (useSend ? "sendMessage()" : "dcopAddMessage()") << endl;
-		if (useSend)
+	// KMail is now running. Determine which DCOP call to use.
+	bool useSend = false;
+	QCString sendFunction = "sendMessage(QString,QString,QString,QString,QString,QString,KURL::List)";
+	QCStringList funcs = kapp->dcopClient()->remoteFunctions("kmail", "MailTransportServiceIface");
+	for (QCStringList::Iterator it=funcs.begin();  it != funcs.end() && !useSend;  ++it)
+	{
+		QCString func = DCOPClient::normalizeFunctionSignature(*it);
+		if (func.left(5) == "bool ")
 		{
-			// This version of KMail has the sendMessage() function,
-			// which transmits the message immediately.
-			arg << data.from;
-			arg << data.event.emailAddresses(", ");
-			arg << "";    // CC:
-			arg << data.bcc;
-			arg << data.event.emailSubject();
-			arg << data.event.message();
-			arg << KURL::List(data.event.emailAttachments());
-			if (!callKMail(callData, "MailTransportServiceIface", sendFunction, "bool"))
-				return i18n("Error calling KMail");
+			func = func.mid(5);
+			func.replace(QRegExp(" [0-9A-Za-z_:]+"), "");
+			useSend = (func == sendFunction);
 		}
-		else
-		{
-			// KMail is an older version, so use dcopAddMessage()
-			// to add the message to the outbox for later transmission.
-			QString err = addToKMailFolder(data, "outbox", false);
-			if (!err.isNull())
-				return err;
-		}
-		if (data.allowNotify)
-			notifyQueued(data.event);
+	}
+
+	QByteArray  callData;
+	QDataStream arg(callData, IO_WriteOnly);
+	kdDebug(5950) << "KAMail::sendKMail(): using " << (useSend ? "sendMessage()" : "dcopAddMessage()") << endl;
+	if (useSend)
+	{
+		// This version of KMail has the sendMessage() function,
+		// which transmits the message immediately.
+		arg << data.from;
+		arg << data.event.emailAddresses(", ");
+		arg << "";    // CC:
+		arg << data.bcc;
+		arg << data.event.emailSubject();
+		arg << data.event.message();
+		arg << KURL::List(data.event.emailAttachments());
+		if (!callKMail(callData, "MailTransportServiceIface", sendFunction, "bool"))
+			return i18n("Error calling KMail");
 	}
 	else
 	{
-		// KMail isn't running - start it
-		KProcess proc;
-		proc << "kmail"
-		     << "--subject" << data.event.emailSubject().local8Bit()
-		     << "--body" << data.event.message().local8Bit();
-		if (!data.bcc.isEmpty())
-			proc << "--bcc" << data.bcc.local8Bit();
-		QStringList attachments = data.event.emailAttachments();
-		if (attachments.count())
-		{
-			for (QStringList::Iterator at = attachments.begin();  at != attachments.end();  ++at)
-				proc << "--attach" << (*at).local8Bit();
-		}
-		EmailAddressList addresses = data.event.emailAddresses();
-		for (EmailAddressList::Iterator ad = addresses.begin();  ad != addresses.end();  ++ad)
-			proc << (*ad).fullName().local8Bit();
-		if (!proc.start(KProcess::DontCare))
-		{
-			kdDebug(5950) << "sendKMail(): kmail start failed" << endl;
-			return i18n("Error starting KMail");
-		}
+		// KMail is an older version, so use dcopAddMessage()
+		// to add the message to the outbox for later transmission.
+		err = addToKMailFolder(data, "outbox", false);
+		if (!err.isNull())
+			return err;
 	}
+	if (data.allowNotify)
+		notifyQueued(data.event);
 	return QString::null;
 }
 
@@ -304,10 +279,13 @@ QString KAMail::sendKMail(const KAMailData& data)
 */
 QString KAMail::addToKMailFolder(const KAMailData& data, const char* folder, bool checkKmailRunning)
 {
-	if (!checkKmailRunning  ||  kapp->dcopClient()->isApplicationRegistered("kmail"))
+	QString err;
+	if (checkKmailRunning)
+		err = KAlarm::runKMail(true);
+	if (err.isNull())
 	{
 		QString message = initHeaders(data, true);
-		QString err = appendBodyAttachments(message, data.event);
+		err = appendBodyAttachments(message, data.event);
 		if (!err.isNull())
 			return err;
 
@@ -334,9 +312,10 @@ QString KAMail::addToKMailFolder(const KAMailData& data, const char* folder, boo
 		arg << QString::fromLatin1(folder) << tmpFile.name();
 		if (callKMail(callData, "KMailIface", "dcopAddMessage(QString,QString)", "int"))
 			return QString::null;
+		err = i18n("Error calling KMail");
 	}
-	kdError(5950) << "KAMail::addToKMailFolder(" << folder << "): Error\n";
-	return i18n("Error calling KMail");
+	kdError(5950) << "KAMail::addToKMailFolder(" << folder << "): " << err << endl;
+	return err;
 }
 
 /******************************************************************************
@@ -413,8 +392,9 @@ QString KAMail::initHeaders(const KAMailData& data, bool dateId)
 QString KAMail::appendBodyAttachments(QString& message, const KAEvent& event)
 {
 	static const char* textMimeTypes[] = {
-		"application/x-shellscript", "application/x-nawk", "application/x-gawk", "application/x-awk",
-		"application/x-perl", "application/x-python", "application/x-desktop",
+		"application/x-sh", "application/x-csh", "application/x-shellscript",
+		"application/x-nawk", "application/x-gawk", "application/x-awk",
+		"application/x-perl", "application/x-desktop",
 		0
 	};
 	QStringList attachments = event.emailAttachments();
@@ -485,13 +465,13 @@ QString KAMail::appendBodyAttachments(QString& message, const KAEvent& event)
 				kdDebug(5950) << "KAMail::appendBodyAttachments() tmp load error: " << attachment << endl;
 				return attachError.arg(attachment);
 			}
-			Offset size = file.size();
+			QIODevice::Offset size = file.size();
 			char* contents = new char [size + 1];
 			Q_LONG bytes = file.readBlock(contents, size);
 			file.close();
 			contents[size] = 0;
 			bool atterror = false;
-			if (bytes == -1  ||  (Offset)bytes < size) {
+			if (bytes == -1  ||  (QIODevice::Offset)bytes < size) {
 				kdDebug(5950) << "KAMail::appendBodyAttachments() read error: " << attachment << endl;
 				atterror = true;
 			}
@@ -503,9 +483,9 @@ QString KAMail::appendBodyAttachments(QString& message, const KAEvent& event)
 			else
 			{
 				// Convert the attachment to BASE64 encoding
-				Offset base64Size;
+				QIODevice::Offset base64Size;
 				char* base64 = base64Encode(contents, size, base64Size);
-				if (base64Size == (Offset)-1) {
+				if (base64Size == (QIODevice::Offset)-1) {
 					kdDebug(5950) << "KAMail::appendBodyAttachments() base64 buffer overflow: " << attachment << endl;
 					atterror = true;
 				}
@@ -542,7 +522,7 @@ void KAMail::notifyQueued(const KAEvent& event)
 			QString domain = addr.mailboxList.first().addrSpec.domain;
 			if (!domain.isEmpty()  &&  domain != localhost  &&  domain != hostname)
 			{
-				QString text = (Preferences::instance()->emailClient() == Preferences::KMAIL)
+				QString text = (Preferences::emailClient() == Preferences::KMAIL)
 				             ? i18n("An email has been queued to be sent by KMail")
 				             : i18n("An email has been queued to be sent");
 				KMessageBox::information(0, text, QString::null, Preferences::EMAIL_QUEUED_NOTIFY);
@@ -794,7 +774,7 @@ QString KAMail::convertAttachments(const QString& items, KURL::List& list)
 */
 int KAMail::checkAttachment(QString& attachment, KURL* url)
 {
-	attachment.stripWhiteSpace();
+	attachment = attachment.stripWhiteSpace();
 	if (attachment.isEmpty())
 	{
 		if (url)
@@ -830,7 +810,7 @@ bool KAMail::checkAttachment(const KURL& url)
 *            -1 if overflow.
 *  Reply = BASE64 buffer, which the caller must delete[] afterwards.
 */
-char* KAMail::base64Encode(const char* in, KAMail::Offset size, KAMail::Offset& outSize)
+char* KAMail::base64Encode(const char* in, QIODevice::Offset size, QIODevice::Offset& outSize)
 {
 	const int MAX_LINELEN = 72;
 	static unsigned char dtable[65] =
@@ -839,10 +819,10 @@ char* KAMail::base64Encode(const char* in, KAMail::Offset size, KAMail::Offset&
 		"0123456789+/";
 
 	char* out = new char [2*size + 5];
-	outSize = (Offset)-1;
-	Offset outIndex = 0;
+	outSize = (QIODevice::Offset)-1;
+	QIODevice::Offset outIndex = 0;
 	int lineLength = 0;
-	for (Offset inIndex = 0;  inIndex < size;  )
+	for (QIODevice::Offset inIndex = 0;  inIndex < size;  )
 	{
 		unsigned char igroup[3];
 		int n;
@@ -975,7 +955,7 @@ bool parseUserName( const char* & scursor, const char * const send,
   QString maybeLocalPart;
   QString tmp;
 
-  while ( scursor != send ) {
+  if ( scursor != send ) {
     // first, eat any whitespace
     eatCFWS( scursor, send, isCRLF );
 
