@@ -1,7 +1,7 @@
 /*
  *  messagewin.cpp  -  displays an alarm message
  *  Program:  kalarm
- *  Copyright © 2001-2006 by David Jarvie <software@astrojar.org.uk>
+ *  Copyright © 2001-2007 by David Jarvie <software@astrojar.org.uk>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -140,7 +140,7 @@ MessageWin::MessageWin(const KAEvent& event, const KAAlarm& alarm, bool reschedu
 	  mFont(event.font()),
 	  mBgColour(event.bgColour()),
 	  mFgColour(event.fgColour()),
-	  mDateTime((alarm.type() & KAAlarm::REMINDER_ALARM) ? event.mainDateTime() : alarm.dateTime()),
+	  mDateTime((alarm.type() & KAAlarm::REMINDER_ALARM) ? event.mainDateTime(true) : alarm.dateTime(true)),
 	  mEventID(event.id()),
 	  mAudioFile(event.audioFile()),
 	  mVolume(event.soundVolume()),
@@ -168,14 +168,15 @@ MessageWin::MessageWin(const KAEvent& event, const KAAlarm& alarm, bool reschedu
 	  mFlags(event.flags()),
 	  mLateCancel(event.lateCancel()),
 	  mErrorWindow(false),
-	  mNoPostAction(false),
+	  mNoPostAction(alarm.type() & KAAlarm::REMINDER_ALARM),
 	  mRecreating(false),
 	  mBeep(event.beep()),
 	  mSpeak(event.speak()),
 	  mRescheduleEvent(reschedule_event),
 	  mShown(false),
 	  mPositioning(false),
-	  mNoCloseConfirm(false)
+	  mNoCloseConfirm(false),
+	  mDisableDeferral(false)
 {
 	kdDebug(5950) << "MessageWin::MessageWin(event)" << endl;
 	// Set to save settings automatically, but don't save window size.
@@ -218,7 +219,8 @@ MessageWin::MessageWin(const KAEvent& event, const DateTime& alarmDateTime, cons
 	  mRescheduleEvent(false),
 	  mShown(false),
 	  mPositioning(false),
-	  mNoCloseConfirm(false)
+	  mNoCloseConfirm(false),
+	  mDisableDeferral(false)
 {
 	kdDebug(5950) << "MessageWin::MessageWin(errmsg)" << endl;
 	initView();
@@ -239,14 +241,14 @@ MessageWin::MessageWin()
 	  mDeferDlg(0),
 	  mWinModule(0),
 	  mErrorWindow(false),
-	  mNoPostAction(true),
 	  mRecreating(false),
 	  mRescheduleEvent(false),
 	  mShown(false),
 	  mPositioning(false),
-	  mNoCloseConfirm(false)
+	  mNoCloseConfirm(false),
+	  mDisableDeferral(false)
 {
-	kdDebug(5950) << "MessageWin::MessageWin()\n";
+	kdDebug(5950) << "MessageWin::MessageWin(restore)\n";
 	mWindowList.append(this);
 }
 
@@ -255,7 +257,7 @@ MessageWin::MessageWin()
 */
 MessageWin::~MessageWin()
 {
-	kdDebug(5950) << "MessageWin::~MessageWin()\n";
+	kdDebug(5950) << "MessageWin::~MessageWin(" << mEventID << ")" << endl;
 	stopPlay();
 	delete mWinModule;
 	mWinModule = 0;
@@ -601,7 +603,7 @@ void MessageWin::setRemainingTextDay()
 {
 	QString text;
 	int days = QDate::currentDate().daysTo(mDateTime.date());
-	if (days == 0  &&  !mDateTime.isDateOnly())
+	if (days <= 0  &&  !mDateTime.isDateOnly())
 	{
 		// The alarm is due today, so start refreshing every minute
 		MidnightTimer::disconnect(this, SLOT(setRemainingTextDay()));
@@ -610,7 +612,7 @@ void MessageWin::setRemainingTextDay()
 	}
 	else
 	{
-		if (days == 0)
+		if (days <= 0)
 			text = i18n("Today");
 		else if (days % 7)
 			text = i18n("Tomorrow", "in %n days' time", days);
@@ -629,7 +631,7 @@ void MessageWin::setRemainingTextMinute()
 	QString text;
 	int mins = (QDateTime::currentDateTime().secsTo(mDateTime.dateTime()) + 59) / 60;
 	if (mins < 60)
-		text = i18n("in 1 minute's time", "in %n minutes' time", mins);
+		text = i18n("in 1 minute's time", "in %n minutes' time", (mins > 0 ? mins : 0));
 	else if (mins % 60 == 0)
 		text = i18n("in 1 hour's time", "in %n hours' time", mins/60);
 	else if (mins % 60 == 1)
@@ -674,6 +676,7 @@ void MessageWin::saveProperties(KConfig* config)
 		config->writeEntry(QString::fromLatin1("Height"), height());
 		config->writeEntry(QString::fromLatin1("DeferMins"), mDefaultDeferMinutes);
 		config->writeEntry(QString::fromLatin1("NoDefer"), mNoDefer);
+		config->writeEntry(QString::fromLatin1("NoPostAction"), mNoPostAction);
 		config->writeEntry(QString::fromLatin1("KMailSerial"), mKMailSerialNumber);
 	}
 	else
@@ -713,8 +716,10 @@ void MessageWin::readProperties(KConfig* config)
 	mRestoreHeight       = config->readNumEntry(QString::fromLatin1("Height"));
 	mDefaultDeferMinutes = config->readNumEntry(QString::fromLatin1("DeferMins"));
 	mNoDefer             = config->readBoolEntry(QString::fromLatin1("NoDefer"));
+	mNoPostAction        = config->readBoolEntry(QString::fromLatin1("NoPostAction"));
 	mKMailSerialNumber   = config->readUnsignedLongNumEntry(QString::fromLatin1("KMailSerial"));
 	mShowEdit            = false;
+	kdDebug(5950) << "MessageWin::readProperties(" << mEventID << ")" << endl;
 	if (mAlarmType != KAAlarm::INVALID_ALARM)
 	{
 		// Recreate the event from the calendar file (if possible)
@@ -1325,7 +1330,7 @@ void MessageWin::enableButtons()
 {
 	mOkButton->setEnabled(true);
 	mKAlarmButton->setEnabled(true);
-	if (mDeferButton)
+	if (mDeferButton  &&  !mDisableDeferral)
 		mDeferButton->setEnabled(true);
 	if (mEditButton)
 		mEditButton->setEnabled(true);
@@ -1466,6 +1471,7 @@ void MessageWin::setDeferralLimit(const KAEvent& event)
 	{
 		mDeferLimit = event.deferralLimit().dateTime();
 		MidnightTimer::connect(this, SLOT(checkDeferralLimit()));   // check every day
+		mDisableDeferral = false;
 		checkDeferralLimit();
 	}
 }
@@ -1498,6 +1504,7 @@ void MessageWin::checkDeferralLimit()
 		}
 	}
 	mDeferButton->setEnabled(false);
+	mDisableDeferral = true;
 }
 
 /******************************************************************************
@@ -1525,6 +1532,8 @@ void MessageWin::slotDefer()
 			bool repeat = event.defer(dateTime, (mAlarmType & KAAlarm::REMINDER_ALARM), true);
 			event.setDeferDefaultMinutes(delayMins);
 			KAlarm::updateEvent(event, 0, mDeferDlg, true, !repeat);
+			if (event.deferred())
+				mNoPostAction = true;
 		}
 		else
 		{
@@ -1547,6 +1556,8 @@ void MessageWin::slotDefer()
 			// Add the event back into the calendar file, retaining its ID
 			// and not updating KOrganizer
 			KAlarm::addEvent(event, 0, mDeferDlg, true, false);
+			if (event.deferred())
+				mNoPostAction = true;
 			if (kcalEvent)
 			{
 				event.setUid(KAEvent::EXPIRED);
