@@ -310,7 +310,7 @@ MiscPrefTab::MiscPrefTab(QVBox* frame)
 	QWhatsThis::add(mConfirmAlarmDeletion,
 	      i18n("Check to be prompted for confirmation each time you delete an alarm."));
 	itemBox->setStretchFactor(new QWidget(itemBox), 1);    // left adjust the controls
-	itemBox->setFixedHeight(box->sizeHint().height());
+	itemBox->setFixedHeight(itemBox->sizeHint().height());
 
 	// Expired alarms
 	group = new QGroupBox(i18n("Expired Alarms"), mPage);
@@ -1074,7 +1074,7 @@ void EditPrefTab::apply(bool syncToDisc)
 	Preferences::mDefaultSoundRepeat      = mSoundRepeat->isChecked();
 #endif
 	Preferences::mDefaultCmdScript        = mCmdScript->isChecked();
-	Preferences::mDefaultCmdLogFile       = (mCmdXterm->isChecked() ? EditAlarmDlg::EXEC_IN_TERMINAL : EditAlarmDlg::DISCARD_OUTPUT);
+	Preferences::mDefaultCmdLogType       = (mCmdXterm->isChecked() ? EditAlarmDlg::EXEC_IN_TERMINAL : EditAlarmDlg::DISCARD_OUTPUT);
 	Preferences::mDefaultEmailBcc         = mEmailBcc->isChecked();
 	Preferences::mDefaultCopyToKOrganizer = mCopyToKOrganizer->isChecked();
 	Preferences::mDefaultLateCancel       = mLateCancel->isChecked() ? 1 : 0;
