@@ -1,7 +1,7 @@
 /*
  *  preferences.h  -  program preference settings
  *  Program:  kalarm
- *  Copyright (C) 2001 - 2005 by David Jarvie <software@astrojar.org.uk>
+ *  Copyright © 2001-2006 by David Jarvie <software@astrojar.org.uk>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -60,7 +60,6 @@ class Preferences : public QObject
 		static const QFont&      messageFont()                    { return mMessageFont; }
 		static const QTime&      startOfDay()                     { return mStartOfDay; }
 		static bool              hasStartOfDayChanged()           { return mStartOfDayChanged; }
-		static bool              autostartDaemon()                { return mAutostartDaemon; }
 		static bool              runInSystemTray()                { return mRunInSystemTray; }
 		static bool              disableAlarmsIfStopped()         { return mDisableAlarmsIfStopped; }
 		static bool              quitWarn()                       { return notifying(QUIT_WARN); }
@@ -90,7 +89,6 @@ class Preferences : public QObject
 		static QColor            disabledColour()                 { return mDisabledColour; }
 		static QColor            expiredColour()                  { return mExpiredColour; }
 		static int               expiredKeepDays()                { return mExpiredKeepDays; }
-		static bool              defaultSound()                   { return mDefaultSound; }
 		static SoundPicker::Type defaultSoundType()               { return mDefaultSoundType; }
 		static const QString&    defaultSoundFile()               { return mDefaultSoundFile; }
 		static float             defaultSoundVolume()             { return mDefaultSoundVolume; }
@@ -123,7 +121,6 @@ class Preferences : public QObject
 		static const QColor                     default_defaultFgColour;
 		static const QFont&                     default_messageFont()  { return mDefault_messageFont; };
 		static const QTime                      default_startOfDay;
-		static const bool                       default_autostartDaemon;
 		static const bool                       default_runInSystemTray;
 		static const bool                       default_disableAlarmsIfStopped;
 		static const bool                       default_quitWarn;
@@ -154,7 +151,6 @@ class Preferences : public QObject
 		static const int                        default_defaultLateCancel;
 		static const bool                       default_defaultAutoClose;
 		static const bool                       default_defaultCopyToKOrganizer;
-		static const bool                       default_defaultSound;
 		static const SoundPicker::Type          default_defaultSoundType;
 		static const bool                       default_defaultSoundRepeat;
 		static const bool                       default_defaultConfirmAck;
@@ -201,7 +197,6 @@ class Preferences : public QObject
 		static QColor              mDefaultBgColour;
 		static QFont               mMessageFont;
 		static QTime               mStartOfDay;
-		static bool                mAutostartDaemon;
 		static bool                mRunInSystemTray;
 		static bool                mDisableAlarmsIfStopped;
 		static bool                mAutostartTrayIcon;
@@ -229,7 +224,6 @@ class Preferences : public QObject
 		static int                 mDefaultLateCancel;
 		static bool                mDefaultAutoClose;
 		static bool                mDefaultCopyToKOrganizer;
-		static bool                mDefaultSound;
 		static SoundPicker::Type   mDefaultSoundType;
 		static bool                mDefaultSoundRepeat;
 		static bool                mDefaultConfirmAck;
@@ -245,7 +239,6 @@ class Preferences : public QObject
 		// Change tracking
 		static QTime               mOldStartOfDay;       // previous start-of-day time
 		static bool                mStartOfDayChanged;   // start-of-day check value doesn't tally with mStartOfDay
-		static bool                mOldAutostartDaemon;  // previous daemon autostart value
 };
 
 #endif // PREFERENCES_H
