@@ -81,8 +81,8 @@ TaskView::TaskView(QWidget *parent, const char *name, const QString &icsfile ):K
   _idleTimeDetector = new IdleTimeDetector( _preferences->idlenessTimeout() );
   connect( _idleTimeDetector, SIGNAL( extractTime(int) ),
            this, SLOT( extractTime(int) ));
-  connect( _idleTimeDetector, SIGNAL( stopAllTimers() ),
-           this, SLOT( stopAllTimers() ));
+  connect( _idleTimeDetector, SIGNAL( stopAllTimersAt(QDateTime) ),
+           this, SLOT( stopAllTimersAt(QDateTime) ));
   connect( _preferences, SIGNAL( idlenessTimeout(int) ),
            _idleTimeDetector, SLOT( setMaxIdle(int) ));
   connect( _preferences, SIGNAL( detectIdleness(bool) ),
@@ -352,38 +352,20 @@ QString TaskView::exportcsvHistory()
 
 void TaskView::scheduleSave()
 {
-    _manualSaveTimer->start( 10, true /*single-shot*/ );
+  kdDebug(5970) << "Entering TaskView::scheduleSave" << endl;
+  // save changes a little while after they happen
+  _manualSaveTimer->start( 10, true /*single-shot*/ );
 }
 
 Preferences* TaskView::preferences() { return _preferences; }
 
 QString TaskView::save()
+// This saves the tasks. If they do not yet have an endDate, their startDate is also not saved.
 {
-    // DF: this code created a new event for the running task(s),
-    // at every call (very frequent with autosave) !!!
-    // -> if one wants autosave to save the current event, then
-    // Task needs to store the "current event" and we need to update
-    // it before calling save.
-#if 0
-  // Stop then start all timers so history entries are written.  This is
-  // inefficient if more than one task running, but it is correct.  It is
-  // inefficient because the iCalendar file is saved every time a task's
-  // setRunning(false, ...) is called.  For a big ics file, this could be a
-  // drag.  However, it does ensure that the data will be consistent.  And
-  // if the most common use case is that one task is running most of the time,
-  // it won't make any difference.
-  for (unsigned int i = 0; i < activeTasks.count(); i++)
-  {
-    activeTasks.at(i)->setRunning(false, _storage);
-    activeTasks.at(i)->setRunning(true, _storage);
-  }
-
-  // If there was an active task, the iCal file has already been saved.
-  if (activeTasks.count() == 0)
-#endif
-  {
-    return _storage->save(this);
-  }
+  kdDebug(5970) << "Entering TaskView::save" << endl;
+  QString err = _storage->save(this);
+  emit(setStatusBar(err));
+  return err;
 }
 
 void TaskView::startCurrentTimer()
@@ -400,16 +382,21 @@ long TaskView::count()
 
 void TaskView::startTimerFor(Task* task, QDateTime startTime )
 {
-  if (task != 0 && activeTasks.findRef(task) == -1) {
-    _idleTimeDetector->startIdleDetection();
-    task->setRunning(true, _storage, startTime);
-    activeTasks.append(task);
-    emit updateButtons();
-    if ( activeTasks.count() == 1 )
+  kdDebug(5970) << "Entering TaskView::startTimerFor" << endl;
+  if (save()==QString())
+  {
+    if (task != 0 && activeTasks.findRef(task) == -1) 
+    {
+      _idleTimeDetector->startIdleDetection();
+      task->setRunning(true, _storage, startTime);
+      activeTasks.append(task);
+      emit updateButtons();
+      if ( activeTasks.count() == 1 )
         emit timersActive();
-
-    emit tasksChanged( activeTasks);
+      emit tasksChanged( activeTasks);
+    }
   }
+  else KMessageBox::error(0,i18n("Saving is impossible, so timing is useless. \nSaving problems may result from a full harddisk, a directory name instead of a file name, or stale locks. Check that your harddisk has enough space, that your calendar file exists and is a file and remove stale locks, typically from ~/.kde/share/apps/kabc/lock."));
 }
 
 void TaskView::clearActiveTasks()
@@ -419,6 +406,7 @@ void TaskView::clearActiveTasks()
 
 void TaskView::stopAllTimers()
 {
+  kdDebug(5970) << "Entering TaskView::stopAllTimers()" << endl;
   for ( unsigned int i = 0; i < activeTasks.count(); i++ )
     activeTasks.at(i)->setRunning(false, _storage);
 
@@ -426,7 +414,25 @@ void TaskView::stopAllTimers()
   activeTasks.clear();
   emit updateButtons();
   emit timersInactive();
-  emit tasksChanged( activeTasks);
+  emit tasksChanged( activeTasks );
+}
+
+void TaskView::stopAllTimersAt(QDateTime qdt)
+// stops all timers for the time qdt. This makes sense, if the idletimedetector detected
+// the last work has been done 50 minutes ago.
+{
+  kdDebug(5970) << "Entering TaskView::stopAllTimersAt " << qdt << endl;
+  for ( unsigned int i = 0; i < activeTasks.count(); i++ )
+  {
+    activeTasks.at(i)->setRunning(false, _storage, qdt, qdt);
+    kdDebug() << activeTasks.at(i)->name() << endl;
+  }
+
+  _idleTimeDetector->stopIdleDetection();
+  activeTasks.clear();
+  emit updateButtons();
+  emit timersInactive();
+  emit tasksChanged( activeTasks );
 }
 
 void TaskView::startNewSession()
@@ -449,6 +455,7 @@ void TaskView::resetTimeForAllTasks()
 
 void TaskView::stopTimerFor(Task* task)
 {
+  kdDebug(5970) << "Entering stopTimerFor. task = " << task->name() << endl;
   if ( task != 0 && activeTasks.findRef(task) != -1 ) {
     activeTasks.removeRef(task);
     task->setRunning(false, _storage);
@@ -689,8 +696,14 @@ void TaskView::deleteTask(bool markingascomplete)
 }
 
 void TaskView::extractTime(int minutes)
+// This procedure subtracts ''minutes'' from the active task's time in the memory.
+// It is called by the idletimedetector class.
+// When the desktop has been idle for the past 20 minutes, the past 20 minutes have 
+// already been added to the task's time in order for the time to be displayed correctly.
+// That is why idletimedetector needs to subtract this time first.
 {
-  addTimeToActiveTasks(-minutes);
+  kdDebug(5970) << "Entering extractTime" << endl;
+  addTimeToActiveTasks(-minutes,false); // subtract minutes, but do not store it
 }
 
 void TaskView::autoSaveChanged(bool on)
@@ -748,11 +761,16 @@ void TaskView::deletingTask(Task* deletedTask)
 }
 
 void TaskView::iCalFileChanged(QString file)
+// User might have picked a new file in the preferences dialog.
+// This is not iCalFileModified.
 {
   kdDebug(5970) << "TaskView:iCalFileChanged: " << file << endl;
-  stopAllTimers();
-  _storage->save(this);
-  load();
+  if (_storage->icalfile() != file)
+  {
+    stopAllTimers();
+    _storage->save(this);
+    load();
+  }
 }
 
 QValueList<HistoryEvent> TaskView::getHistory(const QDate& from,
@@ -794,18 +812,42 @@ void TaskView::clipTotals()
         i18n("Copy totals for just this task and its subtasks, or copy totals for all tasks?"),
         i18n("Copy Totals to Clipboard"),
         i18n("Copy This Task"), i18n("Copy All Tasks") );
-    if (response == KMessageBox::Yes) // this task only
+    if (response == KMessageBox::Yes) // This task only
     {
-      KApplication::clipboard()->setText(t.totalsAsText(this));
+      KApplication::clipboard()->setText(t.totalsAsText(this, true, TimeKard::TotalTime));
     }
-    else // only task
+    else // All tasks
     {
-      KApplication::clipboard()->setText(t.totalsAsText(this, false));
+      KApplication::clipboard()->setText(t.totalsAsText(this, false, TimeKard::TotalTime));
     }
   }
   else
   {
-    KApplication::clipboard()->setText(t.totalsAsText(this));
+    KApplication::clipboard()->setText(t.totalsAsText(this, true, TimeKard::TotalTime));
+  }
+}
+
+void TaskView::clipSession()
+{
+  TimeKard t;
+  if (current_item() && current_item()->isRoot())
+  {
+    int response = KMessageBox::questionYesNo( 0,
+        i18n("Copy session time for just this task and its subtasks, or copy session time for all tasks?"),
+        i18n("Copy Session Time to Clipboard"),
+        i18n("Copy This Task"), i18n("Copy All Tasks") );
+    if (response == KMessageBox::Yes) // this task only
+    {
+      KApplication::clipboard()->setText(t.totalsAsText(this, true, TimeKard::SessionTime));
+    }
+    else // only task
+    {
+      KApplication::clipboard()->setText(t.totalsAsText(this, false, TimeKard::SessionTime));
+    }
+  }
+  else
+  {
+    KApplication::clipboard()->setText(t.totalsAsText(this, true, TimeKard::SessionTime));
   }
 }
 
