@@ -469,7 +469,7 @@ void KDGanttMinimizeSplitter::setOrientation( Orientation o )
 
 #if QT_VERSION >= 300
 /*!
-  \reimp
+  Reimplemented from superclass.
 */
 void KDGanttMinimizeSplitter::resizeEvent( QResizeEvent * )
 {
@@ -600,7 +600,7 @@ void KDGanttMinimizeSplitter::setRubberband( int p )
 }
 
 
-/*! \reimp */
+/*! Reimplemented from superclass. */
 bool KDGanttMinimizeSplitter::event( QEvent *e )
 {
     if ( e->type() == QEvent::LayoutHint || ( e->type() == QEvent::Show && data->firstShow ) ) {
@@ -952,7 +952,7 @@ void KDGanttMinimizeSplitter::recalc( bool update )
     for ( int i = 0; i< n; i++ ) {
 	QSplitterLayoutStruct *s = data->list.at(i);
 	if ( !s->isSplitter ) {
-	    QSplitterLayoutStruct *p = (i > 0) ? p = data->list.at( i-1 ) : 0;
+	    QSplitterLayoutStruct *p = (i > 0) ? data->list.at( i-1 ) : 0;
 	    if ( p && p->isSplitter )
 		if ( first || s->wid->isHidden() )
 		    p->wid->hide(); //may trigger new recalc
@@ -1124,7 +1124,7 @@ void KDGanttMinimizeSplitter::recalcId()
 }
 
 
-/*!\reimp
+/*! Reimplemented from superclass.
 */
 QSize KDGanttMinimizeSplitter::sizeHint() const
 {
@@ -1325,7 +1325,7 @@ void KDGanttMinimizeSplitter::processChildEvents()
 
 
 /*!
-  \reimp
+  Reimplemented from superclass.
 */
 
 void KDGanttMinimizeSplitter::styleChange( QStyle& old )
