@@ -1219,6 +1219,7 @@ IMAP4Protocol::del (const KURL & _url, bool isFile)
  * ACL commands: data = 'A' + command + URL (KURL) + command-dependent args
  * AnnotateMore commands: data = 'M' + 'G'et/'S'et + URL + entry + command-dependent args
  * Search: data = 'E' + URL (KURL)
+ * Quota commands: data = 'Q' + 'R'oot/'G'et/'S'et + URL + entry + command-dependent args
  */
 void
 IMAP4Protocol::special (const QByteArray & aData)
@@ -1337,6 +1338,18 @@ IMAP4Protocol::special (const QByteArray & aData)
     }
     break;
   }
+  case 'Q':
+  {
+    // quota
+    int cmd;
+    stream >> cmd;
+    if ( hasCapability( "QUOTA" ) ) {
+      specialQuotaCommand( cmd, stream );
+    } else {
+      error( ERR_UNSUPPORTED_ACTION, "QUOTA" );
+    }
+    break;
+  }
   case 'S':
   {
     // status
@@ -1585,6 +1598,50 @@ IMAP4Protocol::specialAnnotateMoreCommand( int command, QDataStream& stream )
   }
 }
 
+void
+IMAP4Protocol::specialQuotaCommand( int command, QDataStream& stream )
+{
+  // All commands start with the URL to the box
+  KURL _url;
+  stream >> _url;
+  QString aBox, aSequence, aLType, aSection, aValidity, aDelimiter, aInfo;
+  parseURL (_url, aBox, aSection, aLType, aSequence, aValidity, aDelimiter, aInfo);
+
+  switch( command ) {
+    case 'R': // GETQUOTAROOT
+      {
+        kdDebug(7116) << "QUOTAROOT " << aBox << endl;
+        imapCommand *cmd = doCommand(imapCommand::clientGetQuotaroot( aBox ) );
+        if (cmd->result () != "OK")
+        {
+          error(ERR_SLAVE_DEFINED, i18n("Retrieving the quota root information on folder %1 "
+                "failed. The server returned: %2")
+              .arg(_url.prettyURL())
+              .arg(cmd->resultInfo()));
+          return;
+        }
+        infoMessage(getResults().join( "\r" ));
+        finished();
+        break;
+      }
+    case 'G': // GETQUOTA
+      {
+        kdDebug(7116) << "GETQUOTA command" << endl;
+        kdWarning(7116) << "UNIMPLEMENTED" << endl;
+        break;
+      }
+    case 'S': // SETQUOTA
+      {
+        kdDebug(7116) << "SETQUOTA command" << endl;
+        kdWarning(7116) << "UNIMPLEMENTED" << endl;
+        break;
+      }
+    default:
+      kdWarning(7116) << "Unknown special quota command:" << command << endl;
+      error( ERR_UNSUPPORTED_ACTION, QString(QChar(command)) );
+  }
+}
+
 void
 IMAP4Protocol::rename (const KURL & src, const KURL & dest, bool overwrite)
 {
@@ -1963,14 +2020,14 @@ bool IMAP4Protocol::makeLogin ()
         }
       }
       if (!clientLogin (myUser, myPass, resultInfo))
-        error(KIO::ERR_COULD_NOT_LOGIN, i18n("Unable to login. Probably the "
+        error(KIO::ERR_COULD_NOT_AUTHENTICATE, i18n("Unable to login. Probably the "
         "password is wrong.\nThe server %1 replied:\n%2").arg(myHost).arg(resultInfo));
     }
     else
     {
 #ifdef HAVE_LIBSASL2
       if (!clientAuthenticate (this, authInfo, myHost, myAuth, mySSL, resultInfo))
-        error(KIO::ERR_COULD_NOT_LOGIN, i18n("Unable to authenticate via %1.\n"
+        error(KIO::ERR_COULD_NOT_AUTHENTICATE, i18n("Unable to authenticate via %1.\n"
 	"The server %2 replied:\n%3").arg(myAuth).arg(myHost).arg(resultInfo));
       else {
         myUser = authInfo.username;
