@@ -64,6 +64,7 @@
 #include "folderrequester.h"
 #include "kmmainwidget.h"
 #include "kmfolder.h"
+#include "globalsettings.h"
 
 #include <cassert>
 #include <stdlib.h>
@@ -632,7 +633,8 @@ void AccountDialog::makePopAccountPage()
            this, SLOT( slotEnableLeaveOnServerDays(bool)) );
   mPop.leaveOnServerDaysSpin = new KIntNumInput( afterDaysBox );
   mPop.leaveOnServerDaysSpin->setRange( 1, 365, 1, false );
-  mPop.leaveOnServerDaysSpin->setSuffix( i18n(" days") );
+  connect( mPop.leaveOnServerDaysSpin, SIGNAL(valueChanged(int)),
+           SLOT(slotLeaveOnServerDaysChanged(int)));
   mPop.leaveOnServerDaysSpin->setValue( 1 );
   afterDaysBox->setStretchFactor( mPop.leaveOnServerDaysSpin, 1 );
   grid->addMultiCellWidget( afterDaysBox, 7, 7, 0, 1 );
@@ -644,7 +646,8 @@ void AccountDialog::makePopAccountPage()
            this, SLOT( slotEnableLeaveOnServerCount(bool)) );
   mPop.leaveOnServerCountSpin = new KIntNumInput( leaveOnServerCountBox );
   mPop.leaveOnServerCountSpin->setRange( 1, 999999, 1, false );
-  mPop.leaveOnServerCountSpin->setSuffix( i18n(" messages") );
+  connect( mPop.leaveOnServerCountSpin, SIGNAL(valueChanged(int)),
+           SLOT(slotLeaveOnServerCountChanged(int)));
   mPop.leaveOnServerCountSpin->setValue( 100 );
   grid->addMultiCellWidget( leaveOnServerCountBox, 8, 8, 0, 1 );
   QHBox *leaveOnServerSizeBox = new QHBox( page1 );
@@ -696,8 +699,9 @@ void AccountDialog::makePopAccountPage()
   mPop.filterOnServerSizeSpin->setEnabled( false );
   hbox->setStretchFactor( mPop.filterOnServerSizeSpin, 1 );
   mPop.filterOnServerSizeSpin->setRange( 1, 10000000, 100, FALSE );
+  connect(mPop.filterOnServerSizeSpin, SIGNAL(valueChanged(int)),
+          SLOT(slotFilterOnServerSizeChanged(int)));
   mPop.filterOnServerSizeSpin->setValue( 50000 );
-  mPop.filterOnServerSizeSpin->setSuffix( i18n(" byte") );
   grid->addMultiCellWidget( hbox, 11, 11, 0, 1 );
   connect( mPop.filterOnServerCheck, SIGNAL(toggled(bool)),
 	   mPop.filterOnServerSizeSpin, SLOT(setEnabled(bool)) );
@@ -881,10 +885,10 @@ void AccountDialog::makeImapAccountPage( bool connected )
   button->setAutoRaise(true);
   button->setSizePolicy( QSizePolicy( QSizePolicy::Fixed, QSizePolicy::Fixed ) );
   button->setFixedSize( 22, 22 );
-  button->setIconSet( 
+  button->setIconSet(
       KGlobal::iconLoader()->loadIconSet( "reload", KIcon::Small, 0 ) );
   connect( button, SIGNAL(clicked()), this, SLOT(slotReloadNamespaces()) );
-  QWhatsThis::add( button, 
+  QWhatsThis::add( button,
       i18n("Reload the namespaces from the server. This overwrites any changes.") );
   grid->addWidget( box, row, 0 );
 
@@ -895,7 +899,7 @@ void AccountDialog::makeImapAccountPage( bool connected )
   mImap.personalNS = new KLineEdit( listbox );
   mImap.personalNS->setReadOnly( true );
   mImap.editPNS = new QToolButton( listbox );
-  mImap.editPNS->setIconSet( 
+  mImap.editPNS->setIconSet(
       KGlobal::iconLoader()->loadIconSet( "edit", KIcon::Small, 0 ) );
   mImap.editPNS->setAutoRaise( true );
   mImap.editPNS->setSizePolicy( QSizePolicy( QSizePolicy::Fixed, QSizePolicy::Fixed ) );
@@ -907,7 +911,7 @@ void AccountDialog::makeImapAccountPage( bool connected )
   mImap.otherUsersNS = new KLineEdit( listbox );
   mImap.otherUsersNS->setReadOnly( true );
   mImap.editONS = new QToolButton( listbox );
-  mImap.editONS->setIconSet( 
+  mImap.editONS->setIconSet(
       KGlobal::iconLoader()->loadIconSet( "edit", KIcon::Small, 0 ) );
   mImap.editONS->setAutoRaise( true );
   mImap.editONS->setSizePolicy( QSizePolicy( QSizePolicy::Fixed, QSizePolicy::Fixed ) );
@@ -919,7 +923,7 @@ void AccountDialog::makeImapAccountPage( bool connected )
   mImap.sharedNS = new KLineEdit( listbox );
   mImap.sharedNS->setReadOnly( true );
   mImap.editSNS = new QToolButton( listbox );
-  mImap.editSNS->setIconSet( 
+  mImap.editSNS->setIconSet(
       KGlobal::iconLoader()->loadIconSet( "edit", KIcon::Small, 0 ) );
   mImap.editSNS->setAutoRaise( true );
   mImap.editSNS->setSizePolicy( QSizePolicy( QSizePolicy::Fixed, QSizePolicy::Fixed ) );
@@ -961,6 +965,11 @@ void AccountDialog::makeImapAccountPage( bool connected )
     i18n("Show only s&ubscribed folders"), page1);
   grid->addMultiCellWidget( mImap.subscribedFoldersCheck, row, row, 0, 1 );
 
+  ++row;
+  mImap.locallySubscribedFoldersCheck = new QCheckBox(
+    i18n("Show only &locally subscribed folders"), page1);
+  grid->addMultiCellWidget( mImap.locallySubscribedFoldersCheck, row, row, 0, 1 );
+
   if ( !connected ) {
     // not implemented for disconnected yet
     ++row;
@@ -1023,7 +1032,8 @@ void AccountDialog::makeImapAccountPage( bool connected )
   mImap.intervalLabel = new QLabel( i18n("Check inter&val:"), page1 );
   grid->addWidget( mImap.intervalLabel, row, 0 );
   mImap.intervalSpin = new KIntNumInput( page1 );
-  mImap.intervalSpin->setRange( 1, 10000, 1, FALSE );
+  const int kioskMinimumImapCheckInterval = GlobalSettings::minimumImapCheckInterval();
+  mImap.intervalSpin->setRange( kioskMinimumImapCheckInterval, 10000, 1, FALSE );
   mImap.intervalSpin->setValue( 1 );
   mImap.intervalSpin->setSuffix( i18n( " min" ) );
   mImap.intervalLabel->setBuddy( mImap.intervalSpin );
@@ -1218,6 +1228,7 @@ void AccountDialog::setupSettings()
     mImap.autoExpungeCheck->setChecked( ai.autoExpunge() );
     mImap.hiddenFoldersCheck->setChecked( ai.hiddenFolders() );
     mImap.subscribedFoldersCheck->setChecked( ai.onlySubscribedFolders() );
+    mImap.locallySubscribedFoldersCheck->setChecked( ai.onlyLocallySubscribedFolders() );
     mImap.loadOnDemandCheck->setChecked( ai.loadOnDemand() );
     mImap.listOnlyOpenCheck->setChecked( ai.listOnlyOpenFolders() );
     mImap.storePasswordCheck->setChecked( ai.storePasswd() );
@@ -1271,6 +1282,7 @@ void AccountDialog::setupSettings()
 #endif
     mImap.hiddenFoldersCheck->setChecked( ai.hiddenFolders() );
     mImap.subscribedFoldersCheck->setChecked( ai.onlySubscribedFolders() );
+    mImap.locallySubscribedFoldersCheck->setChecked( ai.onlyLocallySubscribedFolders() );
     mImap.storePasswordCheck->setChecked( ai.storePasswd() );
     mImap.intervalCheck->setChecked( interval >= 1 );
     mImap.intervalSpin->setValue( QMAX(1, interval) );
@@ -1682,6 +1694,23 @@ void AccountDialog::slotImapCapabilities( const QStringList & capaNormal,
   mServerTest = 0;
 }
 
+void AccountDialog::slotLeaveOnServerDaysChanged ( int value )
+{
+  mPop.leaveOnServerDaysSpin->setSuffix( i18n(" day", " days", value) );
+}
+
+
+void AccountDialog::slotLeaveOnServerCountChanged ( int value )
+{
+  mPop.leaveOnServerCountSpin->setSuffix( i18n(" message", " messages", value) );
+}
+
+
+void AccountDialog::slotFilterOnServerSizeChanged ( int value )
+{
+  mPop.filterOnServerSizeSpin->setSuffix( i18n(" byte", " bytes", value) );
+}
+
 
 void AccountDialog::enableImapAuthMethods( unsigned int capa )
 {
@@ -1796,6 +1825,7 @@ void AccountDialog::saveSettings()
     epa.setAutoExpunge( mImap.autoExpungeCheck->isChecked() );
     epa.setHiddenFolders( mImap.hiddenFoldersCheck->isChecked() );
     epa.setOnlySubscribedFolders( mImap.subscribedFoldersCheck->isChecked() );
+    epa.setOnlyLocallySubscribedFolders( mImap.locallySubscribedFoldersCheck->isChecked() );
     epa.setLoadOnDemand( mImap.loadOnDemandCheck->isChecked() );
     epa.setListOnlyOpenFolders( mImap.listOnlyOpenCheck->isChecked() );
     KMFolder *t = mImap.trashCombo->folder();
@@ -1827,6 +1857,9 @@ void AccountDialog::saveSettings()
     KMAcctCachedImap &epa = *(KMAcctCachedImap*)mAccount;
     epa.setHiddenFolders( mImap.hiddenFoldersCheck->isChecked() );
     epa.setOnlySubscribedFolders( mImap.subscribedFoldersCheck->isChecked() );
+    epa.setOnlyLocallySubscribedFolders( mImap.locallySubscribedFoldersCheck->isChecked() );
+    epa.setStorePasswd( mImap.storePasswordCheck->isChecked() );
+    epa.setPasswd( mImap.passwordEdit->text(), epa.storePasswd() );
     KMFolder *t = mImap.trashCombo->folder();
     if ( t )
       epa.setTrash( mImap.trashCombo->folder()->idString() );
@@ -1887,7 +1920,7 @@ void AccountDialog::saveSettings()
     }
     ai.setNamespaces( map );
     ai.setNamespaceToDelimiter( delimMap );
-  }  
+  }
 
   kmkernel->acctMgr()->writeConfig(TRUE);
 
@@ -2047,7 +2080,7 @@ void AccountDialog::slotReloadNamespaces()
     connect( ai, SIGNAL( namespacesFetched( const ImapAccountBase::nsDelimMap& ) ),
         this, SLOT( slotSetupNamespaces( const ImapAccountBase::nsDelimMap& ) ) );
     connect( ai, SIGNAL( connectionResult(int, const QString&) ),
-          this, SLOT( slotConnectionResult(int, const QString&) ) );    
+          this, SLOT( slotConnectionResult(int, const QString&) ) );
     ai->getNamespaces();
   }
 }
@@ -2059,7 +2092,7 @@ void AccountDialog::slotConnectionResult( int errorCode, const QString& )
     disconnect( ai, SIGNAL( namespacesFetched( const ImapAccountBase::nsDelimMap& ) ),
         this, SLOT( slotSetupNamespaces( const ImapAccountBase::nsDelimMap& ) ) );
     disconnect( ai, SIGNAL( connectionResult(int, const QString&) ),
-          this, SLOT( slotConnectionResult(int, const QString&) ) );    
+          this, SLOT( slotConnectionResult(int, const QString&) ) );
     mImap.personalNS->setText( QString::null );
   }
 }
@@ -2139,8 +2172,8 @@ void AccountDialog::initAccountForConnect()
       na.setAuth("GSSAPI");
     else if (mPop.authAPOP->isChecked())
       na.setAuth("APOP");
-    else na.setAuth("AUTO");    
-  } 
+    else na.setAuth("AUTO");
+  }
   else if ( type == "imap" || type == "cachedimap" ) {
     na.setHost( mImap.hostEdit->text().stripWhiteSpace() );
     na.setPort( mImap.portEdit->text().toInt() );
@@ -2163,7 +2196,7 @@ void AccountDialog::initAccountForConnect()
       na.setAuth("LOGIN");
     else if (mImap.authPlain->isChecked())
       na.setAuth("PLAIN");
-    else na.setAuth("*");    
+    else na.setAuth("*");
   }
 }
 
@@ -2202,7 +2235,7 @@ void NamespaceLineEdit::setText( const QString& text )
   KLineEdit::setText( text );
 }
 
-NamespaceEditDialog::NamespaceEditDialog( QWidget *parent, 
+NamespaceEditDialog::NamespaceEditDialog( QWidget *parent,
     ImapAccountBase::imapNamespace type, ImapAccountBase::nsDelimMap* map )
   : KDialogBase( parent, "edit_namespace", false, QString::null,
       Ok|Cancel, Ok, true ), mType( type ), mNamespaceMap( map )
@@ -2228,7 +2261,7 @@ NamespaceEditDialog::NamespaceEditDialog( QWidget *parent,
     NamespaceLineEdit* edit = new NamespaceLineEdit( grid );
     edit->setText( it.key() );
     QToolButton* button = new QToolButton( grid );
-    button->setIconSet( 
+    button->setIconSet(
       KGlobal::iconLoader()->loadIconSet( "editdelete", KIcon::Small, 0 ) );
     button->setAutoRaise( true );
     button->setSizePolicy( QSizePolicy( QSizePolicy::Fixed, QSizePolicy::Fixed ) );
