@@ -122,7 +122,7 @@ ActionScheduler::~ActionScheduler()
 {
   schedulerList->remove( this );
   tempCloseFolders();
-  mSrcFolder->close();
+  mSrcFolder->close("actionschedsrc");
 
   if (mDeleteSrcFolder)
     tempFolderMgr->remove(mSrcFolder);
@@ -151,11 +151,11 @@ void ActionScheduler::setDefaultDestinationFolder( KMFolder *destFolder )
 
 void ActionScheduler::setSourceFolder( KMFolder *srcFolder )
 {
-  srcFolder->open();
+  srcFolder->open("actionschedsrc");
   if (mSrcFolder) {
     disconnect( mSrcFolder, SIGNAL(msgAdded(KMFolder*, Q_UINT32)),
 		this, SLOT(msgAdded(KMFolder*, Q_UINT32)) );
-    mSrcFolder->close();
+    mSrcFolder->close("actionschedsrc");
   }
   mSrcFolder = srcFolder;
   int i = 0;
@@ -170,7 +170,7 @@ void ActionScheduler::setFilterList( QValueList<KMFilter*> filters )
 {
   mFiltersAreQueued = true;
   mQueuedFilters.clear();
-  
+
   QValueList<KMFilter*>::Iterator it = filters.begin();
   for (; it != filters.end(); ++it)
     mQueuedFilters.append( **it );
@@ -188,7 +188,7 @@ int ActionScheduler::tempOpenFolder( KMFolder* aFolder )
   if ( aFolder == mSrcFolder.operator->() )
     return 0;
 
-  int rc = aFolder->open();
+  int rc = aFolder->open("actionsched");
   if (rc)
     return rc;
 
@@ -203,7 +203,7 @@ void ActionScheduler::tempCloseFolders()
   for (it = mOpenFolders.begin(); it != mOpenFolders.end(); ++it) {
     KMFolder *folder = *it;
     if (folder)
-      folder->close();
+      folder->close("actionsched");
   }
   mOpenFolders.clear();
 }
@@ -231,7 +231,7 @@ void ActionScheduler::execFilters(KMMsgBase* msgBase)
 void ActionScheduler::execFilters(Q_UINT32 serNum)
 {
   if (mResult != ResultOk) {
-      if ((mResult != ResultCriticalError) && 
+      if ((mResult != ResultCriticalError) &&
 	  !mExecuting && !mExecutingLock && !mFetchExecuting) {
 	  mResult = ResultOk; // Recoverable error
 	  if (!mFetchSerNums.isEmpty()) {
@@ -420,10 +420,10 @@ void ActionScheduler::messageFetched( KMMessage *msg )
       fetchMessageTimer->start( 0, true );
       return;
   }
-	
+
   mFetchSerNums.remove( msg->getMsgSerNum() );
 
-  // Note: This may not be necessary. What about when it's time to 
+  // Note: This may not be necessary. What about when it's time to
   //       delete the original message?
   //       Is the new serial number being set correctly then?
   if ((mSet & KMFilterMgr::Explicit) ||
@@ -500,7 +500,7 @@ void ActionScheduler::processMessage()
 
   //If we got this far then there's a valid message to work with
   KMMsgBase *msgBase = messageBase( *mMessageIt );
-  if (mResult != ResultOk) {
+  if (!msgBase || mResult != ResultOk) {
     mExecuting = false;
     return;
   }
@@ -580,7 +580,7 @@ void ActionScheduler::filterMessage()
     if (mAlwaysMatch ||
 	(*mFilterIt).pattern()->matches( *mMessageIt )) {
       if ( FilterLog::instance()->isLogging() ) {
-        FilterLog::instance()->add( i18n( "<b>Filter rules have matched.</b>" ), 
+        FilterLog::instance()->add( i18n( "<b>Filter rules have matched.</b>" ),
                                     FilterLog::patternResult );
       }
       mFilterAction = (*mFilterIt).actions()->first();
@@ -694,7 +694,7 @@ void ActionScheduler::moveMessageFinished( KMCommand *command )
     msg = message( mOriginalSerNum );
     emit filtered( mOriginalSerNum );
   }
-  
+
   mResult = mOldReturnCode; // ignore errors in deleting original message
   KMCommand *cmd = 0;
   if (msg && msg->parent()) {
@@ -710,7 +710,7 @@ void ActionScheduler::moveMessageFinished( KMCommand *command )
     else
 	processMessageTimer->start( 0, true );
   } else {
-    // Note: An alternative to consider is just calling 
+    // Note: An alternative to consider is just calling
     //       finishTimer->start and returning
     if (cmd)
 	connect( cmd, SIGNAL( completed( KMCommand * ) ),
@@ -727,7 +727,7 @@ void ActionScheduler::copyMessageFinished( KMCommand *command )
 {
   if ( command->result() != KMCommand::OK )
     actionMessage( KMFilterAction::ErrorButGoOn );
-  else 
+  else
     actionMessage();
 }
 
@@ -786,7 +786,7 @@ QString ActionScheduler::debug()
 	    res.append( QString( "ResultCriticalError.\n" ) );
 	else
 	    res.append( QString( "Unknown.\n" ) );
-	    
+
 	++i;
     }
     return res;
