@@ -9,7 +9,7 @@
     version 2.0, as published by the Free Software Foundation.
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software Foundation,
-    Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, US
+    Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, US
 */
 
 #ifdef HAVE_CONFIG_H
@@ -19,12 +19,12 @@
 // my header file
 #include "attachmentlistview.h"
 
-// other KMail headers 
+// other KMail headers
 #include "kmmsgbase.h"
 #include "kmfolder.h"
 #include "kmcommands.h"
 #include "kmmsgdict.h"
-#include "kmcomposewin.h"
+#include "composer.h"
 
 // other module headers
 #include <maillistdrag.h>
@@ -46,7 +46,7 @@ using KPIM::MailListDrag;
 
 namespace KMail {
 
-AttachmentListView::AttachmentListView( KMComposeWin* composer,
+AttachmentListView::AttachmentListView( KMail::Composer * composer,
                                         QWidget* parent,
                                         const char* name )
   : KListView( parent, name ),
@@ -92,14 +92,14 @@ void AttachmentListView::contentsDropEvent( QDropEvent* e )
     QBuffer serNumBuffer( serNums );
     serNumBuffer.open( IO_ReadOnly );
     QDataStream serNumStream( &serNumBuffer );
-    unsigned long serNum;
+    Q_UINT32 serNum;
     KMFolder *folder = 0;
     int idx;
     QPtrList<KMMsgBase> messageList;
     while( !serNumStream.atEnd() ) {
       KMMsgBase *msgBase = 0;
       serNumStream >> serNum;
-      kmkernel->msgDict()->getLocation( serNum, &folder, &idx );
+      KMMsgDict::instance()->getLocation( serNum, &folder, &idx );
       if( folder )
         msgBase = folder->getMsgBase( idx );
       if( msgBase )
