@@ -84,6 +84,8 @@ FolderStorage::FolderStorage( KMFolder* folder, const char* aName )
 
   mHasChildren = HasNoChildren;
   mContentsType = KMail::ContentsTypeMail;
+ 
+  connect(this, SIGNAL(closed(KMFolder*)), mFolder, SIGNAL(closed()));  
 }
 
 //-----------------------------------------------------------------------------
@@ -584,14 +586,14 @@ int FolderStorage::moveMsg(KMMessage* aMsg, int* aIndex_ret)
   KMFolder* msgParent = aMsg->parent();
 
   if (msgParent)
-    msgParent->open();
+    msgParent->open("moveMsgSrc");
 
-  open();
+  open("moveMsgDest");
   int rc = addMsg(aMsg, aIndex_ret);
-  close();
+  close("moveMsgDest");
 
   if (msgParent)
-    msgParent->close();
+    msgParent->close("moveMsgSrc");
 
   return rc;
 }
@@ -604,18 +606,18 @@ int FolderStorage::moveMsg(QPtrList<KMMessage> msglist, int* aIndex_ret)
   KMFolder* msgParent = aMsg->parent();
 
   if (msgParent)
-    msgParent->open();
+    msgParent->open("foldermovemsg");
 
   QValueList<int> index;
-  open();
+  open("moveMsg");
   int rc = addMsg(msglist, index);
-  close();
+  close("moveMsg");
   // FIXME: we want to have a QValueList to pass it back, so change this method
   if ( !index.isEmpty() )
     aIndex_ret = &index.first();
 
   if (msgParent)
-    msgParent->close();
+    msgParent->close("foldermovemsg");
 
   return rc;
 }
@@ -627,7 +629,7 @@ int FolderStorage::rename(const QString& newName, KMFolderDir *newParent)
   QString oldLoc, oldIndexLoc, oldIdsLoc, newLoc, newIndexLoc, newIdsLoc;
   QString oldSubDirLoc, newSubDirLoc;
   QString oldName;
-  int rc=0, openCount=mOpenCount;
+  int rc=0;
   KMFolderDir *oldParent;
 
   assert(!newName.isEmpty());
@@ -638,7 +640,7 @@ int FolderStorage::rename(const QString& newName, KMFolderDir *newParent)
   oldIdsLoc =  KMMsgDict::instance()->getFolderIdsLocation( *this );
   QString oldConfigString = "Folder-" + folder()->idString();
 
-  close(true);
+  close("rename", true);
 
   oldName = folder()->fileName();
   oldParent = folder()->parent();
@@ -697,11 +699,6 @@ int FolderStorage::rename(const QString& newName, KMFolderDir *newParent)
     }
   }
 
-  if (openCount > 0)
-  {
-    open();
-    mOpenCount = openCount;
-  }
   writeConfig();
 
   // delete the old entry as we get two entries with the same ID otherwise
@@ -711,6 +708,7 @@ int FolderStorage::rename(const QString& newName, KMFolderDir *newParent)
   emit locationChanged( oldLoc, newLoc );
   emit nameChanged();
   kmkernel->folderMgr()->contentsChanged();
+  emit closed(folder()); // let the ticket owners regain
   return rc;
 }
 
@@ -721,10 +719,12 @@ void FolderStorage::remove()
   assert(!folder()->name().isEmpty());
 
   clearIndex( true, mExportsSernums ); // delete and remove from dict if necessary
-  close(true);
+  close("remove", true);
 
-  if ( mExportsSernums )
+  if ( mExportsSernums ) {
     KMMsgDict::mutableInstance()->removeFolderIds( *this );
+    mExportsSernums = false;	// do not writeFolderIds after removal
+  }
   unlink(QFile::encodeName(indexLocation()) + ".sorted");
   unlink(QFile::encodeName(indexLocation()));
 
@@ -736,6 +736,7 @@ void FolderStorage::remove()
   KConfig* config = KMKernel::config();
   config->deleteGroup( "Folder-" + folder()->idString() );
 
+  emit closed(folder());
   emit removed(folder(), (rc ? false : true));
 }
 
@@ -743,12 +744,10 @@ void FolderStorage::remove()
 //-----------------------------------------------------------------------------
 int FolderStorage::expunge()
 {
-  int openCount = mOpenCount;
-
   assert(!folder()->name().isEmpty());
 
   clearIndex( true, mExportsSernums );   // delete and remove from dict, if needed
-  close( true );
+  close( "expunge", true );
 
   if ( mExportsSernums )
     KMMsgDict::mutableInstance()->removeFolderIds( *this );
@@ -762,12 +761,6 @@ int FolderStorage::expunge()
   mDirty = false;
   needsCompact = false; //we're cleared and truncated no need to compact
 
-  if (openCount > 0)
-  {
-    open();
-    mOpenCount = openCount;
-  }
-
   mUnreadMsgs = 0;
   mTotalMsgs = 0;
   emit numUnreadMsgsChanged( folder() );
@@ -806,9 +799,9 @@ int FolderStorage::countUnread()
   if (mUnreadMsgs > -1)
     return mUnreadMsgs;
 
-  open(); // will update unreadMsgs
+  open("countunread"); // will update unreadMsgs
   int unread = mUnreadMsgs;
-  close();
+  close("countunread");
   return (unread > 0) ? unread : 0;
 }
 
@@ -905,8 +898,8 @@ void FolderStorage::writeConfig()
 //-----------------------------------------------------------------------------
 void FolderStorage::correctUnreadMsgsCount()
 {
-  open();
-  close();
+  open("countunreadmsg");
+  close("countunreadmsg");
   emit numUnreadMsgsChanged( folder() );
 }
 
@@ -1062,11 +1055,12 @@ void FolderStorage::setNoChildren( bool aNoChildren )
 }
 
 //-----------------------------------------------------------------------------
-void FolderStorage::setContentsType( KMail::FolderContentsType type )
+void FolderStorage::setContentsType( KMail::FolderContentsType type, bool quiet )
 {
   if ( type != mContentsType ) {
     mContentsType = type;
-    emit contentsTypeChanged( type );
+    if ( !quiet )
+       emit contentsTypeChanged( type );
   }
 }
 
