@@ -24,6 +24,8 @@
 #ifndef __KMAIL_IMAPACCOUNTBASE_H__
 #define __KMAIL_IMAPACCOUNTBASE_H__
 
+#include <set>
+
 #include "networkaccount.h"
 
 #include <qtimer.h>
@@ -49,6 +51,7 @@ namespace KPIM {
 
 namespace KMail {
   struct ACLListEntry;
+  struct QuotaInfo;
   typedef QValueVector<KMail::ACLListEntry> ACLList;
 
   class AttachmentStrategy;
@@ -79,6 +82,11 @@ namespace KMail {
     bool onlySubscribedFolders() const { return mOnlySubscribedFolders; }
     virtual void setOnlySubscribedFolders( bool show );
 
+    /** @return whether to show only locally subscribed folders */
+    bool onlyLocallySubscribedFolders() const { return mOnlyLocallySubscribedFolders; }
+    virtual void setOnlyLocallySubscribedFolders( bool show );
+
+
     /** @return whether to load attachments on demand */
     bool loadOnDemand() const { return mLoadOnDemand; }
     virtual void setLoadOnDemand( bool load );
@@ -185,6 +193,19 @@ namespace KMail {
      */
     void changeSubscription(bool subscribe, const QString& imapPath);
 
+    /** 
+     * Returns whether the account is locally subscribed to the
+     * folder @param imapPath. No relation to server side subscription above.
+     */
+    bool locallySubscribedTo( const QString& imapPath );
+
+    /**
+     * Locally subscribe (@p subscribe = TRUE) / Unsubscribe the folder
+     * identified by @p imapPath.
+     */
+    void changeLocalSubscription( const QString& imapPath, bool subscribe );
+
+
     /**
      * Retrieve the users' right on the folder
      * identified by @p folder and @p imapPath.
@@ -199,6 +220,13 @@ namespace KMail {
      */
     void getACL( KMFolder* folder, const QString& imapPath );
 
+    /**
+     * Retrieve the the quota inforamiton on the folder
+     * identified by @p imapPath.
+     * Emits receivedQuotaInfo signal on success/error.
+     */
+    void getStorageQuotaInfo( KMFolder* folder, const QString& imapPath );
+
     /**
      * Set the status on the server
      * Emits imapStatusChanged signal on success/error.
@@ -272,6 +300,17 @@ namespace KMail {
      */
     void setHasNoAnnotationSupport() { mAnnotationSupport = false; }
 
+    /**
+     * Returns false if the IMAP server for this account doesn't support quotas.
+     * (and true if it does, or if we didn't try yet).
+     */
+    bool hasQuotaSupport() const { return mQuotaSupport; }
+
+    /**
+     * Called if the quota command failed due to 'unsupported'
+     */
+    void setHasNoQuotaSupport() { mQuotaSupport = false; }
+
     /**
      * React to an error from the job. Uses job->error and job->errorString and calls
      * the protected virtual handleJobError with them. See handleError below for details.
@@ -400,6 +439,9 @@ namespace KMail {
     /// Result of getACL() job
     void slotGetACLResult( KIO::Job* _job );
 
+    /// Result of getStorageQuotaInfo() job
+    void slotGetStorageQuotaInfoResult( KIO::Job* _job );
+
     /**
      * Send a NOOP command regularly to keep the slave from disconnecting
      */
@@ -467,6 +509,9 @@ namespace KMail {
     /** Migrate the prefix */
     void migratePrefix();
 
+    // used for writing the blacklist out to the config file
+    QStringList locallyBlacklistedFolders() const;
+    void localBlacklistFromStringList( const QStringList & );
 
   protected:
     QPtrList<QGuardedPtr<KMFolder> > mOpenFolders;
@@ -482,6 +527,7 @@ namespace KMail {
     bool mAutoExpunge : 1;
     bool mHiddenFolders : 1;
     bool mOnlySubscribedFolders : 1;
+    bool mOnlyLocallySubscribedFolders : 1;
     bool mLoadOnDemand : 1;
     bool mListOnlyOpenFolders : 1;
     bool mProgressEnabled : 1;
@@ -490,6 +536,7 @@ namespace KMail {
     bool mPasswordDialogIsActive : 1;
     bool mACLSupport : 1;
     bool mAnnotationSupport : 1;
+    bool mQuotaSupport : 1;
     bool mSlaveConnected : 1;
     bool mSlaveConnectionError : 1;
     bool mCheckingSingleFolder : 1;
@@ -517,6 +564,8 @@ namespace KMail {
     // capabilities
     QStringList mCapabilities;
 
+    std::set<QString> mLocalSubscriptionBlackList;
+
   signals:
     /**
      * Emitted when the slave managed or failed to connect
@@ -555,6 +604,16 @@ namespace KMail {
      */
     void receivedACL( KMFolder* folder, KIO::Job* job, const KMail::ACLList& entries );
 
+    /**
+     * Emitted when the getQuotaInfo job is done,
+     * as a result of a getQuotaInfo call.
+     * @param folder The folder for which we were getting quota info (can be 0)
+     * @param job The job that was used for doing so (can be used to display errors)
+     * @param info The quota information for this folder. Make your copy of it,
+     * it comes from the job.
+     */
+    void receivedStorageQuotaInfo( KMFolder* folder, KIO::Job* job, const KMail::QuotaInfo& entries );
+
     /**
      * Emitted when we got the namespaces
      */
