@@ -84,12 +84,12 @@ void ImapJob::init( JobType jt, QString sets, KMFolderImap* folder,
   mDestFolder = folder? folder->folder() : 0;
   // refcount++
   if (folder) {
-    folder->open();
+    folder->open("imapjobdest");
   }
   KMFolder *msg_parent = msg->parent();
   if (msg_parent) {
     if (!folder || folder!= msg_parent->storage()) {
-      msg_parent->open();
+      msg_parent->open("imapjobsrc");
     }
   }
   mSrcFolder = msg_parent;
@@ -241,7 +241,7 @@ ImapJob::~ImapJob()
       }
       account->mJobList.remove( this );
     }
-    mDestFolder->close();
+    mDestFolder->close("imapjobdest");
   }
 
   if ( mSrcFolder ) {
@@ -266,7 +266,7 @@ ImapJob::~ImapJob()
         account->mJobList.remove( this ); // remove the folderjob
       }
     }
-    mSrcFolder->close();
+    mSrcFolder->close("imapjobsrc");
   }
 }
 
@@ -502,6 +502,12 @@ void ImapJob::slotGetBodyStructureResult( KIO::Job * job )
 void ImapJob::slotPutMessageDataReq( KIO::Job *job, QByteArray &data )
 {
   KMAcctImap *account = static_cast<KMFolderImap*>(mDestFolder->storage())->account();
+  if ( !account )
+  {
+    emit finished();
+    deleteLater();
+    return;
+  }
   ImapAccountBase::JobIterator it = account->findJob( job );
   if ( it == account->jobsEnd() ) return;
 
@@ -522,6 +528,12 @@ void ImapJob::slotPutMessageDataReq( KIO::Job *job, QByteArray &data )
 void ImapJob::slotPutMessageResult( KIO::Job *job )
 {
   KMAcctImap *account = static_cast<KMFolderImap*>(mDestFolder->storage())->account();
+  if ( !account )
+  {
+    emit finished();
+    deleteLater();
+    return;
+  }
   ImapAccountBase::JobIterator it = account->findJob( job );
   if ( it == account->jobsEnd() ) return;
   bool deleteMe = false;
@@ -562,6 +574,12 @@ void ImapJob::slotCopyMessageInfoData(KIO::Job * job, const QString & data)
 {
   KMFolderImap * imapFolder = static_cast<KMFolderImap*>(mDestFolder->storage());
   KMAcctImap *account = imapFolder->account();
+  if ( !account )
+  {
+    emit finished();
+    deleteLater();
+    return;
+  }
   ImapAccountBase::JobIterator it = account->findJob( job );
   if ( it == account->jobsEnd() ) return;
 
@@ -595,6 +613,12 @@ void ImapJob::slotPutMessageInfoData(KIO::Job *job, const QString &data)
 {
   KMFolderImap * imapFolder = static_cast<KMFolderImap*>(mDestFolder->storage());
   KMAcctImap *account = imapFolder->account();
+  if ( !account )
+  {
+    emit finished();
+    deleteLater();
+    return;
+  }
   ImapAccountBase::JobIterator it = account->findJob( job );
   if ( it == account->jobsEnd() ) return;
 
@@ -613,6 +637,12 @@ void ImapJob::slotPutMessageInfoData(KIO::Job *job, const QString &data)
 void ImapJob::slotCopyMessageResult( KIO::Job *job )
 {
   KMAcctImap *account = static_cast<KMFolderImap*>(mDestFolder->storage())->account();
+  if ( !account )
+  {
+    emit finished();
+    deleteLater();
+    return;
+  }
   ImapAccountBase::JobIterator it = account->findJob( job );
   if ( it == account->jobsEnd() ) return;
 
