@@ -151,6 +151,11 @@ void KMAccount::readConfig(KConfig& config)
   {
     setFolder(kmkernel->folderMgr()->findIdString(folderName), true);
   }
+
+  if (mInterval == 0)
+    deinstallTimer();
+  else
+    installTimer();
 }
 
 
@@ -278,15 +283,10 @@ if( fileD0.open( IO_WriteOnly ) ) {
 void KMAccount::setCheckInterval(int aInterval)
 {
   if (aInterval <= 0)
-  {
     mInterval = 0;
-    deinstallTimer();
-  }
   else
-  {
     mInterval = aInterval;
-    installTimer();
-  }
+  // Don't call installTimer from here! See #117935.
 }
 
 //----------------------------------------------------------------------------
@@ -399,7 +399,9 @@ QString KMAccount::encryptStr(const QString &aStr)
 {
   QString result;
   for (uint i = 0; i < aStr.length(); i++)
-    result += (aStr[i].unicode() < 0x20) ? aStr[i] :
+    /* yes, no typo. can't encode ' ' or '!' because
+       they're the unicode BOM. stupid scrambling. stupid. */
+    result += (aStr[i].unicode() <= 0x21 ) ? aStr[i] :
       QChar(0x1001F - aStr[i].unicode());
   return result;
 }
