@@ -15,8 +15,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 
     In addition, as a special exception, the copyright holders give
     permission to link the code of this program with any edition of
@@ -107,6 +107,11 @@ k_dcop:
    */
   virtual QValueList<KMailICalIface::SubResource> subresourcesKolab( const QString& contentsType ) = 0;
 
+  /**
+   * Causes all resource folders of the given type to be synced with the server.
+   */
+  virtual bool triggerSync( const QString & ) = 0;
+
 k_dcop_signals:
   void incidenceAdded( const QString& type, const QString& folder,
                        Q_UINT32 sernum, int format, const QString& entry );
