@@ -70,6 +70,8 @@ using KMail::AccountManager;
 #include <kurl.h>
 #include <ktempfile.h>
 
+using namespace KMail;
+
 // Local helper methods
 static void vPartMicroParser( const QString& str, QString& s );
 static void reloadFolderTree();
@@ -480,9 +482,9 @@ int KMailICalIfaceImpl::incidencesKolabCount( const QString& mimetype,
     return 0;
   }
 
-  f->open();
+  f->open("kolabcount");
   int n = f->count();
-  f->close();
+  f->close("kolabcount");
   kdDebug(5006) << "KMailICalIfaceImpl::incidencesKolabCount( " << mimetype << ", "
                 << resource << " ) returned " << n << endl;
   return n;
@@ -507,7 +509,7 @@ QMap<Q_UINT32, QString> KMailICalIfaceImpl::incidencesKolab( const QString& mime
     return aMap;
   }
 
-  f->open();
+  f->open("incidences");
 
   int stopIndex = nbMessages == -1 ? f->count() :
                   QMIN( f->count(), startIndex + nbMessages );
@@ -553,6 +555,7 @@ QMap<Q_UINT32, QString> KMailICalIfaceImpl::incidencesKolab( const QString& mime
 #endif
     }
   }
+  f->close( "incidences" );
   return aMap;
 }
 
@@ -634,7 +637,7 @@ bool KMailICalIfaceImpl::triggerSync( const QString& contentsType )
   kdDebug(5006) << k_funcinfo << endl;
   QValueList<KMailICalIfaceImpl::SubResource> folderList = subresourcesKolab( contentsType );
   for ( QValueList<KMailICalIfaceImpl::SubResource>::const_iterator it( folderList.begin() ),
-                                                                    end( folderList.end() ); 
+                                                                    end( folderList.end() );
         it != end ; ++it ) {
     KMFolder * const f = findResourceFolder( (*it).location );
     if ( !f ) continue;
@@ -723,7 +726,7 @@ Q_UINT32 KMailICalIfaceImpl::update( const QString& resource,
     return rc;
   }
 
-  f->open();
+  f->open("ifaceupdate");
 
   KMMessage* msg = 0;
   if ( sernum != 0 ) {
@@ -751,7 +754,7 @@ Q_UINT32 KMailICalIfaceImpl::update( const QString& resource,
     const KMail::FolderContentsType t = f->storage()->contentsType();
     const QCString type = msg->typeStr();
     const QCString subtype = msg->subtypeStr();
-    const bool messageWasIcalVcardFormat = ( type.lower() == "text" && 
+    const bool messageWasIcalVcardFormat = ( type.lower() == "text" &&
         ( subtype.lower() == "calendar" || subtype.lower() == "x-vcard" ) );
 
     if ( storageFormat( f ) == StorageIcalVcard ) {
@@ -806,7 +809,7 @@ Q_UINT32 KMailICalIfaceImpl::update( const QString& resource,
                             attachmentMimetypes );
   }
 
-  f->close();
+  f->close("ifaceupdate");
   return rc;
 }
 
@@ -1079,6 +1082,16 @@ bool KMailICalIfaceImpl::hideResourceFolder( KMFolder* folder ) const
   return mHideFolders && isResourceFolder( folder );
 }
 
+bool KMailICalIfaceImpl::hideResourceAccountRoot( KMFolder* folder ) const
+{
+  KMFolderCachedImap *dimapFolder = dynamic_cast<KMFolderCachedImap*>( folder->storage() );
+  bool hide = dimapFolder && mHideFolders 
+       && (int)dimapFolder->account()->id() == GlobalSettings::self()->theIMAPResourceAccount()
+       && GlobalSettings::self()->showOnlyGroupwareFoldersForGroupwareAccount();
+  return hide;
+
+}
+
 KFolderTreeItem::Type KMailICalIfaceImpl::folderType( KMFolder* folder ) const
 {
   if( mUseResourceIMAP && folder ) {
@@ -1691,7 +1704,7 @@ KMFolder* KMailICalIfaceImpl::initFolder( KMail::FolderContentsType contentsType
   folder->storage()->setContentsType( contentsType );
   folder->setSystemFolder( true );
   folder->storage()->writeConfig();
-  folder->open();
+  folder->open("ifacefolder");
   connectFolder( folder );
   return folder;
 }
@@ -1733,7 +1746,7 @@ static void cleanupFolder( KMFolder* folder, KMailICalIfaceImpl* _this )
   if( folder ) {
     folder->setSystemFolder( false );
     folder->disconnect( _this );
-    folder->close();
+    folder->close("ifacefolder");
   }
 }
 
