@@ -22,6 +22,7 @@
 #include <libkdepim/kfileio.h>
 #include <libkdepim/collectingprocess.h>
 using KPIM::CollectingProcess;
+#include <mimelib/message.h>
 #include "kmfawidgets.h"
 #include "folderrequester.h"
 using KMail::FolderRequester;
@@ -114,11 +115,29 @@ int KMFilterAction::tempOpenFolder(KMFolder* aFolder)
 void KMFilterAction::sendMDN( KMMessage * msg, KMime::MDN::DispositionType d,
                               const QValueList<KMime::MDN::DispositionModifier> & m ) {
   if ( !msg ) return;
+
+  /* createMDN requires Return-Path and Disposition-Notification-To
+   * if it is not set in the message we assume that the notification should go to the
+   * sender
+   */
+  const QString returnPath = msg->headerField( "Return-Path" );
+  const QString dispNoteTo = msg->headerField( "Disposition-Notification-To" );
+  if ( returnPath.isEmpty() )
+    msg->setHeaderField( "Return-Path", msg->from() );
+  if ( dispNoteTo.isEmpty() )
+    msg->setHeaderField( "Disposition-Notification-To", msg->from() );
+
   KMMessage * mdn = msg->createMDN( KMime::MDN::AutomaticAction, d, false, m );
   if ( mdn && !kmkernel->msgSender()->send( mdn, KMail::MessageSender::SendLater ) ) {
     kdDebug(5006) << "KMFilterAction::sendMDN(): sending failed." << endl;
     //delete mdn;
   }
+
+  //restore orignial header
+  if ( returnPath.isEmpty() )
+    msg->removeHeaderField( "Return-Path" );
+  if ( dispNoteTo.isEmpty() )
+    msg->removeHeaderField( "Disposition-Notification-To" );
 }
 
 
@@ -1377,18 +1396,18 @@ KMFilterAction::ReturnCode KMFilterActionCopy::process(KMMessage* msg) const
   // TODO opening and closing the folder is a trade off.
   // Perhaps Copy is a seldomly used action for now,
   // but I gonna look at improvements ASAP.
-  if ( !mFolder && mFolder->open() != 0 )
+  if ( !mFolder || mFolder->open( "filtercopy" ) != 0 ) {
     return ErrorButGoOn;
+  }
 
   // copy the message 1:1
-  KMMessage* msgCopy = new KMMessage;
-  msgCopy->fromDwString(msg->asDwString());
+  KMMessage* msgCopy = new KMMessage( new DwMessage( *msg->asDwMessage() ) );
 
   int index;
   int rc = mFolder->addMsg(msgCopy, &index);
   if (rc == 0 && index != -1)
     mFolder->unGetMsg( index );
-  mFolder->close();
+  mFolder->close("filtercopy");
 
   return GoOn;
 }
@@ -1454,11 +1473,11 @@ KMFilterAction::ReturnCode KMFilterActionForward::process(KMMessage* aMsg) const
   msg->initFromMessage( aMsg );
 
   // QString st = QString::fromUtf8( aMsg->createForwardBody() );
-  
-  TemplateParser parser( msg, TemplateParser::Forward, 
+
+  TemplateParser parser( msg, TemplateParser::Forward,
     aMsg->body(), false, false, false, false);
   parser.process( aMsg );
-  
+
   QCString
     encoding = KMMsgBase::autoDetectCharset( aMsg->charset(),
                                              KMMessage::preferredCharsets(),
