@@ -51,6 +51,7 @@ KMFolder::KMFolder( KMFolderDir* aParent, const QString& aFolderName,
     mIsSystemFolder( false ),
     mHasIndex( withIndex ),
     mExportsSernums( exportedSernums ),
+    mMoveInProgress( false ),
     mExpireMessages( false ), mUnreadExpireAge( 28 ),
     mReadExpireAge( 14 ), mUnreadExpireUnits( expireNever ),
     mReadExpireUnits( expireNever ),
@@ -320,11 +321,6 @@ bool KMFolder::isMessage( int idx )
   return mStorage->isMessage( idx );
 }
 
-QCString& KMFolder::getMsgString( int idx, QCString& mDest )
-{
-  return mStorage->getMsgString( idx,  mDest );
-}
-
 DwString KMFolder::getDwString( int idx )
 {
   return mStorage->getDwString( idx );
@@ -374,7 +370,7 @@ KMMessage* KMFolder::take( int idx )
   return mStorage->take( idx );
 }
 
-void KMFolder::take( QPtrList<KMMessage> msgList )
+void KMFolder::take( QPtrList<KMMessage> msgList ) // TODO const ref
 {
   mStorage->take( msgList );
 }
@@ -404,7 +400,7 @@ void KMFolder::removeMsg( int i, bool imapQuiet )
   mStorage->removeMsg( i, imapQuiet );
 }
 
-void KMFolder::removeMsg( QPtrList<KMMessage> msgList, bool imapQuiet )
+void KMFolder::removeMsg( QPtrList<KMMessage> msgList, bool imapQuiet ) // TODO const ref
 {
   mStorage->removeMsg( msgList, imapQuiet );
 }
@@ -426,12 +422,12 @@ int KMFolder::moveMsg(QPtrList<KMMessage> q, int* index_return )
 
 int KMFolder::find( const KMMsgBase* msg ) const
 {
-  return mStorage->find( msg );
+  return mStorage ? mStorage->find( msg ) : 0;
 }
 
 int KMFolder::find( const KMMessage* msg ) const
 {
-  return mStorage->find( msg );
+  return mStorage ? mStorage->find( msg ) : 0;
 }
 
 int KMFolder::count( bool cache ) const
@@ -468,9 +464,9 @@ void KMFolder::msgStatusChanged( const KMMsgStatus oldStatus,
   mStorage->msgStatusChanged( oldStatus, newStatus, idx );
 }
 
-int KMFolder::open()
+int KMFolder::open(const char *owner)
 {
-  return mStorage->open();
+  return mStorage->open(owner);
 }
 
 int KMFolder::canAccess()
@@ -478,9 +474,10 @@ int KMFolder::canAccess()
   return mStorage->canAccess();
 }
 
-void KMFolder::close( bool force )
+void KMFolder::close( const char *owner, bool force )
 {
-  mStorage->close( force );
+  // do not emit closed() in here - as this would regain too early
+  mStorage->close( owner, force );
 }
 
 void KMFolder::sync()
@@ -631,11 +628,13 @@ void KMFolder::setUserWhoField( const QString& whoField, bool writeConfig )
         mWhoField = "From";
       if ( this == kmkernel->outboxFolder() ||
            this == kmkernel->sentFolder() ||
-           this == kmkernel->draftsFolder() )
+           this == kmkernel->draftsFolder() ||
+           this == kmkernel->templatesFolder() )
         mWhoField = "To";
-    } else if ( identity.drafts() == idString()
-                || identity.fcc() == idString() )
-      // drafts or sent of the identity
+    } else if ( identity.drafts() == idString() ||
+                identity.templates() == idString() ||
+                identity.fcc() == idString() )
+      // drafts, templates or sent of the identity
       mWhoField = "To";
     else
       mWhoField = "From";
@@ -836,7 +835,7 @@ void KMFolder::setShortcut( const KShortcut &sc )
 
 bool KMFolder::isMoveable() const
 {
-  return mStorage->isMoveable();
+  return !isSystemFolder();
 }
 
 void KMFolder::slotContentsTypeChanged( KMail::FolderContentsType type )
