@@ -45,10 +45,15 @@
 #include "kmfoldertype.h"
 #include "folderjob.h"
 #include "cachedimapjob.h"
+#include "quotajobs.h"
 
 using KMail::FolderJob;
+using KMail::QuotaInfo;
 class KMAcctCachedImap;
 
+class QComboBox;
+class QRadioButton;
+
 namespace KMail {
   class AttachmentStrategy;
   class ImapAccountBase;
@@ -60,15 +65,24 @@ class DImapTroubleShootDialog : public KDialogBase
 {
   Q_OBJECT
 public:
+  enum SelectedOperation {
+    None = -1,
+    ReindexCurrent = 0,
+    ReindexRecursive = 1,
+    ReindexAll = 2,
+    RefreshCache
+  };
+
   DImapTroubleShootDialog( QWidget* parent=0, const char* name=0 );
 
   static int run();
 
 private slots:
-  void slotRebuildIndex();
-  void slotRebuildCache();
+  void slotDone();
 
 private:
+  QRadioButton *mIndexButton, *mCacheButton;
+  QComboBox *mIndexScope;
   int rc;
 };
 
@@ -93,7 +107,7 @@ public:
   virtual void readConfig();
   virtual void writeConfig();
 
-  void writeAnnotationConfig();
+  void writeConfigKeysWhichShouldNotGetOverwrittenByReadConfig();
 
   /** Returns the type of this folder */
   virtual KMFolderType folderType() const { return KMFolderTypeCachedImap; }
@@ -191,6 +205,8 @@ public:
   virtual int createIndexFromContents()
     { return KMFolderMaildir::createIndexFromContents(); }
 
+  int createIndexFromContentsRecursive();
+
   //virtual void holdSyncs( bool hold ) { mHoldSyncs = hold; }
 
   /**
@@ -214,6 +230,17 @@ public:
   /// Set the user's rights on this folder - called by getUserRights
   void setUserRights( unsigned int userRights );
 
+  /**
+   * The quota information for this folder.
+   * @return an invalid info if we haven't synced yet, or the server
+   * doesn't support quota. The difference can be figured out by
+   * asking the account whether it supports quota. If we have
+   * synced, the account supports quota, but there is no quota
+   * on the folder, the return info will be valid, but empty.
+   * @see QuotaInfo::isEmpty(), QuotaInfo::isValid()
+   */
+  const QuotaInfo quotaInfo() const { return mQuotaInfo; }
+
   /// Return the list of ACL for this folder
   typedef QValueVector<KMail::ACLListEntry> ACLList;
   const ACLList& aclList() const { return mACLList; }
@@ -277,6 +304,7 @@ protected slots:
   void slotCheckUidValidityResult( KMail::FolderJob* job );
   void slotTestAnnotationResult(KIO::Job *job);
   void slotGetAnnotationResult( KIO::Job* );
+  void slotMultiUrlGetAnnotationResult( KIO::Job* );
   void slotSetAnnotationResult(KIO::Job *job);
   void slotReceivedUserRights( KMFolder* );
   void slotReceivedACL( KMFolder*, KIO::Job*, const KMail::ACLList& );
@@ -287,6 +315,8 @@ protected slots:
   void slotAnnotationChanged( const QString& entry, const QString& attribute, const QString& value );
   void slotDeleteMessagesResult(KMail::FolderJob *);
   void slotImapStatusChanged(KMFolder* folder, const QString&, bool);
+  void slotStorageQuotaResult( const QuotaInfo& );
+  void slotQuotaResult( KIO::Job* job );
 
 protected:
   /* returns true if there were messages to delete
@@ -298,6 +328,7 @@ protected:
   void createNewFolders();
 
   void listDirectory2();
+  void createFoldersNewOnServerAndFinishListing( const QValueVector<int> foldersNewOnServer );
 
 
   /** Utility methods for syncing. Finds new messages
@@ -389,6 +420,7 @@ private:
     SYNC_STATE_SET_ANNOTATIONS,
     SYNC_STATE_GET_ACLS,
     SYNC_STATE_SET_ACLS,
+    SYNC_STATE_GET_QUOTA,
     SYNC_STATE_FIND_SUBFOLDERS,
     SYNC_STATE_SYNC_SUBFOLDERS,
     SYNC_STATE_CHECK_UIDVALIDITY,
@@ -450,7 +482,7 @@ private:
    * listing) attempted, during the sync.  */
   bool mFoundAnIMAPDigest;
 
-  int mUserRights;
+  int mUserRights, mOldUserRights;
   ACLList mACLList;
 
   bool mSilentUpload;
@@ -471,6 +503,8 @@ private:
   int mNamespacesToCheck;
   bool mPersonalNamespacesCheckDone;
   QString mImapPathCreation;
+
+  QuotaInfo mQuotaInfo;
 };
 
 #endif /*kmfoldercachedimap_h*/
