@@ -39,6 +39,7 @@
 #include <kprocess.h>
 #include <kconfig.h>
 
+#include <ctype.h>
 #include <stdio.h>
 #include <errno.h>
 #include <assert.h>
@@ -83,19 +84,22 @@ KMFolderMbox::KMFolderMbox(KMFolder* folder, const char* name)
 //-----------------------------------------------------------------------------
 KMFolderMbox::~KMFolderMbox()
 {
-  if (mOpenCount>0) close(true);
+  if (mOpenCount>0) close("~kmfoldermbox", true);
   if (kmkernel->undoStack()) kmkernel->undoStack()->folderDestroyed( folder() );
 }
 
 //-----------------------------------------------------------------------------
-int KMFolderMbox::open()
+int KMFolderMbox::open(const char *owner)
 {
   int rc = 0;
 
   mOpenCount++;
   kmkernel->jobScheduler()->notifyOpeningFolder( folder() );
 
-  if (mOpenCount > 1) return 0;  // already open
+  if (mOpenCount > 1) {
+     assert(mStream);
+     return 0;  // already open
+  }
 
   assert(!folder()->name().isEmpty());
 
@@ -252,11 +256,15 @@ int KMFolderMbox::create()
 
 
 //-----------------------------------------------------------------------------
-void KMFolderMbox::close(bool aForced)
+void KMFolderMbox::close(const char *owner, bool aForced)
 {
-  if (mOpenCount <= 0 || !mStream) return;
+  if (!aForced)
+     assert(mOpenCount >= 0);
+
+  if (mOpenCount <= 0 || !mStream) { mOpenCount = 0; return; }
   if (mOpenCount > 0) mOpenCount--;
-  if (mOpenCount > 0 && !aForced) return;
+  if (mOpenCount > 0 && !aForced) { assert(mStream); return; }
+
 #if 0 // removed hack that prevented closing system folders (see kmail-devel discussion about mail expiring)
   if ( (folder() != kmkernel->inboxFolder())
         && folder()->isSystemFolder() && !aForced )
@@ -552,6 +560,7 @@ int KMFolderMbox::createIndexFromContents()
   QCString subjStr, dateStr, fromStr, toStr, xmarkStr, *lastStr=0;
   QCString replyToIdStr, replyToAuxIdStr, referencesStr, msgIdStr;
   QCString sizeServerStr, uidStr;
+  QCString contentTypeStr, charset;
   bool atEof = false;
   bool inHeader = true;
   KMMsgInfo* mi;
@@ -652,6 +661,29 @@ int KMFolderMbox::createIndexFromContents()
               replyToAuxIdStr.truncate( rightAngle + 1 );
           }
 
+          contentTypeStr = contentTypeStr.stripWhiteSpace();
+          charset = "";
+          if ( !contentTypeStr.isEmpty() )
+          {
+            int cidx = contentTypeStr.find( "charset=" );
+            if ( cidx != -1 ) {
+              charset = contentTypeStr.mid( cidx + 8 );
+              if ( !charset.isEmpty() && ( charset[0] == '"' ) ) {
+                charset = charset.mid( 1 );
+              }
+              cidx = 0;
+              while ( (unsigned int) cidx < charset.length() ) {
+                if ( charset[cidx] == '"' || ( !isalnum(charset[cidx]) &&
+                    charset[cidx] != '-' && charset[cidx] != '_' ) )
+                  break;
+                ++cidx;
+              }
+              charset.truncate( cidx );
+              // kdDebug() << "KMFolderMaildir::readFileHeaderIntern() charset found: " <<
+              //              charset << " from " << contentTypeStr << endl;
+            }
+          }
+
           mi = new KMMsgInfo(folder());
           mi->init( subjStr.stripWhiteSpace(),
                     fromStr.stripWhiteSpace(),
@@ -660,7 +692,7 @@ int KMFolderMbox::createIndexFromContents()
                     xmarkStr.stripWhiteSpace(),
                     replyToIdStr, replyToAuxIdStr, msgIdStr,
                     KMMsgEncryptionStateUnknown, KMMsgSignatureStateUnknown,
-                    KMMsgMDNStateUnknown, offs, size, sizeServer, uid );
+                    KMMsgMDNStateUnknown, charset, offs, size, sizeServer, uid );
           mi->setStatus(status, xstatus);
           mi->setDate( dateStr.stripWhiteSpace() );
           mi->setDirty(false);
@@ -766,6 +798,11 @@ int KMFolderMbox::createIndexFromContents()
       uid = uidStr.toULong();
       lastStr = &uidStr;
     }
+    else if (strncasecmp(line, "Content-Type:", 13) == 0)
+    {
+      contentTypeStr = QCString(line+13);
+      lastStr = &contentTypeStr;
+    }
   }
 
   if (mAutoCreateIndex)
@@ -840,12 +877,12 @@ static size_t unescapeFrom( char* str, size_t strLen ) {
 }
 
 //static
-QCString KMFolderMbox::escapeFrom( const QCString & str ) {
+QByteArray KMFolderMbox::escapeFrom( const DwString & str ) {
   const unsigned int strLen = str.length();
   if ( strLen <= STRDIM("From ") )
-    return str;
+    return KMail::Util::ByteArray( str );
   // worst case: \nFrom_\nFrom_\nFrom_... => grows to 7/6
-  QCString result( int( strLen + 5 ) / 6 * 7 + 1 );
+  QByteArray result( int( strLen + 5 ) / 6 * 7 + 1 );
 
   const char * s = str.data();
   const char * const e = s + strLen - STRDIM("From ");
@@ -878,29 +915,6 @@ QCString KMFolderMbox::escapeFrom( const QCString & str ) {
 
 #undef STRDIM
 
-//-----------------------------------------------------------------------------
-QCString& KMFolderMbox::getMsgString(int idx, QCString &mDest)
-{
-  unsigned long msgSize;
-  KMMsgInfo* mi = (KMMsgInfo*)mMsgList[idx];
-
-  assert(mi!=0);
-  assert(mStream != 0);
-
-  msgSize = mi->msgSize();
-  mDest.resize(msgSize+2);
-
-  fseek(mStream, mi->folderOffset(), SEEK_SET);
-  fread(mDest.data(), msgSize, 1, mStream);
-  mDest[msgSize] = '\0';
-
-  size_t newMsgSize = unescapeFrom( mDest.data(), msgSize );
-  newMsgSize = KMail::Util::crlf2lf( mDest.data(), newMsgSize );
-
-  return mDest;
-}
-
-
 //-----------------------------------------------------------------------------
 DwString KMFolderMbox::getDwString(int idx)
 {
@@ -931,7 +945,7 @@ int KMFolderMbox::addMsg( KMMessage* aMsg, int* aIndex_ret )
 {
   if (!canAddMsgNow(aMsg, aIndex_ret)) return 0;
   bool opened = false;
-  QCString msgText;
+  QByteArray msgText;
   char endStr[3];
   int idx = -1, rc;
   KMFolder* msgParent;
@@ -941,7 +955,7 @@ int KMFolderMbox::addMsg( KMMessage* aMsg, int* aIndex_ret )
   if (!mStream)
   {
     opened = true;
-    rc = open();
+    rc = open("mboxaddMsg");
     kdDebug(5006) << "KMFolderMBox::addMsg-open: " << rc << " of folder: " << label() << endl;
     if (rc) return rc;
   }
@@ -988,15 +1002,15 @@ if( fileD1.open( IO_WriteOnly ) ) {
     if (aMsg->headerField("Content-Type").isEmpty())  // This might be added by
       aMsg->removeHeaderField("Content-Type");        // the line above
   }
-  msgText = escapeFrom( aMsg->asString() );
-  size_t len = msgText.length();
+  msgText = escapeFrom( aMsg->asDwString() );
+  size_t len = msgText.size();
 
   assert(mStream != 0);
   clearerr(mStream);
   if (len <= 0)
   {
     kdDebug(5006) << "Message added to folder `" << name() << "' contains no data. Ignoring it." << endl;
-    if (opened) close();
+    if (opened) close("mboxaddMsg");
     return 0;
   }
 
@@ -1022,14 +1036,14 @@ if( fileD1.open( IO_WriteOnly ) ) {
   int error = ferror(mStream);
   if (error)
   {
-    if (opened) close();
+    if (opened) close("mboxaddMsg");
     return error;
   }
 
   QCString messageSeparator( aMsg->mboxMessageSeparator() );
   fwrite( messageSeparator.data(), messageSeparator.length(), 1, mStream );
   off_t offs = ftell(mStream);
-  fwrite(msgText, len, 1, mStream);
+  fwrite(msgText.data(), len, 1, mStream);
   if (msgText[(int)len-1]!='\n') fwrite("\n\n", 1, 2, mStream);
   fflush(mStream);
   size_t size = ftell(mStream) - offs;
@@ -1071,10 +1085,10 @@ if( fileD1.open( IO_WriteOnly ) ) {
   }
   ++mTotalMsgs;
 
-  if ( aMsg->attachmentState() == KMMsgAttachmentUnknown && 
+  if ( aMsg->attachmentState() == KMMsgAttachmentUnknown &&
        aMsg->readyToShow() )
     aMsg->updateAttachmentState();
-  
+
   // store information about the position in the folder file in the message
   aMsg->setParent(folder());
   aMsg->setFolderOffset(offs);
@@ -1143,7 +1157,7 @@ if( fileD1.open( IO_WriteOnly ) ) {
   // some "paper work"
   if (aIndex_ret) *aIndex_ret = idx;
   emitMsgAddedSignals(idx);
-  if (opened) close();
+  if (opened) close("mboxaddMsg");
 
   // All streams have been flushed without errors if we arrive here
   // Return success!
@@ -1232,17 +1246,11 @@ int KMFolderMbox::compact( bool silent )
 {
   // This is called only when the user explicitely requests compaction,
   // so we don't check needsCompact.
-  int openCount = mOpenCount;
 
   KMail::MboxCompactionJob* job = new KMail::MboxCompactionJob( folder(), true /*immediate*/ );
   int rc = job->executeNow( silent );
   // Note that job autodeletes itself.
 
-  if (openCount > 0)
-  {
-    open();
-    mOpenCount = openCount;
-  }
   // If this is the current folder, the changed signal will ultimately call
   // KMHeaders::setFolderInfoStatus which will override the message, so save/restore it
   QString statusMsg = BroadcastStatus::instance()->statusMsg();
