@@ -69,6 +69,7 @@ namespace KMail {
   class FolderJob;
   class HeaderListQuickSearch;
   class SearchWindow;
+  class ImapAccountBase;
 }
 
 typedef QMap<int,KMFolder*> KMMenuToFolder;
@@ -208,9 +209,12 @@ public slots:
   /** Update message actions */
   void updateMessageActions();
 
-  /** Launch subscription-dialog */
+  /** Launch subscription-dialog (server side) */
   void slotSubscriptionDialog();
 
+  /** Launch dialog for local (client side) subscription configuration */
+  void slotLocalSubscriptionDialog();
+
   /** The columns of the foldertree changed */
   void slotFolderTreeColumnsChanged();
 
@@ -241,6 +245,10 @@ protected:
   void updateFileMenu();
   void newFromTemplate( KMMessage *msg );
 
+  // helper functions for keeping reference to mFolder
+  void openFolder();
+  void closeFolder();
+
   KActionCollection * actionCollection() const { return mActionCollection; }
 
   /** @return the correct config dialog depending on whether the parent of the mainWidget
@@ -417,6 +425,16 @@ private:
 
   void initializeIMAPActions( bool setState );
 
+  /** Helper which finds the associated account if there is a current
+   * folder and it is an imap or disconnected imap one.
+   */
+  KMail::ImapAccountBase* findCurrentImapAccountBase();
+
+  /** Helper which finds the associated IMAP path if there is a current
+   * folder and it is an imap or disconnected imap one.
+   */
+  QString findCurrentImapPath();
+
 private:
   // Message actions
   KAction *mTrashAction, *mDeleteAction, *mTrashThreadAction,
@@ -498,10 +516,11 @@ private:
 //  QPopupMenu *mMessageMenu;
   KMail::SearchWindow *mSearchWin;
 
-  KAction *mModifyFolderAction, *mRemoveFolderAction, *mExpireFolderAction,
+  KAction *mNewFolderAction, *mModifyFolderAction, *mRemoveFolderAction, *mExpireFolderAction,
       *mCompactFolderAction, *mRefreshFolderAction, *mEmptyFolderAction,
       *mMarkAllAsReadAction, *mFolderMailingListPropertiesAction,
-      *mFolderShortCutCommandAction, *mTroubleshootFolderAction;
+      *mFolderShortCutCommandAction, *mTroubleshootFolderAction,
+      *mRemoveDuplicatesAction;
   KToggleAction *mPreferHtmlAction, *mPreferHtmlLoadExtAction, *mThreadMessagesAction;
   KToggleAction *mThreadBySubjectAction;
   KToggleAction *mFolderAction, *mHeaderAction, *mMimeAction;
@@ -531,6 +550,7 @@ private:
   KXMLGUIClient *mGUIClient;
 
   static QValueList<KMMainWidget*>* s_mainWidgetList;
+  bool mOpenedImapFolder;
 };
 
 #endif
