@@ -161,8 +161,8 @@ bool KMSender::doSend(KMMessage* aMsg, short sendNow)
 
   if (sendNow==-1) sendNow = mSendImmediate;
 
-  kmkernel->outboxFolder()->open();
-  const KMFolderCloser openOutbox( kmkernel->outboxFolder() );
+  kmkernel->outboxFolder()->open("outbox");
+  const KMFolderCloser openOutbox( "outbox", kmkernel->outboxFolder() );
 
   aMsg->setStatus(KMMsgStatusQueued);
 
@@ -219,11 +219,11 @@ bool KMSender::doSendQueued( const QString &customTransport )
 
   // open necessary folders
   mOutboxFolder = kmkernel->outboxFolder();
-  mOutboxFolder->open();
+  mOutboxFolder->open("dosendoutbox");
   mTotalMessages = mOutboxFolder->count();
   if (mTotalMessages == 0) {
     // Nothing in the outbox. We are done.
-    mOutboxFolder->close();
+    mOutboxFolder->close("dosendoutbox");
     mOutboxFolder = 0;
     return TRUE;
   }
@@ -236,7 +236,7 @@ bool KMSender::doSendQueued( const QString &customTransport )
   mCurrentMsg = 0;
 
   mSentFolder = kmkernel->sentFolder();
-  mSentFolder->open();
+  mSentFolder->open("dosendsent");
   kmkernel->filterMgr()->ref();
 
   // start sending the messages
@@ -352,7 +352,7 @@ void KMSender::doSendMsg()
       sentFolder = kmkernel->sentFolder();
 
     if ( sentFolder ) {
-      if ( const int err = sentFolder->open() ) {
+      if ( const int err = sentFolder->open("sentFolder") ) {
         Q_UNUSED( err );
         cleanup();
         return;
@@ -375,7 +375,7 @@ void KMSender::doSendMsg()
                    "Moving failing message to \"sent-mail\" folder."));
       if ( sentFolder ) {
         sentFolder->moveMsg(mCurrentMsg);
-        sentFolder->close();
+        sentFolder->close("sentFolder");
       }
       cleanup();
       return;
@@ -446,7 +446,7 @@ void KMSender::doSendMsg()
     	mCurrentMsg = 0;
     // no more message: cleanup and done
     if ( sentFolder != 0 )
-        sentFolder->close();
+        sentFolder->close("sentFolder");
     if ( someSent ) {
       if ( mSentMessages == mTotalMessages ) {
         setStatusMsg(i18n("%n queued message successfully sent.",
@@ -605,7 +605,7 @@ void KMSender::doSendMsgAux()
   if ( messageIsDispositionNotificationReport( mCurrentMsg ) && GlobalSettings::self()->sendMDNsWithEmptySender() )
     sender = "<>";
 
-  const QCString message = mCurrentMsg->asSendableString();
+  const QByteArray message = mCurrentMsg->asSendableString();
   if ( sender.isEmpty() || !mSendProc->send( sender, to, cc, bcc, message ) ) {
     if ( mCurrentMsg )
       mCurrentMsg->setTransferInProgress( false );
@@ -636,13 +636,13 @@ void KMSender::cleanup(void)
     mCurrentMsg = 0;
   }
   if ( mSentFolder ) {
-    mSentFolder->close();
+    mSentFolder->close("dosendsent");
     mSentFolder = 0;
   }
   if ( mOutboxFolder ) {
     disconnect( mOutboxFolder, SIGNAL(msgAdded(int)),
                 this, SLOT(outboxMsgAdded(int)) );
-    mOutboxFolder->close();
+    mOutboxFolder->close("dosendoutbox");
     if ( mOutboxFolder->count( true ) == 0 ) {
       mOutboxFolder->expunge();
     }
@@ -707,6 +707,11 @@ void KMSender::slotIdle()
         mOutboxFolder->unGetMsg( mFailedMessages );
       mCurrentMsg = 0;
       mFailedMessages++;
+      // reset cached password
+      QMapIterator <QString,QString> pc;
+      if ( (pc = mPasswdCache.find( mMethodStr )) != mPasswdCache.end() ) {
+        mPasswdCache.erase(pc);
+      }
       // Sending of message failed.
       if (!errString.isEmpty()) {
         int res = KMessageBox::Yes;
@@ -854,7 +859,7 @@ void KMSender::setStatusByLink(const KMMessage *aMsg)
     int index = -1;
     KMMsgDict::instance()->getLocation(msn, &folder, &index);
     if (folder && index != -1) {
-      folder->open();
+      folder->open("setstatus");
       if ( status == KMMsgStatusDeleted ) {
         // Move the message to the trash folder
         KMDeleteMsgCommand *cmd =
@@ -863,7 +868,7 @@ void KMSender::setStatusByLink(const KMMessage *aMsg)
       } else {
         folder->setStatus(index, status);
       }
-      folder->close();
+      folder->close("setstatus");
     } else {
       kdWarning(5006) << k_funcinfo << "Cannot update linked message, it could not be found!" << endl;
     }
@@ -963,7 +968,7 @@ void KMSendSendmail::abort()
   idle();
 }
 
-bool KMSendSendmail::doSend( const QString & sender, const QStringList & to, const QStringList & cc, const QStringList & bcc, const QCString & message ) {
+bool KMSendSendmail::doSend( const QString & sender, const QStringList & to, const QStringList & cc, const QStringList & bcc, const QByteArray & message ) {
   mMailerProc->clearArguments();
   *mMailerProc << mSender->transportInfo()->host
                << "-i" << "-f" << sender
@@ -977,7 +982,7 @@ bool KMSendSendmail::doSend( const QString & sender, const QStringList & to, con
     return false;
   }
   mMsgPos  = mMsgStr.data();
-  mMsgRest = mMsgStr.length();
+  mMsgRest = mMsgStr.size();
   wroteStdin( mMailerProc );
 
   return true;
@@ -1048,7 +1053,7 @@ KMSendSMTP::~KMSendSMTP()
   if (mJob) mJob->kill();
 }
 
-bool KMSendSMTP::doSend( const QString & sender, const QStringList & to, const QStringList & cc, const QStringList & bcc, const QCString & message ) {
+bool KMSendSMTP::doSend( const QString & sender, const QStringList & to, const QStringList & cc, const QStringList & bcc, const QByteArray & message ) {
   QString query = "headers=0&from=";
   query += KURL::encode_string( sender );
 
@@ -1077,6 +1082,12 @@ bool KMSendSMTP::doSend( const QString & sender, const QStringList & to, const Q
 
   if (ti->auth)
   {
+    QMapIterator<QString,QString> tpc = mSender->mPasswdCache.find( ti->name );
+    QString tpwd = ( tpc != mSender->mPasswdCache.end() )?(*tpc):QString::null;
+
+    if ( ti->passwd().isEmpty() )
+      ti->setPasswd( tpwd );
+
     if( (ti->user.isEmpty() || ti->passwd().isEmpty()) &&
       ti->authType != "GSSAPI" )
     {
@@ -1097,6 +1108,9 @@ bool KMSendSMTP::doSend( const QString & sender, const QStringList & to, const Q
       if (int id = KMTransportInfo::findTransport(ti->name)) {
         ti->setPasswd( passwd );
         ti->writeConfig(id);
+
+        // save the password into the cache
+        mSender->mPasswdCache[ti->name] = passwd;
       }
     }
     destination.setUser(ti->user);
@@ -1119,7 +1133,7 @@ bool KMSendSMTP::doSend( const QString & sender, const QStringList & to, const Q
 
   // dotstuffing is now done by the slave (see setting of metadata)
   mMessage = message;
-  mMessageLength = mMessage.length();
+  mMessageLength = mMessage.size();
   mMessageOffset = 0;
 
   if ( mMessageLength )
