@@ -14,7 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #include <config.h>
@@ -42,9 +42,9 @@
 using KWallet::Wallet;
 #include <kprotocolinfo.h>
 
+#include "kmkernel.h"
 #include "kmservertest.h"
 #include "kmaccount.h"
-#include "kmkernel.h"
 #include "protocols.h"
 #include "transportmanager.h"
 using namespace KMail;
@@ -126,15 +126,15 @@ void KMTransportInfo::writeConfig(int id)
   if ( storePasswd() ) {
     // write password into the wallet if possible and necessary
     bool passwdStored = false;
+    Wallet *wallet = kmkernel->wallet();
     if ( mPasswdDirty ) {
-      Wallet *wallet = kmkernel->wallet();
       if ( wallet && wallet->writePassword( "transport-" + QString::number(mId), passwd() ) == 0 ) {
         passwdStored = true;
         mPasswdDirty = false;
         mStorePasswdInConfig = false;
       }
     } else {
-      passwdStored = !mStorePasswdInConfig; // already in the wallet
+      passwdStored = wallet ? !mStorePasswdInConfig /*already in the wallet*/ : config->hasKey("pass");
     }
     // wallet not available, ask the user if we should use the config file instead
     if ( !passwdStored && ( mStorePasswdInConfig ||  KMessageBox::warningYesNo( 0,
@@ -778,10 +778,27 @@ void KMTransportDialog::slotSmtpCapabilities( const QStringList & capaNormal,
   delete mServerTest;
   mServerTest = 0;
 }
-
+bool KMTransportDialog::sanityCheckSmtpInput()
+{
+  // FIXME: add additional checks for all fields that needs it
+  // this is only the beginning
+  if ( mSmtp.hostEdit->text().isEmpty() ) {
+    QString errorMsg = i18n("The Host field cannot be empty. Please  "
+                            "enter the name or the IP address of the SMTP server.");
+    KMessageBox::sorry( this, errorMsg, i18n("Invalid Hostname or Address") );
+    return false;
+  }
+  return true;
+}
 
 void KMTransportDialog::slotOk()
 {
+  if (mTransportInfo->type != "sendmail") {
+    if( !sanityCheckSmtpInput() ) {
+      return;
+    }
+  }
+
   saveSettings();
   accept();
 }
