@@ -1,4 +1,4 @@
-/**
+/*
  * Copyright (c) 2004 Carsten Burghardt <burghardt@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -12,7 +12,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  *  In addition, as a special exception, the copyright holders give
  *  permission to link the code of this program with any edition of
@@ -60,23 +60,49 @@ public:
    * @param storage the parent folder, either provide this or a path
    * @param account the ImapAccountBase
    * @param type Type of subscription
-   * @param secondStep if this is the second listing (when a prefix is set)
    * @param complete list all folders or only next level
-   * @param hasInbox if you already have an inbox
    * @param path the listing path;
    *             if empty the path of the folder will be taken
    * @param item a parent ProgressItem
    */
-  ListJob( FolderStorage* storage, ImapAccountBase* account,
-           ImapAccountBase::ListType type,
-           bool secondStep = false, bool complete = false,
-           bool hasInbox = false, const QString& path = QString::null,
-           KPIM::ProgressItem* item = 0 );
+  ListJob( ImapAccountBase* account, ImapAccountBase::ListType type,
+           FolderStorage* storage = 0, const QString& path = QString::null,
+           bool complete = false, KPIM::ProgressItem* item = 0 );
 
   virtual ~ListJob();
 
+  /**
+   * Set whether the listing should include only folders that the
+   * account is subscribed to locally. This is different from the server
+   * side subscription managed by the ctor parameter.
+   */
+  void setHonorLocalSubscription( bool value );
+  
+  /**
+   * Return whether the listing includes only folders that the
+   * account is subscribed to locally. This is different from the server
+   * side subscription managed by the ctor parameter.
+   */
+  bool honorLocalSubscription() const;
+
   virtual void execute();
 
+  /** Path */
+  void setPath( const QString& path ) { mPath = path; }
+
+  /** Storage */
+  void setStorage( FolderStorage* st ) { mStorage = st; }
+
+  /** Set this to true for a complete listing */
+  void setComplete( bool complete ) { mComplete = complete; }
+
+  /** Set parent progress item */
+  void setParentProgressItem( KPIM::ProgressItem* it ) { 
+    mParentProgressItem = it; }
+
+  /** Set the namespace for this listing */
+  void setNamespace( const QString& ns ) { mNamespace = ns; }
+
 protected:
   /**
    * Does the actual KIO::listDir
@@ -111,13 +137,13 @@ protected:
   FolderStorage* mStorage;
   ImapAccountBase* mAccount;
   ImapAccountBase::ListType mType;
-  bool mHasInbox;
-  bool mSecondStep;
   bool mComplete;
+  bool mHonorLocalSubscription;
   QString mPath;
   QStringList mSubfolderNames, mSubfolderPaths,
               mSubfolderMimeTypes, mSubfolderAttributes;
   KPIM::ProgressItem* mParentProgressItem;
+  QString mNamespace;
 };
 
 } // namespace
