@@ -28,9 +28,12 @@
 #include "kmfoldermgr.h"
 #include "kmfoldersearch.h"
 #include "kmfoldertree.h"
+#include "kmheaders.h"
 #include "kmsearchpatternedit.h"
 #include "kmsearchpattern.h"
 #include "folderrequester.h"
+#include "messagecopyhelper.h"
+#include "textsource.h"
 
 #include <kapplication.h>
 #include <kdebug.h>
@@ -38,6 +41,7 @@
 #include <kwin.h>
 #include <kconfig.h>
 #include <kstdaction.h>
+#include <kiconloader.h>
 
 #include <qcheckbox.h>
 #include <qlayout.h>
@@ -50,6 +54,9 @@
 #include <qcursor.h>
 #include <qpopupmenu.h>
 
+#include <maillistdrag.h>
+using namespace KPIM;
+
 #include <mimelib/enum.h>
 #include <mimelib/boyermor.h>
 
@@ -60,6 +67,44 @@ namespace KMail {
 
 const int SearchWindow::MSGID_COLUMN = 4;
 
+// KListView sub-class for dnd support
+class MatchListView : public KListView
+{
+  public:
+    MatchListView( QWidget *parent, SearchWindow* sw, const char* name = 0 ) :
+      KListView( parent, name ),
+      mSearchWindow( sw )
+    {}
+
+  protected:
+    virtual QDragObject* dragObject()
+    {
+      KMMessageList list = mSearchWindow->selectedMessages();
+      MailList mailList;
+      for ( KMMsgBase* msg = list.first(); msg; msg = list.next() ) {
+        if ( !msg )
+          continue;
+        MailSummary mailSummary( msg->getMsgSerNum(), msg->msgIdMD5(),
+                                 msg->subject(), msg->fromStrip(),
+                                 msg->toStrip(), msg->date() );
+        mailList.append( mailSummary );
+      }
+      MailListDrag *d = new MailListDrag( mailList, viewport(), new KMTextSource );
+
+      QPixmap pixmap;
+      if( mailList.count() == 1 )
+        pixmap = QPixmap( DesktopIcon("message", KIcon::SizeSmall) );
+      else
+        pixmap = QPixmap( DesktopIcon("kmultiple", KIcon::SizeSmall) );
+
+      d->setPixmap( pixmap );
+      return d;
+    }
+
+  private:
+    SearchWindow* mSearchWindow;
+};
+
 //-----------------------------------------------------------------------------
 SearchWindow::SearchWindow(KMMainWidget* w, const char* name,
                          KMFolder *curFolder, bool modal):
@@ -157,7 +202,7 @@ SearchWindow::SearchWindow(KMMainWidget* w, const char* name,
   connect( mChkbxAllFolders, SIGNAL(toggled(bool)),
            this, SLOT(setEnabledSearchButton(bool)) );
 
-  mLbxMatches = new KListView(searchWidget, "Find Messages");
+  mLbxMatches = new MatchListView(searchWidget, this, "Find Messages");
 
   /*
      Default is to sort by date. TODO: Unfortunately this sorts *while*
@@ -190,6 +235,8 @@ SearchWindow::SearchWindow(KMMainWidget* w, const char* name,
   mLbxMatches->setColumnWidth(MSGID_COLUMN, 0);
   mLbxMatches->header()->setResizeEnabled(false, MSGID_COLUMN);
 
+  mLbxMatches->setDragEnabled( true );
+
   connect(mLbxMatches, SIGNAL(doubleClicked(QListViewItem *)),
           this, SLOT(slotShowMsg(QListViewItem *)));
   connect( mLbxMatches, SIGNAL( contextMenuRequested( QListViewItem*, const QPoint &, int )),
@@ -256,6 +303,7 @@ SearchWindow::SearchWindow(KMMainWidget* w, const char* name,
 
   //set up actions
   KActionCollection *ac = actionCollection();
+  ac->setWidget( this );
   mReplyAction = new KAction( i18n("&Reply..."), "mail_reply", 0, this,
                               SLOT(slotReplyToMsg()), ac, "search_reply" );
   mReplyAllAction = new KAction( i18n("Reply to &All..."), "mail_replyall",
@@ -297,6 +345,10 @@ SearchWindow::SearchWindow(KMMainWidget* w, const char* name,
   mPrintAction = KStdAction::print( this, SLOT(slotPrintMsg()), ac, "search_print" );
   mClearAction = new KAction( i18n("Clear Selection"), 0, 0, this,
                               SLOT(slotClearSelection()), ac, "search_clear_selection" );
+
+  mCopyAction = KStdAction::copy( this, SLOT(slotCopyMsgs()), ac, "search_copy_messages" );
+  mCutAction = KStdAction::cut( this, SLOT(slotCutMsgs()), ac, "search_cut_messages" );
+
   connect(mTimer, SIGNAL(timeout()), this, SLOT(updStatus()));
   connect(kmkernel->searchFolderMgr(), SIGNAL(folderInvalidated(KMFolder*)),
           this, SLOT(folderInvalidated(KMFolder*)));
@@ -313,7 +365,7 @@ SearchWindow::~SearchWindow()
   for ( fit = mFolders.begin(); fit != mFolders.end(); ++fit ) {
     if (!(*fit))
       continue;
-    (*fit)->close();
+    (*fit)->close("searchwindow");
   }
 
   KConfig* config = KMKernel::config();
@@ -470,7 +522,7 @@ void SearchWindow::slotSearch()
     enableGUI();
 
     if (mFolder && !mFolders.contains(mFolder.operator->()->folder())) {
-        mFolder->open();
+        mFolder->open("searchwindow");
         mFolders.append(mFolder.operator->()->folder());
     }
     mTimer->start(200);
@@ -502,7 +554,7 @@ void SearchWindow::slotAddMsg(int idx)
     KMFolder *pFolder = msg->parent();
     if (!mFolders.contains(pFolder)) {
         mFolders.append(pFolder);
-        pFolder->open();
+        pFolder->open("searchwindow");
     }
     if(pFolder->whoField() == "To")
         from = msg->to();
@@ -717,6 +769,8 @@ void SearchWindow::updateContextMenuActions()
     mPrintAction->setEnabled( single_actions );
     mForwardDigestAction->setEnabled( !single_actions );
     mRedirectAction->setEnabled( single_actions );
+    mCopyAction->setEnabled( count > 0 );
+    mCutAction->setEnabled( count > 0 );
 }
 
 //-----------------------------------------------------------------------------
@@ -746,8 +800,11 @@ void SearchWindow::slotContextMenuRequested( QListViewItem *lvi, const QPoint &,
     mReplyListAction->plug(menu);
     mForwardActionMenu->plug(menu);
     menu->insertSeparator();
+    mCopyAction->plug(menu);
+    mCutAction->plug(menu);
     menu->insertItem(i18n("&Copy To"), msgCopyMenu);
     menu->insertItem(i18n("&Move To"), msgMoveMenu);
+    menu->insertSeparator();
     mSaveAsAction->plug(menu);
     mSaveAtchAction->plug(menu);
     mPrintAction->plug(menu);
@@ -838,5 +895,17 @@ void SearchWindow::slotPrintMsg()
     command->start();
 }
 
+void SearchWindow::slotCopyMsgs()
+{
+  QValueList<Q_UINT32> list = MessageCopyHelper::serNumListFromMsgList( selectedMessages() );
+  mKMMainWidget->headers()->setCopiedMessages( list, false );
+}
+
+void SearchWindow::slotCutMsgs()
+{
+  QValueList<Q_UINT32> list = MessageCopyHelper::serNumListFromMsgList( selectedMessages() );
+  mKMMainWidget->headers()->setCopiedMessages( list, true );
+}
+
 } // namespace KMail
 #include "searchwindow.moc"
