@@ -41,64 +41,79 @@ class FolderStorage;
 
 namespace KMail {
 
-  class SubscriptionDialog : public KSubscription
+  // Abstract base class for the server side and client side subscription dialogs.
+  // Scott Meyers says: "Make non-leaf classes abstract" and he is right, I think.
+  // (More Effective C++, Item 33)
+  class SubscriptionDialogBase : public KSubscription
   {
     Q_OBJECT
 
     public:
-      SubscriptionDialog( QWidget *parent, const QString &caption, KAccount* acct,
-         QString startPath = QString::null );
+      SubscriptionDialogBase( QWidget *parent,
+                              const QString &caption,
+                              KAccount* acct,
+                              QString startPath = QString::null );
+      virtual ~SubscriptionDialogBase() {}
 
       void show();
 
     protected:
       /**
-       * Find the parent item 
-       */ 
+       * Find the parent item
+       */
       void findParentItem ( QString &name, QString &path, QString &compare,
                        GroupItem **parent, GroupItem **oldItem );
 
       /**
        * Process the next prefix in mPrefixList
-       */ 
+       */
       void processNext();
 
       /**
        * Fill mPrefixList
-       */ 
+       */
       void initPrefixList();
 
+      virtual void loadingComplete();
+
     public slots:
       /**
        * get the listing from the imap-server
-       */ 
+       */
       void slotListDirectory(const QStringList&, const QStringList&,
           const QStringList&, const QStringList&, const ImapAccountBase::jobData &);
 
-      /** 
+      /**
        * called by Ok-button, saves the changes
-       */ 
+       */
       void slotSave();
 
       /**
        * Called from the account when a connection was established
        */
-      void slotConnectionResult( int errorCode, const QString& errorMsg );      
+      void slotConnectionResult( int errorCode, const QString& errorMsg );
 
     protected slots:
       /**
        * Loads the folders
-       */ 
+       */
       void slotLoadFolders();
 
-      /**
-       * Create or update the listitems
-       */ 
-      void createItems();
+    protected:
+      virtual void listAllAvailableAndCreateItems() = 0;
+      virtual void processFolderListing() = 0;
+      virtual void doSave() = 0;
+
+      // helpers
+      /** Move all child items of @param oldItem under @param item */
+      void moveChildrenToNewParent( GroupItem *oldItem, GroupItem *item  );
+
+      /** Create a listview item for the i-th entry in the list of available
+       * folders. */
+      void createListViewItem( int i );
 
-    private:
       QString mDelimiter;
-      QStringList mFolderNames, mFolderPaths, 
+      QStringList mFolderNames, mFolderPaths,
                   mFolderMimeTypes, mFolderAttributes;
       ImapAccountBase::jobData mJobData;
       uint mCount;
@@ -109,6 +124,33 @@ namespace KMail {
       QString mCurrentNamespace;
   };
 
+  class SubscriptionDialog : public SubscriptionDialogBase
+  {
+    Q_OBJECT
+    public:
+
+      SubscriptionDialog( QWidget *parent,
+                          const QString &caption,
+                          KAccount* acct,
+                          QString startPath = QString::null );
+      virtual ~SubscriptionDialog();
+     protected:
+      /** reimpl */
+      virtual void listAllAvailableAndCreateItems();
+      /** reimpl */
+      virtual void processFolderListing();
+      /** reimpl */
+      virtual void doSave();
+
+    private:
+      /**
+       * Create or update the listitems, depending on whether we are listing
+       * all available folders, or only subscribed ones.
+       */
+      void processItems();
+
+  };
+
 } // namespace KMail
 
 #endif
