@@ -3,7 +3,7 @@
  *                                                                             *
  * KonsoleKalendar is a command line interface to KDE calendars                *
  * Copyright (C) 2002-2004  Tuukka Pasanen <illuusio@mailcity.com>             *
- * Copyright (C) 2003-2004  Allen Winter <winter@kde.org>                      *
+ * Copyright (C) 2003-2005  Allen Winter <winter@kde.org>                      *
  *                                                                             *
  * This program is free software; you can redistribute it and/or modify        *
  * it under the terms of the GNU General Public License as published by        *
@@ -17,14 +17,19 @@
  *                                                                             *
  * You should have received a copy of the GNU General Public License           *
  * along with this program; if not, write to the Free Software                 *
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. *
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA. *
  *                                                                             *
  * As a special exception, permission is given to link this program            *
  * with any edition of Qt, and distribute the resulting executable,            *
  * without including the source code for Qt in the source distribution.        *
  *                                                                             *
  ******************************************************************************/
-
+/**
+ * @file konsolekalendaradd.cpp
+ * Provides the KonsoleKalendarAdd class definition.
+ * @author Tuukka Pasanen
+ * @author Allen Winter
+ */
 #include <stdlib.h>
 #include <iostream>
 
@@ -32,11 +37,13 @@
 #include <qobject.h>
 
 #include <kdebug.h>
+#include <kstandarddirs.h>
 #include <klocale.h>
 
 #include <libkcal/calendarlocal.h>
 #include <libkcal/calendar.h>
 #include <libkcal/event.h>
+#include <libkdepim/kpimprefs.h>
 
 #include "konsolekalendaradd.h"
 
@@ -63,12 +70,12 @@ bool KonsoleKalendarAdd::addEvent()
   kdDebug() << "konsolekalendaradd.cpp::addEvent()" << endl;
 
   if ( m_variables->isDryRun() ) {
-    cout << i18n("Insert Event <Dry Run>:").local8Bit()
+    cout << i18n( "Insert Event <Dry Run>:" ).local8Bit()
          << endl;
     printSpecs();
   } else {
     if ( m_variables->isVerbose() ) {
-      cout << i18n("Insert Event <Verbose>:").local8Bit()
+      cout << i18n( "Insert Event <Verbose>:" ).local8Bit()
            << endl;
       printSpecs();
     }
@@ -83,19 +90,14 @@ bool KonsoleKalendarAdd::addEvent()
     event->setLocation( m_variables->getLocation() );
 
     if ( m_variables->getCalendar()->addEvent( event ) ) {
-      cout << i18n("Success: \"%1\" inserted").
+      cout << i18n( "Success: \"%1\" inserted" ).
         arg( m_variables->getSummary() ).local8Bit()
            << endl;
 
-      if ( ! m_variables->isCalendarResources() ) {
-        status =
-          m_variables->getCalendar()->save( m_variables->getCalendarFile() );
-      } else {
         m_variables->getCalendar()->save();
-      }
 
     } else {
-      cout << i18n("Failure: \"%1\" not inserted").
+      cout << i18n( "Failure: \"%1\" not inserted" ).
         arg( m_variables->getSummary() ).local8Bit()
            << endl;
       status = false;
@@ -109,56 +111,58 @@ bool KonsoleKalendarAdd::addEvent()
 bool KonsoleKalendarAdd::addImportedCalendar()
 {
 
-  // TODO: reimplement this please..
+// If --file specified, then import into that file
+// else, import into the standard calendar
 
-  /*if ( ! m_variables->getCalendar()->load( m_variables->getImportFile() ) ) {
+  QString fileName;
+  if ( m_variables->getCalendarFile().isEmpty() )
+    fileName = locateLocal( "data", "korganizer/std.ics" );
+  else
+    fileName = m_variables->getCalendarFile();
+
+  CalendarLocal *cal = new CalendarLocal( KPimPrefs::timezone() );
+  if ( !cal->load( fileName ) ||
+       !cal->load( m_variables->getImportFile() ) ||
+       !cal->save( fileName ) ) {
     kdDebug()
       << "konsolekalendaradd.cpp::importCalendar() | "
       << "Can't import file: "
       << m_variables->getImportFile()
       << endl;
     return false;
-  } else {
-    kdDebug()
-      << "konsolekalendaradd.cpp::importCalendar() | "
-      << "Successfully imported file: "
-      << m_variables->getImportFile()
-      << endl;
   }
-
-  if ( ! m_variables->isCalendarResources() ) {
-    m_variables->getCalendar()->save( m_variables->getCalendarFile() );
-  } else {
-    m_variables->getCalendar()->save();
-  }*/
-
+  kdDebug()
+    << "konsolekalendaradd.cpp::importCalendar() | "
+    << "Successfully imported file: "
+    << m_variables->getImportFile()
+    << endl;
   return true;
 }
 
 void KonsoleKalendarAdd::printSpecs()
 {
-  cout << i18n("  What:  %1").
+  cout << i18n( "  What:  %1" ).
     arg( m_variables->getSummary() ).local8Bit()
        << endl;
 
-  cout << i18n("  Begin: %1").
-    arg( m_variables->getStartDateTime().toString(Qt::TextDate) ).local8Bit()
+  cout << i18n( "  Begin: %1" ).
+    arg( m_variables->getStartDateTime().toString( Qt::TextDate ) ).local8Bit()
        << endl;
 
-  cout << i18n("  End:   %1").
-    arg( m_variables->getEndDateTime().toString(Qt::TextDate) ).local8Bit()
+  cout << i18n( "  End:   %1" ).
+    arg( m_variables->getEndDateTime().toString( Qt::TextDate ) ).local8Bit()
        << endl;
 
   if ( m_variables->getFloating() == true ) {
-    cout << i18n("  No Time Associated with Event").local8Bit()
+    cout << i18n( "  No Time Associated with Event" ).local8Bit()
          << endl;
   }
 
-  cout << i18n("  Desc:  %1").
+  cout << i18n( "  Desc:  %1" ).
     arg( m_variables->getDescription() ).local8Bit()
        << endl;
 
-  cout << i18n("  Location:  %1").
+  cout << i18n( "  Location:  %1" ).
     arg( m_variables->getLocation() ).local8Bit()
        << endl;
 }
