@@ -17,8 +17,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 #ifndef SUMMARYVIEW_PART_H
@@ -73,6 +73,7 @@ class SummaryViewPart : public KParts::ReadOnlyPart
 
   protected slots:
     void slotConfigure();
+    void updateSummaries();
     void updateWidgets();
     void summaryWidgetMoved( QWidget *target, QWidget *widget, int alignment );
 
@@ -94,6 +95,7 @@ class SummaryViewPart : public KParts::ReadOnlyPart
     QLabel *mUsernameLabel;
     QLabel *mDateLabel;
     KAction *mConfigAction;
+    KAction *mRefreshAction;
 
     QStringList mLeftColumnSummaries;
     QStringList mRightColumnSummaries;
