@@ -15,14 +15,14 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
     As a special exception, permission is given to link this program
     with any edition of Qt, and distribute the resulting executable,
     without including the source code for Qt in the source distribution.
 */
-#ifndef __TEST_PLUGIN_H__
-#define __TEST_PLUGIN_H__
+#ifndef TEST_PLUGIN_H
+#define TEST_PLUGIN_H
 
 
 #include "plugin.h"
@@ -42,11 +42,10 @@ public:
 
 protected:
   KParts::Part* createPart();
-  
+
 private slots:
 
   void slotTestMenu();
 };
 
-
 #endif
