@@ -2,6 +2,7 @@
     This file is part of the KOrganizer interfaces.
 
     Copyright (c) 1999,2001,2003 Cornelius Schumacher <schumacher@kde.org>
+		Copyright (C) 2004           Reinhold Kainhofer   <reinhold@kainhofer.com>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -15,8 +16,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 #ifndef KORG_BASEVIEW_H
 #define KORG_BASEVIEW_H
@@ -28,25 +29,19 @@
 #include <klocale.h>
 #include <kdebug.h>
 #include <kmessagebox.h>
+#include <kdepimmacros.h>
+#include "korganizer/incidencechangerbase.h"
+
+#include "printplugin.h"
 
 #include <libkcal/event.h>
-#include <libkcal/calendar.h>
 
 using namespace KCal;
 
-class CalPrinter;
+namespace KCal { class Calendar; }
 
 namespace KOrg {
 
-/**
-  Base class of KOrganizer printer class.
-*/
-class CalPrinterBase
-{
-  public:
-    enum PrintType { Day, Week, Month, Todolist };
-};
-
 
 /**
   This class provides an interface for all views being displayed within the main
@@ -59,7 +54,7 @@ class CalPrinterBase
   @author Preston Brown, Cornelius Schumacher
   @see KOTodoView, KOEventView, KOListView, KOAgendaView, KOMonthView
 */
-class BaseView : public QWidget
+class KDE_EXPORT BaseView : public QWidget
 {
     Q_OBJECT
   public:
@@ -71,8 +66,9 @@ class BaseView : public QWidget
       @param parent parent widget.
       @param name   name of this widget.
     */
-    BaseView( Calendar *cal, QWidget *parent = 0, const char *name = 0 )
-      : QWidget( parent, name ), mCalendar( cal ) {}
+    BaseView( Calendar *cal, QWidget *parent = 0,
+              const char *name = 0 )
+      : QWidget( parent, name ), mCalendar( cal ), mChanger( 0 ) {}
 
     /**
       Destructor.  Views will do view-specific cleanups here.
@@ -99,35 +95,6 @@ class BaseView : public QWidget
     */
     virtual DateList selectedDates() = 0;
 
-    /**
-      Generate a print preview of this event view.
-
-      @param calPrinter Calendar printer object used for printing
-      @param fd from date
-      @param td to date
-    */
-/*
-  The date parameters should be determined by the view itself and not given as
-  parameters. At the moment I just move the code from the topwidget to the
-  individual views.
-*/
-    virtual void printPreview( CalPrinter *, const QDate &, const QDate & )
-    {
-      KMessageBox::sorry(this, i18n("Unfortunately, we don't handle printing for\n"
-                                    "that view yet.\n"));
-    }
-
-    /**
-      Print this view.
-
-      @param calPrinter Calendar printer object used for printing
-    */
-    virtual void print( CalPrinter * )
-    {
-      KMessageBox::sorry(this, i18n("Unfortunately, we don't handle printing for\n"
-                                    "that view yet.\n"));
-    }
-
     virtual CalPrinterBase::PrintType printType()
     {
       return CalPrinterBase::Month;
@@ -156,16 +123,21 @@ class BaseView : public QWidget
       Show given incidences. Depending on the actual view it might not be possible to
       show all given events.
 
-      @param eventList a list of events to show.
+      @param incidenceList a list of incidences to show.
     */
-    virtual void showIncidences( const Incidence::List &eventList ) = 0;
+    virtual void showIncidences( const Incidence::List &incidenceList ) = 0;
 
     /**
       Updates the current display to reflect changes that may have happened
       in the calendar since the last display refresh.
     */
     virtual void updateView() = 0;
-    virtual void dayPassed( QDate ) { updateView(); }
+    virtual void dayPassed( const QDate & ) { updateView(); }
+
+    /**
+      Assign a new incidence change helper object.
+     */
+    virtual void setIncidenceChanger( IncidenceChangerBase *changer ) { mChanger = changer; }
 
     /**
       Write all unsaved data back to calendar store.
@@ -214,17 +186,27 @@ class BaseView : public QWidget
      * box, etc.  Doesn't make sense to connect to more than one receiver.
      */
     void deleteIncidenceSignal(Incidence *);
- 
-    /** 
+
+    /**
+    * instructs the receiver to cut the Incidence
+    */
+    void cutIncidenceSignal(Incidence *);
+
+    /**
+    * instructs the receiver to copy the incidence
+    */
+    void copyIncidenceSignal(Incidence *);
+
+    /**
      * instructs the receiver to toggle the alarms of the Incidence.
      */
     void toggleAlarmSignal(Incidence *);
-
-    void incidenceAdded( Incidence* );
-    void incidenceChanged( Incidence*, Incidence*, int );
-    void incidenceChanged( Incidence*, Incidence* );
-    void incidenceDeleted( Incidence* );
-    void incidenceToBeDeleted( Incidence* );
+    /** Dissociate from a recurring incidence the occurrence on the given
+        date to a new incidence */
+    void dissociateOccurrenceSignal( Incidence *, const QDate & );
+    /** Dissociate from a recurring incidence all occurrences after the given
+        date to a new incidence */
+    void dissociateFutureOccurrenceSignal( Incidence *, const QDate & );
 
     void startMultiModify( const QString & );
     void endMultiModify();
@@ -238,24 +220,28 @@ class BaseView : public QWidget
      * instructs the receiver to create a new event with the specified beginning
      * time. Doesn't make sense to connect to more than one receiver.
      */
-    void newEventSignal(QDate);
+    void newEventSignal( const QDate & );
     /**
      * instructs the receiver to create a new event with the specified beginning
      * time. Doesn't make sense to connect to more than one receiver.
      */
-    void newEventSignal(QDateTime);
+    void newEventSignal( const QDateTime & );
     /**
      * instructs the receiver to create a new event, with the specified
      * beginning end ending times.  Doesn't make sense to connect to more
      * than one receiver.
      */
-    void newEventSignal(QDateTime, QDateTime);
+    void newEventSignal( const QDateTime &, const QDateTime & );
 
-    void newTodoSignal( QDate );
+    void newTodoSignal( const QDate & );
     void newSubTodoSignal( Todo * );
 
+    void newJournalSignal( const QDate & );
+
   private:
     Calendar *mCalendar;
+  protected:
+    IncidenceChangerBase *mChanger;
 };
 
 }
