@@ -31,10 +31,12 @@
 #include <kdebug.h>
 #include <klocale.h>
 #include <kwordwrap.h>
+#include <kmessagebox.h>
 
 #include <libkcal/icaldrag.h>
 #include <libkcal/vcaldrag.h>
 #include <libkdepim/kvcarddrag.h>
+#include <libemailfunctions/email.h>
 #ifndef KORG_NOKABC
 #include <kabc/addressee.h>
 #include <kabc/vcardconverter.h>
@@ -550,21 +552,18 @@ void KOAgendaItem::dragEnterEvent( QDragEnterEvent *e )
 void KOAgendaItem::addAttendee( const QString &newAttendee )
 {
   kdDebug(5850) << " Email: " << newAttendee << endl;
-  // TODO: Use proper email parsing instead of simply grepping for "<" and "@"
-  int pos = newAttendee.find("<");
-  QString name = newAttendee.left(pos);
-  QString email = newAttendee.mid(pos);
-  if (!email.isEmpty()) {
+  QString name, email;
+  KPIM::getNameAndMail( newAttendee, name, email );
+  if ( !( name.isEmpty() && email.isEmpty() ) ) {
     mIncidence->addAttendee(new Attendee(name,email));
-  } else if (name.contains("@")) {
-    mIncidence->addAttendee(new Attendee(name,name));
-  } else {
-    mIncidence->addAttendee(new Attendee(name,QString::null));
-  }
+    KMessageBox::information( this, i18n("Attendee \"%1\" added to the calendar item \"%2\"").arg(KPIM::normalizedAddress(name, email, QString())).arg(text()), i18n("Attendee added"), "AttendeeDroppedAdded" );
+  } 
+ 
 }
 
 void KOAgendaItem::dropEvent( QDropEvent *e )
 {
+  // TODO: Organize this better: First check for attachment (not only file, also any other url!), then if it's a vcard, otherwise check for attendees, then if the data is binary, add a binary attachment. 
 #ifndef KORG_NODND
   QString text;
 
@@ -662,11 +661,23 @@ static void conditionalPaint( QPainter *p, bool cond, int &x, int ft,
   x += pxmp.width() + ft;
 }
 
+void KOAgendaItem::paintEventIcon( QPainter *p, int &x, int ft )
+{
+  if ( !mIncidence ) return;
+  static const QPixmap eventPxmp =
+    KOGlobals::self()->smallIcon( "appointment" );
+  if ( mIncidence->type() != "Event" )
+    return;
+  conditionalPaint( p, true, x, ft, eventPxmp );
+}
+
 void KOAgendaItem::paintTodoIcon( QPainter *p, int &x, int ft )
 {
   if ( !mIncidence ) return;
-  static const QPixmap todoPxmp = KOGlobals::self()->smallIcon("todo");
-  static const QPixmap completedPxmp = KOGlobals::self()->smallIcon("checkedbox");
+  static const QPixmap todoPxmp =
+    KOGlobals::self()->smallIcon( "todo" );
+  static const QPixmap completedPxmp =
+    KOGlobals::self()->smallIcon( "checkedbox" );
   if ( mIncidence->type() != "Todo" )
     return;
   bool b = ( static_cast<Todo *>( mIncidence ) )->isCompleted();
@@ -676,6 +687,7 @@ void KOAgendaItem::paintTodoIcon( QPainter *p, int &x, int ft )
 
 void KOAgendaItem::paintIcons( QPainter *p, int &x, int ft )
 {
+  paintEventIcon( p, x, ft );
   paintTodoIcon( p, x, ft );
   conditionalPaint( p, mIconAlarm,          x, ft, *alarmPxmp );
   conditionalPaint( p, mIconRecur,          x, ft, *recurPxmp );
