@@ -972,6 +972,8 @@ void KOAgendaView::updateEventDates( KOAgendaItem *item )
 
   Incidence *incidence = item->incidence();
   if ( !incidence ) return;
+  if ( !mChanger || !mChanger->beginChange(incidence) ) return;
+  Incidence *oldIncidence = incidence->clone();
 
   QTime startTime(0,0,0), endTime(0,0,0);
   if ( incidence->doesFloat() ) {
@@ -997,6 +999,7 @@ void KOAgendaView::updateEventDates( KOAgendaItem *item )
     Event*ev = static_cast<Event*>(incidence);
     if( incidence->dtStart() == startDt && ev->dtEnd() == endDt ) {
       // No change
+      delete oldIncidence;
       return;
     }
     incidence->setDtStart( startDt );
@@ -1011,6 +1014,7 @@ void KOAgendaView::updateEventDates( KOAgendaItem *item )
 
     if( td->dtDue() == endDt ) {
       // No change
+      delete oldIncidence;
       return;
     }
   }
@@ -1170,6 +1174,10 @@ void KOAgendaView::updateEventDates( KOAgendaItem *item )
     td->setDtDue( endDt );
   }
 
+  mChanger->changeIncidence( oldIncidence, incidence );
+  mChanger->endChange(incidence);
+  delete oldIncidence;
+
   item->setItemDate( startDt.date() );
 
   KOIncidenceToolTip::remove( item );
@@ -1510,10 +1518,10 @@ void KOAgendaView::clearView()
   mAgenda->clear();
 }
 
-CalPrinter::PrintType KOAgendaView::printType()
+CalPrinterBase::PrintType KOAgendaView::printType()
 {
-  if ( currentDateCount() == 1 ) return CalPrinter::Day;
-  else return CalPrinter::Week;
+  if ( currentDateCount() == 1 ) return CalPrinterBase::Day;
+  else return CalPrinterBase::Week;
 }
 
 void KOAgendaView::updateEventIndicatorTop( int newY )
@@ -1562,7 +1570,7 @@ void KOAgendaView::slotTodoDropped( Todo *todo, const QPoint &gpos, bool allDay
       todo->setDtDue( newTime );
       todo->setFloats( allDay );
       todo->setHasDueDate( true );
-      if ( !mChanger->addIncidence( todo ) ) {
+      if ( !mChanger->addIncidence( todo, this ) ) {
         KODialogManager::errorSaveIncidence( this, todo );
       }
     }
