@@ -16,7 +16,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
     As a special exception, permission is given to link this program
     with any edition of Qt, and distribute the resulting executable,
@@ -55,6 +55,8 @@ class KOEditorAttachments : public QWidget
     /** Write event settings to event object */
     void writeIncidence( KCal::Incidence * );
 
+    bool hasAttachments();
+
   protected slots:
     void showAttachment( QListViewItem *item );
     void slotAdd();
