@@ -16,7 +16,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
     As a special exception, permission is given to link this program
     with any edition of Qt, and distribute the resulting executable,
@@ -40,10 +40,10 @@ namespace KOrg { class IncidenceChangerBase; }
 
 class KOEditorDetails;
 class KOEditorAttachments;
-class KOEditorAlarms;
 
 namespace KCal {
 class Calendar;
+class CalendarLocal;
 class Incidence;
 }
 using namespace KCal;
@@ -63,8 +63,6 @@ class KOIncidenceEditor : public KDialogBase
                        QWidget *parent );
     virtual ~KOIncidenceEditor();
 
-    /** Initialize editor. This function creates the tab widgets. */
-    virtual void init() = 0;
     /** This incidence has been modified externally */
     virtual void modified (int /*change*/=0) {}
 
@@ -76,6 +74,16 @@ class KOIncidenceEditor : public KDialogBase
     virtual void editIncidence(Incidence *) = 0;
     virtual void setIncidenceChanger( IncidenceChangerBase *changer ) {
         mChanger = changer; }
+    /** Initialize editor. This function creates the tab widgets. */
+    virtual void init() = 0;
+    /**
+      Adds attachments to the editor
+    */
+    void addAttachments( const QStringList &attachments );
+    /**
+      Adds attendees to the editor
+    */
+    void addAttendees( const QStringList &attendees );
 
 
   signals:
@@ -93,21 +101,21 @@ class KOIncidenceEditor : public KDialogBase
     void slotCancel();
     void openURL( const KURL &url );
 
-    virtual void slotLoadTemplate();
-    virtual void slotSaveTemplate();
+    virtual void slotManageTemplates();
 
-    virtual void saveTemplate( const QString & ) = 0;
+    virtual void slotSaveTemplate( const QString & ) = 0;
+    virtual void slotLoadTemplate( const QString& );
+    virtual void slotTemplatesChanged( const QStringList& );
 
   protected:
     virtual QString type() { return QString::null; }
+    virtual QStringList& templates() const = 0;
+    virtual void loadTemplate( /*const*/ CalendarLocal& ) = 0;
 
     void setupAttendeesTab();
     void setupAttachmentsTab();
-    void setupAlarmsTab();
     void setupDesignerTabs( const QString &type );
 
-    QString loadTemplate( Calendar *cal, const QString &type,
-                          const QStringList &templates );
     void saveAsTemplate( Incidence *, const QString &name );
 
     void readDesignerFields( Incidence *i );
@@ -130,11 +138,8 @@ class KOIncidenceEditor : public KDialogBase
 
     Calendar *mCalendar;
 
-    KPIM::CategorySelectDialog *mCategoryDialog;
-
     KOEditorDetails *mDetails;
     KOEditorAttachments *mAttachments;
-    KOEditorAlarms *mAlarms;
     KOrg::IncidenceChangerBase *mChanger;
 
     QPtrList<KPIM::DesignerFields> mDesignerFields;
