@@ -66,8 +66,8 @@ KOTodoEditor::~KOTodoEditor()
 
 void KOTodoEditor::init()
 {
+  kdDebug(5850) << k_funcinfo << endl;
   setupGeneral();
-//  setupAlarmsTab();
   setupRecurrence();
   setupAttendeesTab();
   setupAttachmentsTab();
@@ -76,6 +76,9 @@ void KOTodoEditor::init()
            mRecurrence, SLOT( setDateTimeStr( const QString & ) ) );
   connect( mGeneral, SIGNAL( signalDateTimeChanged( const QDateTime &, const QDateTime & ) ),
            mRecurrence, SLOT( setDateTimes( const QDateTime &, const QDateTime & ) ) );
+
+  connect( mGeneral, SIGNAL( openCategoryDialog() ),
+           SIGNAL( editCategories() ) );
 }
 
 void KOTodoEditor::reload()
@@ -132,6 +135,9 @@ void KOTodoEditor::setupGeneral()
     mGeneral->initCategories( topFrame, detailsLayout );
     mGeneral->initSecrecy( topFrame, detailsLayout );
   }
+  // By default, the To-do has no time associated and
+  // neither a start nor end time.
+  mGeneral->setDefaults( QDateTime(), false );
 
   mGeneral->finishSetup();
 }
@@ -152,6 +158,7 @@ void KOTodoEditor::setupRecurrence()
 
 void KOTodoEditor::editIncidence(Incidence *incidence)
 {
+  kdDebug(5850) << k_funcinfo << endl;
   Todo *todo=dynamic_cast<Todo*>(incidence);
   if (todo)
   {
@@ -166,6 +173,7 @@ void KOTodoEditor::editIncidence(Incidence *incidence)
 
 void KOTodoEditor::newTodo()
 {
+  kdDebug(5850) << k_funcinfo << endl;
   init();
   mTodo = 0;
   setCaption( i18n("New To-do") );
@@ -187,6 +195,7 @@ void KOTodoEditor::setTexts( const QString &summary, const QString &description
 
 void KOTodoEditor::loadDefaults()
 {
+  kdDebug(5850) << k_funcinfo << endl;
   setDates( QDateTime::currentDateTime().addDays(7), true, 0 );
 }
 
