@@ -47,7 +47,7 @@ QString KornMailSubject::toString() const
 {
 	QDateTime date;
 	date.setTime_t(_date);
-	return QString("KornMailSubject, Id: ") + (_id?_id->toString():QString("NULL")) + ", " + i18n("Subject:") + " " + QString(_subject.utf8())
-		+ ", " + i18n("Sender:") + " " + QString(_sender.utf8()) + ", " + i18n("Size:") + " " + QString::number(_size)
+	return QString("KornMailSubject, Id: ") + (_id?_id->toString():QString("NULL")) + ", " + i18n("Subject:") + " " + _subject
+		+ ", " + i18n("Sender:") + " " + _sender + ", " + i18n("Size:") + " " + QString::number(_size)
 		+ ", " + i18n("Date:") + " " + date.toString(Qt::ISODate);
 }
