@@ -46,16 +46,16 @@
 #include "vcalconduitSettings.h"
 #include "todo-factory.h"
 
+#include "kcalRecord.h"
+#include "todoRecord.h"
+
 // define conduit versions, one for the version when categories were synced for the first time, and the current version number
 #define CONDUIT_VERSION_CATEGORYSYNC 10
 #define CONDUIT_VERSION 10
 
 extern "C"
 {
-long version_conduit_todo = KPILOT_PLUGIN_API;
-
-const char *id_conduit_todo = "$Id: todo-conduit.cc 450417 2005-08-18 06:07:11Z vanrijn $";
-
+unsigned long version_conduit_todo = Pilot::PLUGIN_API;
 }
 
 
@@ -82,7 +82,12 @@ int TodoConduitPrivate::updateIncidences()
 void TodoConduitPrivate::removeIncidence(KCal::Incidence *e)
 {
 	fAllTodos.remove(static_cast<KCal::Todo*>(e));
+	if (!fCalendar) return;
 	fCalendar->deleteTodo(static_cast<KCal::Todo*>(e));
+	// now just in case we're in the middle of reading through our list
+	// and we delete something, set reading to false so we start at the
+	// top again next time and don't have problems with our iterator
+	reading = false;
 }
 
 
@@ -100,7 +105,7 @@ KCal::Incidence *TodoConduitPrivate::findIncidence(recordid_t id)
 
 
 
-KCal::Incidence *TodoConduitPrivate::findIncidence(PilotAppCategory*tosearch)
+KCal::Incidence *TodoConduitPrivate::findIncidence(PilotRecordBase *tosearch)
 {
 	PilotTodoEntry*entry=dynamic_cast<PilotTodoEntry*>(tosearch);
 	if (!entry) return 0L;
@@ -155,7 +160,7 @@ KCal::Incidence *TodoConduitPrivate::getNextModifiedIncidence()
 
 #ifdef DEBUG
 	if(e)
-		DEBUGCONDUIT<< e->summary()<<" had SyncStatus="<<e->syncStatus()<<endl;
+		DEBUGKPILOT<< e->summary()<<" had SyncStatus="<<e->syncStatus()<<endl;
 #endif
 
 	}
@@ -169,17 +174,13 @@ KCal::Incidence *TodoConduitPrivate::getNextModifiedIncidence()
  *                          TodoConduit class                               *
  ****************************************************************************/
 
-TodoConduit::TodoConduit(KPilotDeviceLink *d,
+TodoConduit::TodoConduit(KPilotLink *d,
 	const char *n,
-	const QStringList &a) : VCalConduitBase(d,n,a)
+	const QStringList &a) : VCalConduitBase(d,n,a),
+	fTodoAppInfo( 0L )
 {
 	FUNCTIONSETUP;
-#ifdef DEBUG
-	DEBUGCONDUIT << id_conduit_todo << endl;
-#endif
 	fConduitName=i18n("To-do");
-
-        (void) id_conduit_todo;
 }
 
 
@@ -195,7 +196,19 @@ void TodoConduit::_setAppInfo()
 {
 	FUNCTIONSETUP;
 	// get the address application header information
-	fTodoAppInfo->write(fDatabase);
+
+	if( !fTodoAppInfo )
+	{
+		DEBUGKPILOT << fname << ": fTodoAppInfo is NULL" << endl;
+		return;
+	}
+	if( !fDatabase )
+	{
+		DEBUGKPILOT << fname << ": fDatabase is NULL" << endl;
+		return;
+	}
+
+	fTodoAppInfo->writeTo(fDatabase);
 }
 
 void TodoConduit::_getAppInfo()
@@ -203,19 +216,20 @@ void TodoConduit::_getAppInfo()
 	FUNCTIONSETUP;
 	// get the address application header information
 
+	KPILOT_DELETE( fTodoAppInfo );
 	fTodoAppInfo = new PilotToDoInfo(fDatabase);
-
-#ifdef DEBUG
 	fTodoAppInfo->dump();
-#endif
 }
 
 
 
-const QString TodoConduit::getTitle(PilotAppCategory*de)
+const QString TodoConduit::getTitle(PilotRecordBase *de)
 {
 	PilotTodoEntry*d=dynamic_cast<PilotTodoEntry*>(de);
-	if (d) return QString(d->getDescription());
+	if (d)
+	{
+		return QString(d->getDescription());
+	}
 	return QString::null;
 }
 
@@ -231,13 +245,18 @@ void TodoConduit::readConfig()
 	//
 	categoriesSynced = config()->conduitVersion()>=CONDUIT_VERSION_CATEGORYSYNC;
 	if (!categoriesSynced && !isFullSync() )
+	{
 		changeSync(SyncMode::eFullSync);
-#ifdef DEBUG
-	DEBUGCONDUIT<<"categoriesSynced="<<categoriesSynced<<endl;
-#endif
+	}
+	DEBUGKPILOT<<"categoriesSynced=" << categoriesSynced << endl;
 }
 
-
+void TodoConduit::preSync()
+{
+	FUNCTIONSETUP;
+	VCalConduitBase::preSync();
+	_getAppInfo();
+}
 
 void TodoConduit::postSync()
 {
@@ -251,61 +270,73 @@ void TodoConduit::postSync()
 
 
 
-PilotRecord*TodoConduit::recordFromIncidence(PilotAppCategory*de, const KCal::Incidence*e)
-{
-	// don't need to check for null pointers here, the recordFromIncidence(PTE*, KCal::Todo*) will do that.
-	PilotTodoEntry *tde = dynamic_cast<PilotTodoEntry*>(de);
-	const KCal::Todo *te = dynamic_cast<const KCal::Todo*>(e);
-
-	return recordFromTodo(tde, te);
-}
-
-
-
-PilotRecord*TodoConduit::recordFromTodo(PilotTodoEntry*de, const KCal::Todo*todo)
+PilotRecord *TodoConduit::recordFromIncidence(PilotRecordBase *de, const KCal::Incidence *e)
 {
 	FUNCTIONSETUP;
-	if (!de || !todo) {
-#ifdef DEBUG
-		DEBUGCONDUIT<<fname<<": NULL todo given... Skipping it"<<endl;
-#endif
-		return NULL;
+
+	if (!de || !e)
+	{
+		DEBUGKPILOT << fname
+			<< ": got NULL entry or NULL incidence." << endl;
+		return 0L;
 	}
 
-	// set secrecy, start/end times, alarms, recurrence, exceptions, summary and description:
-	if (todo->secrecy()!=KCal::Todo::SecrecyPublic) de->setSecret( true );
-
-	// update it from the iCalendar Todo.
-
-	if (todo->hasDueDate()) {
-		struct tm t = writeTm(todo->dtDue());
-		de->setDueDate(t);
-		de->setIndefinite(0);
-	} else {
-		de->setIndefinite(1);
+	PilotTodoEntry *todoEntry = dynamic_cast<PilotTodoEntry*>(de);
+	if (!todoEntry)
+	{
+		// Secretly wasn't a todo entry after all
+		return 0L;
 	}
 
-	// TODO: take recurrence (code in VCAlConduit) from ActionNames
+	const KCal::Todo *todo = dynamic_cast<const KCal::Todo *>(e);
+	if (!todo)
+	{
+		DEBUGKPILOT << fname << ": Incidence is not a todo." << endl;
+		return 0L;
+	}
 
-	setCategory(de, todo);
-
-	// TODO: sync the alarm from ActionNames. Need to extend PilotTodoEntry
-	de->setPriority(todo->priority());
-
-	de->setComplete(todo->isCompleted());
-
-	// what we call summary pilot calls description.
-	de->setDescription(todo->summary());
-
-	// what we call description pilot puts as a separate note
-	de->setNote(todo->description());
-
-#ifdef DEBUG
-DEBUGCONDUIT<<"-------- "<<todo->summary()<<endl;
-#endif
-	return de->pack();
+	// don't need to check for null pointers here, the recordFromIncidence(PTE*, KCal::Todo*) will do that.
+	if (KCalSync::setTodoEntry(todoEntry,todo,*fTodoAppInfo->categoryInfo()))
+	{
+		return todoEntry->pack();
+	}
+	else
+	{
+		return 0L;
+	}
 }
 
+KCal::Incidence *TodoConduit::incidenceFromRecord(KCal::Incidence *e, const PilotRecordBase *de)
+{
+	FUNCTIONSETUP;
+
+	if (!de || !e)
+	{
+		DEBUGKPILOT << fname
+			<< ": Got NULL entry or NULL incidence." << endl;
+		return 0L;
+	}
+
+	const PilotTodoEntry *todoEntry = dynamic_cast<const PilotTodoEntry *>(de);
+	if (!todoEntry)
+	{
+		DEBUGKPILOT << fname << ": HH record not a todo entry." << endl;
+		return 0L;
+	}
+
+	KCal::Todo *todo = dynamic_cast<KCal::Todo *>(e);
+	if (!todo)
+	{
+		DEBUGKPILOT << fname << ": Incidence is not a todo." << endl;
+		return 0L;
+	}
+
+	KCalSync::setTodo(todo, todoEntry,*fTodoAppInfo->categoryInfo());
+	return e;
+}
+
+
+
 
 
 void TodoConduit::preRecord(PilotRecord*r)
@@ -313,142 +344,30 @@ void TodoConduit::preRecord(PilotRecord*r)
 	FUNCTIONSETUP;
 	if (!categoriesSynced && r)
 	{
-		const PilotAppCategory*de=newPilotEntry(r);
+		const PilotRecordBase *de = newPilotEntry(r);
 		KCal::Incidence *e = fP->findIncidence(r->id());
-		setCategory(dynamic_cast<KCal::Todo*>(e), dynamic_cast<const PilotTodoEntry*>(de));
+		KCalSync::setCategory(dynamic_cast<KCal::Todo*>(e),
+			dynamic_cast<const PilotTodoEntry*>(de),
+			*fTodoAppInfo->categoryInfo());
 	}
 }
 
 
 
-void TodoConduit::setCategory(PilotTodoEntry*de, const KCal::Todo*todo)
-{
-	if (!de || !todo) return;
-	de->setCategory(_getCat(todo->categories(), de->getCategoryLabel()));
-}
 
 
 
-/**
- * _getCat returns the id of the category from the given categories list. If none of the
- * categories exist on the palm, the "Unfiled" one is used.
- */
-QString TodoConduit::_getCat(const QStringList cats, const QString curr) const
-{
-	int j;
-	if (cats.size()<1) return QString::null;
-	if (cats.contains(curr)) return curr;
-	for ( QStringList::ConstIterator it = cats.begin(); it != cats.end(); ++it )
+static VCalConduitSettings *config_vcal = 0L;
+
+VCalConduitSettings *TodoConduit::theConfig() {
+	if (!config_vcal)
 	{
-		for (j=1; j<PILOT_CATEGORY_MAX; j++)
-		{
-			QString catName = fTodoAppInfo->category(j);
-			if (!(*it).isEmpty() && !(*it).compare( catName ) )
-			{
-				return catName;
-			}
-		}
-	}
-	// If we have a free label, return the first possible cat
-	//
-	// FIXME: Clearly buggy, but I don't know how or why
-	QString lastName = fTodoAppInfo->category(PILOT_CATEGORY_MAX-1);
-	if (lastName.isEmpty()) return cats.first();
-	return QString::null;
-}
-
-
-
-KCal::Incidence *TodoConduit::incidenceFromRecord(KCal::Incidence *e, const PilotAppCategory *de)
-{
-	return dynamic_cast<KCal::Incidence*>(incidenceFromRecord(dynamic_cast<KCal::Todo*>(e), dynamic_cast<const PilotTodoEntry*>(de)));
-}
-
-
-
-KCal::Todo *TodoConduit::incidenceFromRecord(KCal::Todo *e, const PilotTodoEntry *de)
-{
-	FUNCTIONSETUP;
-
-	KCal::Todo*vtodo=e;
-	if (!vtodo)
-	{
-#ifdef DEBUG
-		DEBUGCONDUIT<<fname<<": null todo entry given. skipping..."<<endl;
-#endif
-		return NULL;
+		config_vcal = new VCalConduitSettings(CSL1("Calendar"));
 	}
 
-   // We don't want this, do we?
-//	e->setOrganizer(fCalendar->getEmail());
-	e->setPilotId(de->id());
-#ifdef DEBUG
-		DEBUGCONDUIT<<fname<<": set KCal item to pilotId: [" << e->pilotId() << "] ..."<<endl;
-#endif
-	e->setSyncStatus(KCal::Incidence::SYNCNONE);
-	e->setSecrecy(de->isSecret() ? KCal::Todo::SecrecyPrivate : KCal::Todo::SecrecyPublic);
-
-	// we don't want to modify the vobject with pilot info, because it has
-	// already been  modified on the desktop.  The VObject's modified state
-	// overrides the PilotRec's modified state.
-	// TODO: Also include this in the vcal conduit!!!
-//	if (e->syncStatus() != KCal::Incidence::SYNCNONE) return e;
-
-	// otherwise, the vObject hasn't been touched.  Updated it with the
-	// info from the PilotRec.
-	if (de->getIndefinite()) {
-		e->setHasDueDate(false);
-	} else {
-		e->setDtDue(readTm(de->getDueDate()));
-		e->setHasDueDate(true);
-	}
-
-	// Categories
-	setCategory(e, de);
-
-	// PRIORITY //
-	e->setPriority(de->getPriority());
-
-	// COMPLETED? //
-	e->setCompleted(de->getComplete());
-	if ( de->getComplete() && !e->hasCompletedDate() ) {
-		e->setCompleted( QDateTime::currentDateTime() );
-	}
-
-	e->setSummary(de->getDescription());
-	e->setDescription(de->getNote());
-
-	e->setSyncStatus(KCal::Incidence::SYNCNONE);
-
-	return e;
+	return config_vcal;
 }
 
-
-
-void TodoConduit::setCategory(KCal::Todo *e, const PilotTodoEntry *de)
-{
-	if (!e || !de) return;
-	QStringList cats=e->categories();
-	int cat=de->category();
-	if (0<cat && cat<PILOT_CATEGORY_MAX)
-	{
-		QString newcat=fTodoAppInfo->category(cat);
-		if (!cats.contains(newcat))
-		{
-			// if this event only has one category associated with it, then we can
-			// safely assume that what we should be doing here is changing it to match
-			// the palm.  if there's already more than one category in the event, however, we
-			// won't cause data loss--we'll just append what the palm has to the 
-			// event's categories
-			if (cats.count() <=1) cats.clear();
-			
-			cats.append( newcat );
-			e->setCategories(cats);
-		}
-	}
-}
-
-VCalConduitSettings *TodoConduit::config()
-{
-  return ToDoConduitFactory::config();
+VCalConduitSettings *TodoConduit::config() {
+	return theConfig();
 }
