@@ -49,13 +49,12 @@ Q_OBJECT
 public:
 	ProbeDialog(QWidget *p=0L,const char *n=0L);
 	~ProbeDialog();
-	
+
 	bool detected() const { return mDetected; }
 	QString userName() const { return mUserName; }
 	QString device() const { return mDevice; }
-	int userID() const { return mUID; }
 	QStringList dbs()  const { return mDBs; }
-	
+
 
 protected slots:
 	void startDetection();
@@ -88,17 +87,15 @@ protected:
 protected:
 	QGridLayout* fResultsGroupLayout;
 	QGridLayout* fStatusGroupLayout;
-	
+
 	QStringList mDevicesToProbe[3];
 	PilotLinkList mDeviceLinks[3];
 	int mProbeDevicesIndex;
-//	PilotLinkMap mDeviceLinkMap;
 	KPilotDeviceLink *mActiveLink;
-	
+
 	bool mDetected;
 	QString mUserName;
 	QString mDevice;
-	int mUID;
 	QStringList mDBs;
 } ;
 
