@@ -1,6 +1,6 @@
 #ifndef _KPILOT_KPILOTLINK_H
 #define _KPILOT_KPILOTLINK_H
-/* kpilotlink.h			KPilot
+/* KPilot
 **
 ** Copyright (C) 1998-2001 by Dan Pilone
 ** Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
@@ -29,55 +29,84 @@
 ** Bug reports and questions can be sent to kde-pim@kde.org
 */
 
-#include <time.h>
 #include <pi-dlp.h>
 
 #include <qobject.h>
 #include <qvaluelist.h>
 
-class QTimer;
-class QDateTime;
-class QSocketNotifier;
+/** @file
+* Encapsulates all the communication with the handheld. Also
+* does daemon-like polling of the handheld. Interesting status
+* changes are signalled.
+*/
+
 class QThread;
 class KPilotUser;
 class KPilotSysInfo;
 class KPilotCard;
 class PilotDatabase;
-struct DBInfo;
 
 
 
-/** @file
-** Encapsulates all the communication with the pilot. Also
-** does daemon-like polling of the Pilot. Interesting status
-** changes are signalled.
-**
-** This file defines three classes; these handle some aspects of
-** communication with a Handheld. A KPilotLink object represents a
-** connection to a device (which may be active or inactive -- the latter in
-** cases where the link is @e waiting for a device to show up). The object
-** handles waiting, protocol initialization and some general
-** tasks such as getting system information or user data.
-**
-** The actual communication with the handheld should use the
-** PilotDatabase methods or use pilot-link dlp_* functions directly
-** on handle().
-**
-** The KPilotLink class was originally a kind of C++ wrapper
-** for the pilot-link library. It grew and grew and mutated
-** until it was finally cleaned up again in 2001. In the meantime
-** it had become something that wrapped a lot more than just
-** pilot-link.
-**
-** This file defines an abstract base class KPilotLink, which may
-** be specialized for a real physical device that communicates
-** with DLP/SLP through the pilot-link library, or as a "fake"
-** device which uses data on the local filesystem to simulate
-** a device. These subclasses are KPilotDeviceLink and KPilotLocalLink.
-*/
-
 /**
-* Tickle handling.
+* KPilotLink handles some aspects of
+* communication with a Handheld. A KPilotLink object represents a
+* connection to a device (which may be active or inactive -- the latter in
+* cases where the link is @e waiting for a device to show up). The object
+* handles waiting, protocol initialization and some general
+* tasks such as getting system information or user data.
+*
+* The actual communication with the handheld should use the
+* PilotDatabase methods or use pilot-link dlp_* functions directly
+* on the file descriptor returned by handle().
+*
+* Implementations of this abstract class are KPilotDeviceLink
+* (for real physical devices) and KPilotLocalLink (for devices
+* represented by an on-disk directory).
+*
+*
+* @section General
+*
+* A KPilotLink object (or one of its subclasses) represents a single
+* (potential) link to a handheld device. The handheld device may be
+* a real physical one (subclass KPilotDeviceLink) or a virtual one
+* (subclass KPilotLocalLink). Every KPilotLink is associated with exactly
+* one identifier for @em what device it is attached to. Physical devices
+* have physical locations as interpreted by libpisock -- /dev/ttyUSB0 for
+* instance, or net:any -- while virtual devices are associated with a location
+* in the filesystem.
+*
+* A particular KPilotLink object may be connected -- communicating with
+* a device -- or not. For physical devices, that means that the device is
+* attached to the system (for USB-connected devices, think of it as a
+* metaphor in the case of net:any) and that the HotSync button has been
+* pressed. Virtual devices are immediately connected on creation, since there
+* is no sensible "not connected" state. A connected KPilotLink has access to the
+* data on the handheld and can give that data to the rest of the application.
+*
+* The data access API is divided into roughly three parts, with tickle handling
+* being a special fourth part (see section below). These are:
+*
+* - Message logging
+* - System information access
+* - Database access
+*
+* @section Lifecycle
+*
+* The life-cycle of a KPilotLink object is as follows:
+*
+* # Object is created (one of the concrete subclasses, anyway)
+* # Object gets a location assigned through reset(const QString &)
+* # Object is connected to the handheld device (somehow, depends on subclass)
+* # Object emits signal deviceReady()
+*
+* After this, the application is free to use the API to access the information from
+* the handheld. When the device connection is no longer needed, call either
+* endOfSync() or finishSync() to wrap up the communications. The object remains
+* alive and may be re-used by calling reset() to use the same location or
+* reset(const QString &) to give it a new location.
+*
+* @section Tickle handling.
 *
 * During a HotSync, the Pilot expects to be kept awake by (nearly)
 * continuous communication with the PC. The Pilot doesn't like
@@ -97,7 +126,7 @@ struct DBInfo;
 * corruption of the dlp_ communications streams. Hence, you should
 * start and stop tickling the Pilot around any computation which:
 *   - may take a long time
-*   - does not in itself _ever_ communicate directly with the Pilot
+*   - does not in itself @em ever communicate directly with the Pilot
 *
 *
 *
@@ -125,7 +154,7 @@ struct DBInfo;
 * call stopTickle().
 *
 * Call stopTickle() to stop tickling the Pilot and continue with
-* normal operation. You _must_ call stopTickle() before calling
+* normal operation. You @em must call stopTickle() before calling
 * anything else that might communicate with the Pilot, to avoid
 * corrupting the dlp_ communications stream. (TODO: Mutex the heck
 * out of this to avoid this problem). Note that stopTickle() may
@@ -139,23 +168,21 @@ struct DBInfo;
 * with a non-zero timeout and that timeout has elapsed. The
 * tickler is stopped before timeout is emitted.
 */
-
-/** A list of DBInfo structures. */
-typedef QValueList<struct DBInfo> DBInfoList;
-
-/** This is the abstract base class for Handheld interaction.
-*   It tries to define all the behavior that we need; calls
-*   to virtual *Impl() functions are used to implement the
-*   specific behavior for subclasses.
-*/
 class KDE_EXPORT KPilotLink : public QObject
 {
 Q_OBJECT
 friend class SyncAction;
 public:
+	/** A list of DBInfo structures. */
+	typedef QValueList<struct DBInfo> DBInfoList;
+
 	/** Constructor. Use reset() to start looking for a device. */
 	KPilotLink( QObject *parent = 0, const char *name = 0 );
-	/** Destructor. This rudely interrupts any communication in progress. */
+
+	/** Destructor. This rudely interrupts any communication in progress.
+	* It is best to call endOfSync() or finishSync() before destroying
+	* the device.
+	*/
 	virtual ~KPilotLink();
 
 
@@ -177,7 +204,10 @@ public:
 	* Whichever is being used, this function returns its
 	* name in a human-readable form.
 	*/
-	QString pilotPath() const { return fPilotPath; } ;
+	QString pilotPath() const
+	{
+		return fPilotPath;
+	}
 
 	/**
 	* Return the device link to the Init state and try connecting
@@ -189,14 +219,18 @@ public:
 	*/
 	virtual void reset(const QString &pilotPath) = 0;
 
-	/** Implementation detail to handle tickle timeouts. */
-	virtual bool event(QEvent *e);
+	/** Allows our class to receive custom events that our threads
+	* will be giving to us, including tickle timeouts and 
+	* device communication events. 
+	*/
+	void customEvent(QCustomEvent *e);
 
-	/** Install the list of files (full paths!) named by @p l
-	*   onto the handheld (or whatever this link represents).
-	*   If @p deleteFiles  is true, the source files are removed.
+	/**
+	* Install the list of files (full paths!) named by @p l
+	* onto the handheld (or whatever this link represents).
+	* If @p deleteFiles  is true, the source files are removed.
 	*
-	*   @return the number of files successfully installed.
+	* @return the number of files successfully installed.
 	*/
 	unsigned int installFiles(const QStringList &l, const bool deleteFiles);
 
@@ -209,14 +243,21 @@ public:
 	*/
 	void addSyncLogEntry(const QString &entry,bool log=true);
 
-	/** Find a database with the given @p name (and optionally,
-	*   type @p type and creator ID (from pi_mktag) @p creator,
-	*   on searching from index @p index on the handheld.
-	*   Fills in the DBInfo structure if found, returns < 0
-	*   on error.
+	/**
+	* Find a database with the given @p name (and optionally,
+	* type @p type and creator ID (from pi_mktag) @p creator,
+	* on searching from index @p index on the handheld.
+	* Fills in the DBInfo structure @p info if found.
+	*
+	* @return >=0 on success. See the documentation for each
+	*         subclass for particular meanings.
+	* @return < 0 on error.
 	*/
-	virtual int findDatabase(const char *name, struct DBInfo*,
-		int index=0, unsigned long type=0, unsigned long creator=0) = 0;
+	virtual int findDatabase(const char *name,
+		struct DBInfo *info,
+		int index=0,
+		unsigned long type=0,
+		unsigned long creator=0) = 0;
 
 	/**
 	* Retrieve the database indicated by DBInfo @p *db into the
@@ -227,36 +268,50 @@ public:
 	*/
 	virtual bool retrieveDatabase(const QString &path, struct DBInfo *db) = 0;
 
-	/** Fill the DBInfo structure @p db with information about
-	*   the next database (in some ordering) counting from
-	*   @p index.
-	*   @return < 0 on error
+	/**
+	* Fill the DBInfo structure @p db with information about
+	* the next database (in some ordering) counting from
+	* @p index.
+	*
+	* @return < 0 on error
 	*/
 	virtual int getNextDatabase(int index,struct DBInfo *db) = 0;
 
-	/** Returns a list of DBInfo structures describing all the
-	*   databases available on the link (ie. device) with the
-	*   given card number @p cardno and flags @p flags. No known
-	*   handheld uses a cardno other than 0; use flags to
-	*   indicate what kind of databases to fetch -- @c dlpDBListRAM
-	*   or @c dlpDBListROM.
+	/**
+	* Returns a list of DBInfo structures describing all the
+	* databases available on the link (ie. device) with the
+	* given card number @p cardno and flags @p flags. No known
+	* handheld uses a cardno other than 0; use flags to
+	* indicate what kind of databases to fetch -- @c dlpDBListRAM
+	* or @c dlpDBListROM.
 	*
-	*   @return list of DBInfo objects, one for each database
-	*   @note ownership of the DBInfo objects is passed to the
-	*         caller, who must delete the objects.
+	* @return list of DBInfo objects, one for each database
+	* @note ownership of the DBInfo objects is passed to the
+	*       caller, who must delete the objects.
 	*/
 	virtual DBInfoList getDBList(int cardno=0, int flags=dlpDBListRAM) = 0;
 
-	/** Return a database object for manipulating the database with
-	*    name @p name on the link. This database may be local or
-	*    remote, depending on the kind of link in use.
+	/**
+	* Return a database object for manipulating the database with
+	* name @p name on the link. This database may be local or
+	* remote, depending on the kind of link in use.
 	*
-	*    @return pointer to database object, or 0 on error.
-	*    @note ownership of the database object is given to the caller,
-	*          who must delete the object in time.
+	* @return pointer to database object, or 0 on error.
+	* @note ownership of the database object is given to the caller,
+	*       who must delete the object in time.
 	*/
 	virtual PilotDatabase *database( const QString &name ) = 0;
 
+	/**
+	* Return a database object for manipulating the database with
+	* the name stored in the DBInfo structure @p info . The default
+	* version goes through method database( const QString & ), above.
+	*
+	* @return pointer to database object, or 0 on error.
+	* @note ownership of the database object is given to the caller.
+	*/
+	virtual PilotDatabase *database( const DBInfo *info );
+
 	/**
 	* Retrieve the user information from the device. Ownership
 	* is kept by the link, and at the end of a sync the user
@@ -265,7 +320,10 @@ public:
 	*
 	* @note Do not call this before the sync begins!
 	*/
-	KPilotUser &getPilotUser() { return *fPilotUser; }
+	KPilotUser &getPilotUser()
+	{
+		return *fPilotUser;
+	}
 
 	/**
 	* System information about the handheld. Ownership is kept
@@ -274,7 +332,10 @@ public:
 	*
 	* @note Do not call this before the sync begins!
 	*/
-	const KPilotSysInfo &getSysInfo() { return *fPilotSysInfo; }
+	const KPilotSysInfo &getSysInfo()
+	{
+		return *fPilotSysInfo;
+	}
 
 	/**
 	* Retrieve information about the data card @p card;
@@ -289,30 +350,52 @@ public:
 	*/
 	virtual const KPilotCard *getCardInfo(int card=0) = 0;
 
-	/** End the sync in a gracuful manner. */
-	virtual void endOfSync() = 0;
-	/** End the sync in a graceful manner @em and update
-	*   the last-sync time and user information on the handheld.
+	/**
+	* When ending the sync, you can do so gracefully, updating the
+	* last-sync time to indicate a successful sync and setting the
+	* user name on the device, or you can skip that (for unsuccessful
+	* syncs, generally).
 	*/
-	virtual void finishSync() = 0;
+	enum EndOfSyncFlags {
+		NoUpdate, ///<  Do not update the user info
+		UpdateUserInfo ///< Update user info and last successful sync date
+	} ;
+
+	/**
+	* Custom events we can be handling...
+	*/
+	enum CustomEvents { 
+		EventTickleTimeout = 1066
+	};
+	
+	/**
+	* End the sync in a gracuful manner. If @p f is UpdateUserInfo,
+	* the sync was successful and the user info and last successful sync
+	* timestamp are updated.
+	*/
+	virtual void endSync( EndOfSyncFlags f ) = 0;
 
 signals:
-	/** A timeout associated with tickling has occurred. Each
-	*   time startTickle() is called, you can state how long
-	*   tickling should last (at most) before timing out.
+	/**
+	* A timeout associated with tickling has occurred. Each
+	* time startTickle() is called, you can state how long
+	* tickling should last (at most) before timing out.
 	*
-	*   You can only get a timeout when the Qt event loop is
-	*   running, which somewhat limits the usefulness of timeouts.
+	* You can only get a timeout when the Qt event loop is
+	* running, which somewhat limits the usefulness of timeouts.
 	*/
 	void timeout();
 
 	/** Signal that a message has been written to the sync log. */
 	void logMessage(const QString &);
+
 	/** Signal that an error has occurred, for logging. */
 	void logError(const QString &);
-	/** Signal that progress has been made, for logging purposes.
-	*   @p p is the percentage completed (0 <= s <= 100).
-	*   The string @p s is logged as well, if non-Null.
+
+	/**
+	* Signal that progress has been made, for logging purposes.
+	* @p p is the percentage completed (0 <= s <= 100).
+	* The string @p s is logged as well, if non-Null.
 	*/
 	void logProgress(const QString &s, int p);
 
@@ -320,13 +403,13 @@ signals:
 	* Emitted once the user information has been read and
 	* the HotSync is really ready to go.
 	*/
-	void deviceReady( KPilotLink* );
+	void deviceReady( KPilotLink * );
 
 
 public slots:
 	/**
 	* Release all resources, including the master pilot socket,
-	* timers, notifiers, etc.
+	* timers, etc.
 	*/
 	virtual void close() = 0;
 
@@ -348,26 +431,27 @@ protected:
 	*/
 	QString fPilotPath;
 
-	/** Start tickling the Handheld (every few seconds). This
-	*   lasts until @p timeout seconds have passed (or forever
-	*   if @p timeout is zero).
+	/**
+	* Start tickling the Handheld (every few seconds). This
+	* lasts until @p timeout seconds have passed (or forever
+	* if @p timeout is zero).
 	*
-	*   @note Do not call startTickle() twice with no intervening
-	*         stopTickle().
+	* @note Do not call startTickle() twice with no intervening
+	*       stopTickle().
 	*/
 	void startTickle(unsigned int timeout=0);
 
-	/** Stop tickling the Handheld. This may block for some
-	*   time (less than a second) to allow the tickle thread
-	*   to finish.
+	/**
+	* Stop tickling the Handheld. This may block for some
+	* time (less than a second) to allow the tickle thread
+	* to finish.
 	*/
 	void stopTickle();
 
-	/** Install a single file onto the device link. Full pathname
-	*   @p f is used; in addition, if @p deleteFile is true remove
-	*   the source file. Returns @c true if the install succeeded.
-	*
-	*   The default
+	/**
+	* Install a single file onto the device link. Full pathname
+	* @p f is used; in addition, if @p deleteFile is true remove
+	* the source file. Returns @c true if the install succeeded.
 	*/
 	virtual bool installFile( const QString &f, const bool deleteFile ) = 0;
 
@@ -381,25 +465,29 @@ protected:
 	*/
 	virtual int openConduit();
 
-	/** Returns a file handle for raw operations. Not recommended.
-	*   On links with no physical device backing, returns -1.
+	/**
+	* Returns a file handle for raw operations. Not recommended.
+	* On links with no physical device backing, returns -1.
 	*
-	*   @note the default implementation returns -1
+	* @note the default implementation returns -1
 	*/
 	virtual int pilotSocket() const;
 
-	/** Actually write an entry to the device link. The message
-	*   @p s is guaranteed to be non-Null.
+	/**
+	* Actually write an entry to the device link. The message
+	* @p s must be guaranteed non-empty.
 	*/
 	virtual void addSyncLogEntryImpl( const QString &s ) = 0;
 
-	/** User information structure. Should be filled in when a sync
-	*   starts, so that conduits can use the information.
+	/**
+	* User information structure. Should be filled in when a sync
+	* starts, so that conduits can use the information.
 	*/
 	KPilotUser  *fPilotUser;
 
-	/** System information about the device. Filled in when the
-	*   sync starts. Non-device links need to fake something.
+	/**
+	* System information about the device. Filled in when the
+	* sync starts. Non-device links need to fake something.
 	*/
 	KPilotSysInfo *fPilotSysInfo;
 
