@@ -15,8 +15,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include <qapplication.h>
@@ -50,7 +50,8 @@ static const QString DeleteNoteCommand = "infolog.boinfolog.delete";
 static const QString LoadNoteCategoriesCommand = "infolog.boinfolog.categories";
 
 ResourceXMLRPC::ResourceXMLRPC( const KConfig* config )
-  : ResourceNotes( config ), mServer( 0 )
+  : ResourceNotes( config ),  mCalendar( QString::fromLatin1("UTC") ),
+    mServer( 0 )
 {
   init();
 
@@ -61,7 +62,8 @@ ResourceXMLRPC::ResourceXMLRPC( const KConfig* config )
 }
 
 ResourceXMLRPC::ResourceXMLRPC( )
-  : ResourceNotes( 0 ), mServer( 0 )
+  : ResourceNotes( 0 ), mCalendar( QString::fromLatin1("UTC") ),
+    mServer( 0 )
 {
   init();
 
