@@ -43,7 +43,6 @@ ResourceGroupwise::ResourceGroupwise( const KConfig *config )
   if ( config ) {
     readConfig( config );
   }
-
   initGroupwise();
 }
 
@@ -69,11 +68,15 @@ ResourceGroupwise::ResourceGroupwise( const KURL &url,
 
 void ResourceGroupwise::init()
 {
-  mDownloadJob = 0;
+  mJob = 0;
   mProgress = 0;
-  mUpdateSystemAddressBook = false;
+  mSABProgress = 0;
+  mUABProgress = 0;
+  mServerFirstSequence = 0;
+  mServerLastSequence = 0;
+  mServerLastPORebuildTime = 0;
   mPrefs = new GroupwisePrefs;
-
+  mState = Start;
   setType( "groupwise" );
 }
 
@@ -81,10 +84,6 @@ void ResourceGroupwise::initGroupwise()
 {
   mServer = new GroupwiseServer( mPrefs->url(), mPrefs->user(),
                                  mPrefs->password(), this );
-
-  // TODO: find out what this was meant to do.  the ReadAddressBooksJob could cause the server to emit this job when its run() ends
-  // connect( mServer, SIGNAL( readAddressBooksFinished() ),
-  //         SLOT( loadFinished() ) );
 }
 
 ResourceGroupwise::~ResourceGroupwise()
@@ -197,7 +196,7 @@ void ResourceGroupwise::retrieveAddressBooks()
     }
   }
   else
-    emit loadingError( this, server.error() );
+    emit loadingError( this, server.errorText() );
 }
 
 Ticket *ResourceGroupwise::requestSaveTicket()
@@ -227,87 +226,6 @@ void ResourceGroupwise::doClose()
   cancelLoad();
 }
 
-bool ResourceGroupwise::load()
-{
-  return asyncLoad();
-}
-
-bool ResourceGroupwise::asyncLoad()
-{
-  kdDebug() << "ResourceGroupwise::asyncLoad()" << endl;
-
-  if ( mDownloadJob ) {
-    kdDebug() << "Download still in progress" << endl;
-    return true;
-  }
-
-  loadCache();
-
-  if ( addressBooks().isEmpty() ) {
-    kdDebug() << "Retrieving default addressbook list." << endl;
-    retrieveAddressBooks();
-    writeAddressBooks();
-  }
-
-  QStringList ids = mPrefs->readAddressBooks(); // start with all the address books
-
-  // check if we are fetching the SAB and we previously fetched it
-  if ( ( ids.find( mPrefs->systemAddressBook() ) != ids.end() ) &&
-     mPrefs->lastSequenceNumber() != 0 ) 
-  {
-    kdDebug() << "ResourceGroupwise::asyncLoad() - Found previous sequence number, updating SAB" << endl;
-    ids.remove( mPrefs->systemAddressBook() ); // we don't need to read this one again
-    mUpdateSystemAddressBook = true;
-    if ( ids.isEmpty() )
-    {
-      kdDebug() << "ResourceGroupwise::asyncLoad() - No user addressbooks specified, just updating SAB" << endl;
-      updateAddressBooks();
-      mUpdateSystemAddressBook = false;
-      return true; 
-    }
-  }
-
-  KURL url( prefs()->url() );
-  if ( url.protocol() == "http" ) 
-    url.setProtocol( "groupwise" );
-  else 
-    url.setProtocol( "groupwises" );
-
-  url.setPath( url.path() + "/addressbook/" );
-  url.setUser( prefs()->user() );
-  url.setPass( prefs()->password() );
-
-  QString query = "?";
-  QStringList::ConstIterator it;
-  for( it = ids.begin(); it != ids.end(); ++it ) {
-    if ( *it == mPrefs->systemAddressBook() )
-      kdDebug() << "fetching SAB" << (ids.size() > 1 ? ", and user addressbooks" : ", and only SAB" ) << endl;
-    if ( it != ids.begin() ) query += "&";
-    query += "addressbookid=" + *it;
-  }
-  url.setQuery( query );
-
-  kdDebug() << "Download URL: " << url << endl;
-
-  mJobData = QString::null;
-
-  mDownloadJob = KIO::get( url, false, false );
-  connect( mDownloadJob, SIGNAL( result( KIO::Job * ) ),
-           SLOT( slotFetchJobResult( KIO::Job * ) ) );
-  connect( mDownloadJob, SIGNAL( data( KIO::Job *, const QByteArray & ) ),
-           SLOT( slotReadJobData( KIO::Job *, const QByteArray & ) ) );
-  connect( mDownloadJob, SIGNAL( percent( KIO::Job *, unsigned long ) ),
-           SLOT( slotJobPercent( KIO::Job *, unsigned long ) ) );
-
-  mProgress = KPIM::ProgressManager::instance()->createProgressItem(
-    KPIM::ProgressManager::getUniqueID(), i18n("Downloading addressbook") );
-  connect( mProgress,
-           SIGNAL( progressItemCanceled( KPIM::ProgressItem * ) ),
-           SLOT( cancelLoad() ) );
-
-  return true;
-}
-
 bool ResourceGroupwise::save( Ticket *ticket )
 {
   return asyncSave( ticket );
@@ -339,6 +257,7 @@ bool ResourceGroupwise::asyncSave( Ticket* )
       clearChange( *it );
   }
 
+  if ( appIsWhiteListedForSAB() )
   saveCache();
 
   mServer->logout();
@@ -346,141 +265,239 @@ bool ResourceGroupwise::asyncSave( Ticket* )
   return true;
 }
 
-void ResourceGroupwise::slotFetchJobResult( KIO::Job *job )
+bool ResourceGroupwise::load()
 {
-  kdDebug() << "ResourceGroupwise::slotFetchJobResult() " << endl;
+  return asyncLoad();
+}
 
-  if ( job->error() ) {
-    kdError() << job->errorString() << endl;
-    emit loadingError( this, job->errorString() );
-  }
+bool ResourceGroupwise::asyncLoad()
+{
+  kdDebug() << "ResourceGroupwise::asyncLoad()" << endl;
+  //mPrefs->readConfig();  TODO: remove if the system addressbook is not read when disabled in config
 
-  saveCache();
-
-  mDownloadJob = 0;
-  if ( mProgress ) mProgress->setComplete();
-  mProgress = 0;
-
-  // now we fetched addressbooks, if we are using the SAB,  update it with deltas
-  QStringList ids = mPrefs->readAddressBooks();
-  if ( ids.find( mPrefs->systemAddressBook() ) != ids.end() )
+  if ( mState != Start )
   {
-    if ( mUpdateSystemAddressBook )
-    {
-      kdDebug() << "updating system addressbook" << endl;
-      updateAddressBooks();
-      mUpdateSystemAddressBook = false;
-    }
-    else // we just fetched the entire SAB, now get the delta info so we know the last sequence number we have.
-    {
-      kdDebug() << "fetched whole SAB, now fetching delta info" << endl;
-      if ( mServer->login() )
-      {
-        GroupWise::DeltaInfo deltaInfo = mServer->getDeltaInfo( mPrefs->systemAddressBook() );
-        mServer->logout();
-    
-        kdDebug() << "storing delta info to prefs" << endl;
-        mPrefs->setFirstSequenceNumber( deltaInfo.firstSequence );
-        mPrefs->setLastSequenceNumber( deltaInfo.lastSequence );
-        mPrefs->writeConfig();
-        emit loadingFinished( this );
-        addressBook()->emitAddressBookChanged();
-      }
-    }
+     kdDebug() << "  Download still in progress" << endl;
+     return true;
   }
-}
 
-void ResourceGroupwise::slotUpdateJobResult( KIO::Job *job )
-{
-  kdDebug() << "ResourceGroupwise::slotUpdateJobResult() " << endl;
+  if ( appIsWhiteListedForSAB() )
+    loadCache();
 
-  if ( job->error() ) {
-    kdError() << job->errorString() << endl;
-    emit loadingError( this, job->errorString() );
-  }
-  saveCache();
-
-  emit loadingFinished( this );
-  addressBook()->emitAddressBookChanged();
-  mDownloadJob = 0;
-  if ( mProgress ) mProgress->setComplete();
-  mProgress = 0;
-
-}
-
-bool ResourceGroupwise::updateAddressBooks()
-{
-  kdDebug() << "ResourceGroupwise::updateAddressBooks() - Updating address books." << endl;
-    
-  if ( mDownloadJob ) {
-    kdWarning() << "Download still in progress" << endl;
-    return false;
+  if ( !mProgress )
+  {
+    mProgress = KPIM::ProgressManager::instance()->createProgressItem(
+      KPIM::ProgressManager::getUniqueID(), i18n( "Loading GroupWise resource %1" ).arg( resourceName() ), QString::null, true /*CanBeCancelled*/, mPrefs->url().startsWith("https" ) );
+    connect( mProgress, SIGNAL( progressItemCanceled( KPIM::ProgressItem * ) ),
+               SLOT( cancelLoad() ) );
   }
 
   if ( addressBooks().isEmpty() ) {
-    kdDebug() << "Retrieving default addressbook list." << endl;
+    kdDebug() << "  Retrieving default addressbook list." << endl;
     retrieveAddressBooks();
     writeAddressBooks();
   }
 
-  QStringList ids;
-  ids.append( mPrefs->systemAddressBook() );
-
-  KURL url( prefs()->url() );
-  if ( url.protocol() == "http" ) 
-    url.setProtocol( "groupwise" );
-  else 
-    url.setProtocol( "groupwises" );
-
-  url.setPath( url.path() + "/addressbook/" );
-  url.setUser( prefs()->user() );
-  url.setPass( prefs()->password() );
-
-  QString query = "?";
-  QStringList::ConstIterator it;
-  for( it = ids.begin(); it != ids.end(); ++it ) {
-    if ( it != ids.begin() ) query += "&";
-    query += "addressbookid=" + *it;
+  SABState sabState = systemAddressBookState();
+  if ( shouldFetchSystemAddressBook() )
+  {
+    if ( sabState == RefreshNeeded )
+    {
+      kdDebug() << "  Fetching system addressbook" << endl;
+      fetchAddressBooks( System );
+      return true;
+    }
+    else if ( sabState == Stale )
+    {
+      kdDebug() << "  Updating system addressbook" << endl;
+      updateSystemAddressBook(); // we then fetch the user address books after doing this
+      return true;
+    }
+  }
+  else if ( shouldFetchUserAddressBooks() )
+  {
+    kdDebug() << "  Fetching user addressbook" << endl;
+    fetchAddressBooks( User );
+    return true;
   }
-  query += "&update=true";
-  query += QString::fromLatin1( "&lastSeqNo=%1" ).arg( mPrefs->lastSequenceNumber() );
-
-  url.setQuery( query );
-
-  kdDebug() << "Update URL: " << url << endl;
-
-  mJobData = QString::null;
-
-  mDownloadJob = KIO::get( url, false, false );
-  connect( mDownloadJob, SIGNAL( result( KIO::Job * ) ),
-           SLOT( slotUpdateJobResult( KIO::Job * ) ) );
-  connect( mDownloadJob, SIGNAL( data( KIO::Job *, const QByteArray & ) ),
-           SLOT( slotUpdateJobData( KIO::Job *, const QByteArray & ) ) );
-  connect( mDownloadJob, SIGNAL( percent( KIO::Job *, unsigned long ) ),
-           SLOT( slotJobPercent( KIO::Job *, unsigned long ) ) );
-
-  mProgress = KPIM::ProgressManager::instance()->createProgressItem(
-    KPIM::ProgressManager::getUniqueID(), i18n("Updating System Address Book") );
-  connect( mProgress,
-           SIGNAL( progressItemCanceled( KPIM::ProgressItem * ) ),
-           SLOT( cancelLoad() ) );
-
   return true;
 }
 
-void ResourceGroupwise::slotReadJobData( KIO::Job *, const QByteArray &data )
+void ResourceGroupwise::fetchAddressBooks( const BookType bookType )
+{
+  KURL url = createAccessUrl( bookType, Fetch );
+  if ( !url.isValid() )
+    return;
+
+  kdDebug() << k_funcinfo << ( bookType == System ? " System" : " User" ) << " URL: " << url << endl;
+  // sanity check
+  if ( bookType == User && !( mState == SABUptodate || mState == Start ) )
+  {
+    kdDebug() << "  **ERROR** - fetchAddressBooks( User ) called when SAB not up to date" << endl;
+    return;
+  }
+
+  mState = ( bookType == System ? FetchingSAB : FetchingUAB );
+  mJobData = QString::null;
+
+  if ( mJob )
+  {
+    kdDebug() << "  **ERROR** - fetchAddressBooks() called when a job was already running!" << endl;
+    return;
+  }
+
+  mJob = KIO::get( url, false, false );  // TODO: make the GW jobs call finished if the URL 
+                                         // contains no address book IDs
+  kdDebug() << "  Job address: " << mJob << endl;
+  connect( mJob, SIGNAL( data( KIO::Job *, const QByteArray & ) ),
+           SLOT( slotReadJobData( KIO::Job *, const QByteArray & ) ) );
+  connect( mJob, SIGNAL( percent( KIO::Job *, unsigned long ) ),
+           SLOT( slotJobPercent( KIO::Job *, unsigned long ) ) );
+
+  if ( bookType == System )
+  {
+    connect( mJob, SIGNAL( result( KIO::Job * ) ),
+           SLOT( fetchSABResult( KIO::Job * ) ) );
+    mSABProgress = KPIM::ProgressManager::instance()->createProgressItem(
+        mProgress, KPIM::ProgressManager::getUniqueID(),
+        i18n( "Fetching System Address Book" ), QString::null,
+        false /*CannotBeCancelled*/,
+        mPrefs->url().startsWith("https" ) );
+  }
+  else
+  {
+    connect( mJob, SIGNAL( result( KIO::Job * ) ),
+           SLOT( fetchUABResult( KIO::Job * ) ) );
+    mUABProgress = KPIM::ProgressManager::instance()->createProgressItem(
+        mProgress, KPIM::ProgressManager::getUniqueID(),
+        i18n( "Fetching User Address Books" ), QString::null,
+        false /*CannotBeCancelled*/,
+        mPrefs->url().startsWith("https" ) );
+  }
+
+  return;
+}
+
+void ResourceGroupwise::fetchSABResult( KIO::Job *job )
+{
+  kdDebug() << "ResourceGroupwise::fetchSABResult() " << endl;
+
+  if ( job->error() ) {
+    kdError() << job->errorString() << endl;
+    emit loadingError( this, job->errorString() );
+    // TODO kill the rest of the load sequence as well
+  }
+
+  mJob->disconnect( this );
+  mJob = 0;
+  mState = SABUptodate;
+  if ( mSABProgress )
+    mSABProgress->setComplete();
+
+  storeDeltaInfo();
+
+  if ( shouldFetchUserAddressBooks() )
+    fetchAddressBooks( User );
+  else
+    loadCompleted();
+}
+
+void ResourceGroupwise::fetchUABResult( KIO::Job *job )
+{
+  kdDebug() << "ResourceGroupwise::fetchUABResult() " << endl;
+
+  if ( job->error() ) {
+    kdError() << job->errorString() << endl;
+    emit loadingError( this, job->errorString() );
+  }
+
+  mJob->disconnect( this );
+  mJob = 0;
+  mState = Uptodate;
+  if ( mUABProgress )
+    mUABProgress->setComplete();
+  loadCompleted();
+}
+
+void ResourceGroupwise::updateSystemAddressBook()
+{
+  kdDebug() << "ResourceGroupwise::updateSystemAddressBook()" << endl;
+
+  if ( mState != Start ) {
+    kdWarning() << "  Action already in progress" << endl;
+    return;
+  }
+
+  if ( addressBooks().isEmpty() ) {
+    kdDebug() << "  Retrieving default addressbook list." << endl;
+    retrieveAddressBooks();
+    writeAddressBooks();
+  }
+
+  KURL url = createAccessUrl( System, Update, mPrefs->lastSequenceNumber(), mPrefs->lastTimePORebuild() );
+  kdDebug() << "  Update URL: " << url << endl;
+
+  mJobData = QString::null;
+  mSABProgress = KPIM::ProgressManager::instance()->createProgressItem(
+      mProgress, KPIM::ProgressManager::getUniqueID(),
+      i18n( "Updating System Address Book" ), QString::null,
+      false /*CannotBeCancelled*/,
+      mPrefs->url().startsWith("https" ) );
+
+  mJob = KIO::get( url, false, false );
+  mJob->setInteractive( false );
+  connect( mJob, SIGNAL( result( KIO::Job * ) ),
+           SLOT( updateSABResult( KIO::Job * ) ) );
+  connect( mJob, SIGNAL( data( KIO::Job *, const QByteArray & ) ),
+           SLOT( slotUpdateJobData( KIO::Job *, const QByteArray & ) ) );
+  connect( mJob, SIGNAL( percent( KIO::Job *, unsigned long ) ),
+           SLOT( slotJobPercent( KIO::Job *, unsigned long ) ) );
+
+  return;
+}
+
+void ResourceGroupwise::updateSABResult( KIO::Job *job )
+{
+  kdDebug() << "ResourceGroupwise::updateSABResult() " << endl;
+
+  mSABProgress->setComplete();
+  mSABProgress = 0;
+  mJob->disconnect( this );
+  mJob = 0;
+
+  int errorCode = job->error();
+  if ( errorCode != 0 ) {
+    if ( errorCode == KIO::ERR_NO_CONTENT ) // we need to refresh the SAB
+    {
+      kdDebug() << "  update SAB failed, fetching all of it again" << endl;
+      mPrefs->setLastSequenceNumber( 0 );
+      mPrefs->setFirstSequenceNumber( 0 );
+      fetchAddressBooks( System );
+      return;
+    }
+  }
+
+  mState = SABUptodate;
+  storeDeltaInfo();
+
+  if ( shouldFetchUserAddressBooks() )
+    fetchAddressBooks( User );
+  else
+    loadCompleted();
+}
+
+void ResourceGroupwise::slotReadJobData( KIO::Job *job , const QByteArray &data )
 {
   kdDebug() << "ResourceGroupwise::slotReadJobData()" << endl;
+  Q_UNUSED( job );
 
   mJobData.append( data.data() );
-  //mAddrMap.clear(); //ideally we would remove all the contacts from the personal addressbooks and keep the ones from the SAB
-  // for the moment we will just have to deal with double removal.
 
   KABC::VCardConverter conv;
   QTime profile;
   profile.start();
   Addressee::List addressees = conv.parseVCards( mJobData );
-  kdDebug() << "ResourceGroupwise::slotReadJobData() - parsed " << addressees.count() << " contacts in "  << profile.elapsed() << "ms, now adding to resource..." << endl;
+ // kdDebug() << "  parsed " << addressees.count() << " contacts in "  << profile.elapsed() << "ms, now adding to resource..." << endl;
 
   Addressee::List::ConstIterator it;
   for( it = addressees.begin(); it != addressees.end(); ++it ) {
@@ -503,9 +520,13 @@ void ResourceGroupwise::slotReadJobData( KIO::Job *, const QByteArray &data )
   mJobData = QString::null;
 }
 
-void ResourceGroupwise::slotUpdateJobData( KIO::Job *, const QByteArray &data )
+void ResourceGroupwise::slotUpdateJobData( KIO::Job *job, const QByteArray &data )
 {
+  kdDebug() << "ResourceGroupwise::slotUpdateJobData()" << endl;
+  kdDebug() << "  Job address: " << job << endl;
   KABC::VCardConverter conv;
+  mJobData.append( data.data() );
+
   Addressee::List addressees = conv.parseVCards( mJobData );
   Addressee::List::ConstIterator it;
 
@@ -541,26 +562,180 @@ void ResourceGroupwise::slotUpdateJobData( KIO::Job *, const QByteArray &data )
             removeAddressee( addrToDelete );
           }
         }
-        else 
+        else
           kdError() << "Addressee to delete did not have a remote UID, unable to find the corresponding local contact" << endl;
       }
     }
   }
+  mJobData = QString::null;
+}
+
+void ResourceGroupwise::loadCompleted()
+{
+  kdDebug() << "ResourceGroupwise::loadCompleted()" << endl;
+  if ( mProgress )
+    mProgress->setComplete();
+  mProgress = 0;
+  mSABProgress = 0;
+  mUABProgress = 0;
+  mState = Start;
+  if ( appIsWhiteListedForSAB() )
+    saveCache();
+  emit loadingFinished( this );
+  addressBook()->emitAddressBookChanged();
 }
 
 void ResourceGroupwise::slotJobPercent( KIO::Job *, unsigned long percent )
 {
+  // TODO: make this act on the correct progress item
   kdDebug() << "ResourceGroupwise::slotJobPercent() " << percent << endl;
   if ( mProgress ) mProgress->setProgress( percent );
 }
 
 void ResourceGroupwise::cancelLoad()
 {
-  if ( mDownloadJob ) mDownloadJob->kill();
-  mDownloadJob = 0;
+  if ( mJob )
+  {
+    mJob->disconnect( this );
+    mJob->kill();
+  }
+  mJob = 0;
   if ( mProgress ) mProgress->setComplete();
   mProgress = 0;
+  mState = Start;
 }
 
+ResourceGroupwise::SABState ResourceGroupwise::systemAddressBookState()
+{
+  unsigned long storedFirstSequence = mPrefs->firstSequenceNumber();
+  unsigned long storedLastSequence = mPrefs->lastSequenceNumber();
+  unsigned long storedLastPORebuildTime = mPrefs->lastTimePORebuild();
+
+  kdDebug() << "ResourceGroupwise::systemAddressBookState()" << endl;
+  kdDebug() << "  Stored first seq no: " << storedFirstSequence  << endl;
+  kdDebug() << "  Stored last seq no: " << storedLastSequence << endl;
+  kdDebug() << "  Stored last PO Rebuild time: " << storedLastPORebuildTime << endl;
+
+  kdDebug() << "  Fetching delta info to check if update possible" << endl;
+  if ( mServer->login() )
+  {
+    GroupWise::DeltaInfo deltaInfo = mServer->getDeltaInfo( mPrefs->systemAddressBook() );
+    mServer->logout();
+
+    mServerFirstSequence = deltaInfo.firstSequence;
+    mServerLastSequence = deltaInfo.lastSequence;
+    mServerLastPORebuildTime = deltaInfo.lastTimePORebuild;
+
+    kdDebug() << "  Server first seq no: " << mServerFirstSequence  << endl;
+    kdDebug() << "  Server last seq no: " << mServerLastSequence << endl;
+    kdDebug() << "  Server last PO Rebuild time: " << mServerLastPORebuildTime << endl;
+
+    if ( storedFirstSequence == 0 || storedLastSequence == 0 )
+    {
+      kdDebug() << "  no fetched SAB exists yet, can't update" << endl;
+      return RefreshNeeded;
+    }
+
+    if ( mServerFirstSequence > storedLastSequence || storedLastPORebuildTime != mServerLastPORebuildTime)
+    {
+      kdDebug() << "  New entries since the last fetch are no longer available as deltas, or the PO was rebuilt, refresh needed" << endl;
+      return RefreshNeeded;
+    }
+    
+    if ( mServerLastSequence == storedLastSequence )
+    {
+      kdDebug() << "  The local data is up to date" << endl;
+      return InSync;
+    }
+  }
+  
+  if ( storedFirstSequence == 0 || storedLastSequence == 0 )
+  {
+    kdDebug() << "  Fallthrough - no fetched SAB exists yet, refresh" << endl;
+    return RefreshNeeded;
+  }
+  else
+    kdDebug() << "  Fallthrough  - returning Stale" << endl;
+  return Stale;
+}
+
+bool ResourceGroupwise::shouldFetchSystemAddressBook()
+{
+  
+  QStringList ids = mPrefs->readAddressBooks();
+  return ( appIsWhiteListedForSAB() && ids.find( mPrefs->systemAddressBook() ) != ids.end() );
+}
+
+bool ResourceGroupwise::shouldFetchUserAddressBooks()
+{
+  QStringList ids = mPrefs->readAddressBooks();
+  return ( ids.count() > 1 || ids.find( mPrefs->systemAddressBook() ) == ids.end() );
+}
+
+KURL ResourceGroupwise::createAccessUrl( BookType bookType, AccessMode mode, unsigned long lastSequenceNumber, unsigned long lastPORebuildTime )
+{
+  // set up list of address book IDs to fetch
+  QStringList ids;
+  if ( bookType == System )
+    ids.append( mPrefs->systemAddressBook() );
+  else
+  {
+    ids = mPrefs->readAddressBooks();
+    ids.remove( mPrefs->systemAddressBook() );
+  }
+
+  if ( ids.isEmpty() )
+    return KURL();
+
+  KURL url( prefs()->url() );
+  if ( url.protocol() == "http" ) 
+    url.setProtocol( "groupwise" );
+  else 
+    url.setProtocol( "groupwises" );
+
+  url.setPath( url.path() + "/addressbook/" );
+  url.setUser( prefs()->user() );
+  url.setPass( prefs()->password() );
+
+  QString query = "?";
+  QStringList::ConstIterator it;
+  for( it = ids.begin(); it != ids.end(); ++it ) {
+    if ( it != ids.begin() ) query += "&";
+    query += "addressbookid=" + *it;
+  }
+
+  if ( mode == Update && lastSequenceNumber > 0 && lastPORebuildTime > 0 )
+  {
+    query += QString::fromLatin1( "&update=true&lastSeqNo=%1&PORebuildTime=%2" ).arg( lastSequenceNumber ).arg( lastPORebuildTime );;
+  }
+  url.setQuery( query );
+  return url;
+}
+
+void ResourceGroupwise::storeDeltaInfo()
+{
+  // update SAB delta info
+  kdDebug() << "ResourceGroupwise::storeDeltaInfo()" << endl;
+  kdDebug() << "  Server first seq no: " << mServerFirstSequence  << endl;
+  kdDebug() << "  Server last seq no: " << mServerLastSequence << endl;
+  kdDebug() << "  Server last PO Rebuild time: " << mServerLastPORebuildTime << endl;
+
+  if ( mServerFirstSequence == 0 || mServerLastSequence == 0 || mServerLastPORebuildTime == 0 )
+    return;
+  mPrefs->setFirstSequenceNumber( mServerFirstSequence );
+  mPrefs->setLastSequenceNumber( mServerLastSequence );
+  mPrefs->setLastTimePORebuild( mServerLastPORebuildTime );
+  mPrefs->writeConfig();
+}
+
+bool ResourceGroupwise::appIsWhiteListedForSAB()
+{
+  if ( !mPrefs->systemAddressBookWhiteList().contains( qApp->argv()[ 0 ] ) )
+  {
+    kdDebug() << "Application " << qApp->argv()[ 0 ] << " is _blacklisted_ to load the SAB" << endl;
+    return false;
+  }
+  return true;
+}
 
 #include "kabc_resourcegroupwise.moc"
