@@ -55,8 +55,13 @@ public:
 
   struct Address {
   public:
-    QString type;
+    Address() : kdeAddressType( -1 )
+    {
+    }
+    int kdeAddressType; // KABC::Address::Type
+    QString type;       // kolab-compliant address type: home, work or other
     QString street;
+    QString pobox;
     QString locality;
     QString region;
     QString postalCode;
