@@ -901,6 +901,12 @@ class LIBKCAL_EXPORT Calendar : public QObject, public CustomProperties,
     */
     void notifyIncidenceDeleted( Incidence *incidence );
 
+    /**
+      @copydoc
+      CustomProperties::customPropertyUpdated()
+    */
+    virtual void customPropertyUpdated();
+
     /**
        Let Calendar subclasses notify that they enabled an Observer.
 
