@@ -1,7 +1,7 @@
 /*
     This file is part of libkcal.
 
-    Copyright (c) 1998 Preston Brown
+    Copyright (c) 1998 Preston Brown <pbrown@kde.org>
     Copyright (c) 2001,2003 Cornelius Schumacher <schumacher@kde.org>
 
     This library is free software; you can redistribute it and/or
@@ -16,8 +16,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 #ifndef KCAL_CALENDARLOCAL_H
 #define KCAL_CALENDARLOCAL_H
@@ -36,10 +36,6 @@ class CalFormat;
 class LIBKCAL_EXPORT CalendarLocal : public Calendar
 {
   public:
-    /**
-      Constructs a new calendar, with variables initialized to sane values.
-    */
-    CalendarLocal();
     /**
       Constructs a new calendar, with variables initialized to sane values.
     */
@@ -57,8 +53,16 @@ class LIBKCAL_EXPORT CalendarLocal : public Calendar
 
       @return true, if successful, false on error.
       @param fileName the name of the calendar on disk.
+      @param format the format to use. If 0, iCalendar and vCalendar will be used
     */
-    bool load( const QString &fileName );
+    bool load( const QString &fileName, CalFormat *format = 0 );
+
+    /**
+     * Reloads the contents of the storage into memory. The associated file name
+     * must be known, in other words a previous load() must have been executed.
+     * @return success or failure
+    */
+    bool reload( const QString &tz );
 
     /**
       Writes out the calendar to disk in the specified \a format.
@@ -83,7 +87,7 @@ class LIBKCAL_EXPORT CalendarLocal : public Calendar
     /**
       Deletes an event from this calendar.
     */
-    void deleteEvent( Event *event );
+    bool deleteEvent( Event *event );
     /**
       Deletes all events from this calendar.
     */
@@ -105,7 +109,7 @@ class LIBKCAL_EXPORT CalendarLocal : public Calendar
     /**
       Remove a todo from the todolist.
     */
-    void deleteTodo( Todo * );
+    bool deleteTodo( Todo * );
     /**
       Deletes all todos from this calendar.
     */
@@ -131,7 +135,7 @@ class LIBKCAL_EXPORT CalendarLocal : public Calendar
     /**
       Remove a Journal from the calendar.
     */
-    void deleteJournal( Journal * );
+    bool deleteJournal( Journal * );
     /**
       Deletes all journals from this calendar.
     */
@@ -163,9 +167,7 @@ class LIBKCAL_EXPORT CalendarLocal : public Calendar
       Builds and then returns a list of all events that match for the
       date specified. useful for dayView, etc. etc.
     */
-    //TODO: Deprecate
-    Event::List rawEventsForDate( const QDate &date, bool sorted = false );
-    //Event::List rawEventsForDate( const QDate &date, EventSortField sortField = EventSortUnsorted );
+    Event::List rawEventsForDate( const QDate &date, EventSortField sortField = EventSortUnsorted, SortDirection sortDirection = SortDirectionAscending );
     /**
       Get unfiltered events for date \a qdt.
     */
@@ -182,6 +184,13 @@ class LIBKCAL_EXPORT CalendarLocal : public Calendar
     Event::List rawEvents( const QDate &start, const QDate &end,
                                bool inclusive = false );
 
+    /**
+     * Set the timezone of the calendar to be used for interpreting the events
+     * in the calendar. This requires that the calendar is saved first, so the
+     * user is asked whether he wants to do that, or keep the timezone as is.
+     */
+    void setTimeZoneIdViewOnly( const QString& tz );
+  
   protected:
 
     /** inserts an event into its "proper place" in the calendar. */
