@@ -585,7 +585,7 @@ QString IncidenceFormatter::extensiveDisplayString( IncidenceBase *incidence )
 
 static QString string2HTML( const QString& str )
 {
-  return QStyleSheet::convertFromPlainText(str);
+  return QStyleSheet::convertFromPlainText(str, QStyleSheetItem::WhiteSpaceNormal);
 }
 
 static QString invitationRow( const QString &cell1, const QString &cell2 )
