@@ -3,11 +3,10 @@
   FILE: icalparameterimpl.h
   CREATOR: eric 09 May 1999
   
-  $Id: icalparameterimpl.h 405592 2005-04-14 19:28:51Z dfaure $
-  $Locker:  $
     
 
- (C) COPYRIGHT 2000, Eric Busboom, http://www.softwarestudio.org
+ (C) COPYRIGHT 2000, Eric Busboom <eric@softwarestudio.org>
+     http://www.softwarestudio.org
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of either: 
