@@ -15,8 +15,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include <kaboutdata.h>
@@ -55,7 +55,8 @@ int main(int argc,char **argv)
 
   Event *event1 = new Event;
   event1->setSummary("Test Event");
-  event1->recurrence()->setDaily( 2, 3 );
+  event1->recurrence()->setDaily( 2 );
+  event1->recurrence()->setDuration( 3 );
 
   QString eventString1 = f.toString( event1 );
   if ( verbose )
