@@ -119,6 +119,7 @@ QString Todo::dtDueDateStr(bool shortfmt) const
   return KGlobal::locale()->formatDate(dtDue( !doesRecur() ).date(),shortfmt);
 }
 
+// TODO: Add shortfmt param!!!
 QString Todo::dtDueStr() const
 {
   return KGlobal::locale()->formatDateTime( dtDue( !doesRecur() ) );
@@ -275,11 +276,17 @@ bool Todo::recurTodo()
 
     if ( ( r->duration() == -1 || ( nextDate.isValid() && endDateTime.isValid()
            && nextDate <= endDateTime ) ) ) {
-      setDtDue( nextDate );
-      while ( !recursAt( dtDue() ) || dtDue() <= QDateTime::currentDateTime() ) {
-        setDtDue( r->getNextDateTime( dtDue() ) );
+
+      while ( !recursAt( nextDate ) || nextDate <= QDateTime::currentDateTime() ) {
+
+        if ( !nextDate.isValid() || nextDate > endDateTime ) {
+          return false;
+        }
+
+        nextDate = r->getNextDateTime( nextDate );
       }
 
+      setDtDue( nextDate );
       setCompleted( false );
       setRevision( revision() + 1 );
 
