@@ -91,6 +91,13 @@ static QCString newLineEditDCOPObjectName()
 
 static const QString s_completionItemIndentString = "     ";
 
+static bool itemIsHeader( const QListBoxItem* item )
+{
+  return item && !item->text().startsWith( s_completionItemIndentString );
+}
+
+
+
 AddresseeLineEdit::AddresseeLineEdit( QWidget* parent, bool useCompletion,
                                       const char *name )
   : ClickLineEdit( parent, QString::null, name ), DCOPObject( newLineEditDCOPObjectName() )
@@ -99,6 +106,7 @@ AddresseeLineEdit::AddresseeLineEdit( QWidget* parent, bool useCompletion,
   m_completionInitialized = false;
   m_smartPaste = false;
   m_addressBookConnected = false;
+  m_searchExtended = false;
 
   init();
 
@@ -123,11 +131,11 @@ void AddresseeLineEdit::init()
 
   if ( m_useCompletion ) {
     if ( !s_LDAPTimer ) {
-      ldapTimerDeleter.setObject( s_LDAPTimer, new QTimer );
+      ldapTimerDeleter.setObject( s_LDAPTimer, new QTimer( 0, "ldapTimerDeleter" ) );
       ldapSearchDeleter.setObject( s_LDAPSearch, new KPIM::LdapSearch );
       ldapTextDeleter.setObject( s_LDAPText, new QString );
 
-      /* Add completion sources for all ldap server, 0 to n. Added first so 
+      /* Add completion sources for all ldap server, 0 to n. Added first so
        * that they map to the ldapclient::clientNumber() */
       QValueList< LdapClient* > clients =  s_LDAPSearch->clients();
       for ( QValueList<LdapClient*>::iterator it = clients.begin(); it != clients.end(); ++it ) {
@@ -251,15 +259,14 @@ void AddresseeLineEdit::insert( const QString &t )
 
   QString contents = text();
   int start_sel = 0;
-  int end_sel = 0;
   int pos = cursorPosition( );
-  if ( getSelection( &start_sel, &end_sel ) ) {
+
+  if ( hasSelectedText() ) {
     // Cut away the selection.
-    if ( pos > end_sel )
-      pos -= (end_sel - start_sel);
-    else if ( pos > start_sel )
-      pos = start_sel;
-    contents = contents.left( start_sel ) + contents.right( end_sel + 1 );
+    start_sel = selectionStart();
+    pos = start_sel;
+    contents = contents.left( start_sel ) +
+               contents.mid( start_sel + selectedText().length() );
   }
 
   int eot = contents.length();
@@ -422,7 +429,7 @@ void AddresseeLineEdit::doCompletion( bool ctrlT )
       setCompletionMode( completionMode() );
 
       if ( !m_searchString.isEmpty() ) {
-        
+
         //if only our \" is left, remove it since user has not typed it either
         if ( m_searchExtended && m_searchString == "\"" ){
           m_searchExtended = false;
@@ -437,7 +444,7 @@ void AddresseeLineEdit::doCompletion( bool ctrlT )
           if ( match != m_searchString ) {
             QString adds = m_previousAddresses + match;
             setCompletedText( adds );
-          } 
+          }
         } else {
           if ( !m_searchString.startsWith( "\"" ) ) {
             //try with quoted text, if user has not type one already
@@ -525,8 +532,9 @@ void AddresseeLineEdit::loadContacts()
       int weight = config.readNumEntry( resource->identifier(), 60 );
       s_completionSources->append( resource->resourceName() );
       KABC::Resource::Iterator it;
-      for ( it = resource->begin(); it != resource->end(); ++it )
-        addContact( *it, weight, s_completionSources->size()-1 );
+      if ( resource->type() != "ldapkio" )
+        for ( it = resource->begin(); it != resource->end(); ++it )
+          addContact( *it, weight, s_completionSources->size()-1 );
     }
   }
 
@@ -562,7 +570,7 @@ void AddresseeLineEdit::addContact( const KABC::Addressee& addr, int weight, int
 #ifdef KDEPIM_NEW_DISTRLISTS
   if ( KPIM::DistributionList::isDistributionList( addr ) ) {
     //kdDebug(5300) << "AddresseeLineEdit::addContact() distribution list \"" << addr.formattedName() << "\" weight=" << weight << endl;
- 
+
     //for CompletionAuto
     addCompletionItem( addr.formattedName(), weight, source );
 
@@ -576,38 +584,40 @@ void AddresseeLineEdit::addContact( const KABC::Addressee& addr, int weight, int
   //m_contactMap.insert( addr.realName(), addr );
   const QStringList emails = addr.emails();
   QStringList::ConstIterator it;
+  const int prefEmailWeight = 1;     //increment weight by prefEmailWeight
+  int isPrefEmail = prefEmailWeight; //first in list is preferredEmail
   for ( it = emails.begin(); it != emails.end(); ++it ) {
-    //TODO: highlight preferredEmail 
+    //TODO: highlight preferredEmail
     const QString email( (*it) );
     const QString givenName = addr.givenName();
     const QString familyName= addr.familyName();
     const QString nickName  = addr.nickName();
-    const QString fullEmail = addr.fullEmail( email );
     const QString domain    = email.mid( email.find( '@' ) + 1 );
+    QString fullEmail = addr.fullEmail( email );
     //TODO: let user decide what fields to use in lookup, e.g. company, city, ...
 
     //for CompletionAuto
     if ( givenName.isEmpty() && familyName.isEmpty() ) {
-      addCompletionItem( fullEmail, weight, source ); // use whatever is there
+      addCompletionItem( fullEmail, weight + isPrefEmail, source ); // use whatever is there
     } else {
       const QString byFirstName=  "\"" + givenName + " " + familyName + "\" <" + email + ">";
       const QString byLastName =  "\"" + familyName + ", " + givenName + "\" <" + email + ">";
-      addCompletionItem( byFirstName, weight, source );
-      addCompletionItem( byLastName, weight, source );
+      addCompletionItem( byFirstName, weight + isPrefEmail, source );
+      addCompletionItem( byLastName, weight + isPrefEmail, source );
     }
 
-    addCompletionItem( email, weight, source );
+    addCompletionItem( email, weight + isPrefEmail, source );
 
     if ( !nickName.isEmpty() ){
       const QString byNick     =  "\"" + nickName + "\" <" + email + ">";
-      addCompletionItem( byNick, weight, source );
+      addCompletionItem( byNick, weight + isPrefEmail, source );
     }
 
     if ( !domain.isEmpty() ){
       const QString byDomain   =  "\"" + domain + " " + familyName + " " + givenName + "\" <" + email + ">";
-      addCompletionItem( byDomain, weight, source );
+      addCompletionItem( byDomain, weight + isPrefEmail, source );
     }
-    
+
     //for CompletionShell, CompletionPopup
     QStringList keyWords;
     const QString realName  = addr.realName();
@@ -632,7 +642,17 @@ void AddresseeLineEdit::addContact( const KABC::Addressee& addr, int weight, int
 
     keyWords.append( email );
 
-    addCompletionItem( fullEmail, weight, source, &keyWords );
+    /* KMailCompletion does not have knowledge about identities, it stores emails and
+     * keywords for each email. KMailCompletion::allMatches does a lookup on the
+     * keywords and returns an ordered list of emails. In order to get the preferred
+     * email before others for each identity we use this little trick.
+     * We remove the <blank> in getAdjustedCompletionItems.
+     */
+    if ( isPrefEmail == prefEmailWeight )
+      fullEmail.replace( " <", "  <" );
+
+    addCompletionItem( fullEmail, weight + isPrefEmail, source, &keyWords );
+    isPrefEmail = 0;
 
 #if 0
     int len = (*it).length();
@@ -733,7 +753,7 @@ void AddresseeLineEdit::startLoadingLDAPEntries()
   if ( s.isEmpty() )
     return;
 
-  loadContacts(); // TODO reuse these?
+  //loadContacts(); // TODO reuse these?
   s_LDAPSearch->startSearch( s );
 }
 
@@ -746,12 +766,12 @@ void AddresseeLineEdit::slotLDAPSearchData( const KPIM::LdapResultList& adrs )
     KABC::Addressee addr;
     addr.setNameFromString( (*it).name );
     addr.setEmails( (*it).email );
-    
+
     addContact( addr, (*it).completionWeight, (*it ).clientNumber  );
   }
 
   if ( (hasFocus() || completionBox()->hasFocus() )
-       && completionMode() != KGlobalSettings::CompletionNone 
+       && completionMode() != KGlobalSettings::CompletionNone
        && completionMode() != KGlobalSettings::CompletionShell) {
     setText( m_previousAddresses + m_searchString );
     doCompletion( m_lastSearchMode );
@@ -771,7 +791,7 @@ void AddresseeLineEdit::setCompletedItems( const QStringList& items, bool autoSu
           if ( !m_searchString.isEmpty() )
             completionBox->setCancelledText( m_searchString );
           completionBox->popup();
-          // we have to install the event filter after popup(), since that 
+          // we have to install the event filter after popup(), since that
           // calls show(), and that's where KCompletionBox installs its filter.
           // We want to be first, though, so do it now.
           if ( s_completion->order() == KCompletion::Weighted )
@@ -906,10 +926,10 @@ bool KPIM::AddresseeLineEdit::eventFilter(QObject *obj, QEvent *e)
       }
       // avoid selection of headers on button press, or move or release while
       // a button is pressed
-      if ( e->type() == QEvent::MouseButtonPress 
-          || me->state() & LeftButton || me->state() & MidButton 
+      if ( e->type() == QEvent::MouseButtonPress
+          || me->state() & LeftButton || me->state() & MidButton
           || me->state() & RightButton ) {
-        if ( !item->text().startsWith( s_completionItemIndentString ) ) {
+        if ( itemIsHeader(item) ) {
           return true; // eat the event, we don't want anything to happen
         } else {
           // if we are not on one of the group heading, make sure the item
@@ -936,12 +956,12 @@ bool KPIM::AddresseeLineEdit::eventFilter(QObject *obj, QEvent *e)
       completionBox()->isVisible() ) {
     QKeyEvent *ke = static_cast<QKeyEvent*>( e );
     unsigned int currentIndex = completionBox()->currentItem();
-    if ( ke->key() == Key_Up || ke->key() == Key_Backtab ) {
+    if ( ke->key() == Key_Up ) {
       //kdDebug() << "EVENTFILTER: Key_Up currentIndex=" << currentIndex << endl;
       // figure out if the item we would be moving to is one we want
       // to ignore. If so, go one further
       QListBoxItem *itemAbove = completionBox()->item( currentIndex - 1 );
-      if ( itemAbove && !itemAbove->text().startsWith( s_completionItemIndentString ) ) {
+      if ( itemAbove && itemIsHeader(itemAbove) ) {
         // there is a header above us, check if there is even further up
         // and if so go one up, so it'll be selected
         if ( currentIndex > 1 && completionBox()->item( currentIndex - 2 ) ) {
@@ -956,11 +976,11 @@ bool KPIM::AddresseeLineEdit::eventFilter(QObject *obj, QEvent *e)
         }
         return true;
       }
-    } else if ( ke->key() == Key_Down || ke->key() == Key_Tab ) {
+    } else if ( ke->key() == Key_Down  ) {
       // same strategy for downwards
       //kdDebug() << "EVENTFILTER: Key_Down. currentIndex=" << currentIndex << endl;
       QListBoxItem *itemBelow = completionBox()->item( currentIndex + 1 );
-      if ( itemBelow && !itemBelow->text().startsWith( s_completionItemIndentString ) ) {
+      if ( itemBelow && itemIsHeader( itemBelow ) ) {
         if ( completionBox()->item( currentIndex + 2 ) ) {
           //kdDebug() << "EVENTFILTER: Key_Down -> skipping " << currentIndex+1 << endl;
           completionBox()->setCurrentItem( itemBelow->next() );
@@ -979,9 +999,41 @@ bool KPIM::AddresseeLineEdit::eventFilter(QObject *obj, QEvent *e)
       // Setting it to selected tricks KCompletionBox into not treating is special
       // and selecting making it current, instead of the one below.
       QListBoxItem *item = completionBox()->item( currentIndex );
-      if ( item && !item->text().startsWith( s_completionItemIndentString )  ) {
+      if ( item && itemIsHeader(item) ) {
         completionBox()->setSelected( currentIndex, true );
       }
+    } else if ( ke->key() == Key_Tab || ke->key() == Key_Backtab ) {
+      /// first, find the header of teh current section
+      QListBoxItem *myHeader = 0;
+      int i = currentIndex;
+      while ( i>=0 ) {
+        if ( itemIsHeader( completionBox()->item(i) ) ) {
+          myHeader = completionBox()->item( i );
+          break;
+        }
+        i--;
+      }
+      Q_ASSERT( myHeader ); // we should always be able to find a header
+
+      // find the next header (searching backwards, for Key_Backtab
+      QListBoxItem *nextHeader = 0;
+      const int iterationstep = ke->key() == Key_Tab ?  1 : -1;
+      // when iterating forward, start at the currentindex, when backwards, 
+      // one up from our header, or at the end
+      uint j = ke->key() == Key_Tab ? currentIndex : i==0 ? completionBox()->count()-1 : (i-1) % completionBox()->count();
+      while ( ( nextHeader = completionBox()->item( j ) ) && nextHeader != myHeader ) {
+          if ( itemIsHeader(nextHeader) ) {
+              break;
+          }
+          j = (j + iterationstep) % completionBox()->count();
+      }
+      if ( nextHeader && nextHeader != myHeader ) {
+        QListBoxItem *item = completionBox()->item( j + 1 );
+        if ( item && !itemIsHeader(item) ) {
+          completionBox()->setSelected( j+1, true );
+        }
+      }
+      return true;
     }
   }
   return ClickLineEdit::eventFilter( obj, e );
@@ -992,7 +1044,7 @@ const QStringList KPIM::AddresseeLineEdit::getAdjustedCompletionItems( bool full
   QStringList items = fullSearch ?
     s_completion->allMatches( m_searchString )
     : s_completion->substringCompletion( m_searchString );
- 
+
   int lastSourceIndex = -1;
   unsigned int i = 0;
   QMap<int, QStringList> sections;
@@ -1010,6 +1062,8 @@ const QStringList KPIM::AddresseeLineEdit::getAdjustedCompletionItems( bool full
         lastSourceIndex = idx;
       }
       (*it) = (*it).prepend( s_completionItemIndentString );
+      // remove preferred email sort <blank> added in  addContact()
+      (*it).replace( "  <", " <" );
     }
     sections[idx].append( *it );
 
