@@ -82,7 +82,7 @@ class KDE_EXPORT DiffAlgo
     /**
       Destructor.
      */
-    virtual ~DiffAlgo() {};
+    virtual ~DiffAlgo() {}
 
     /**
       Starts the diffing algorithm.
