@@ -15,7 +15,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
     In addition, as a special exception, the copyright holders give
     permission to link the code of this program with any edition of
@@ -54,6 +54,7 @@
 #include <kglobalsettings.h>
 #include <kiconloader.h>
 #include <kdebug.h>
+#include <kdcopservicestarter.h>
 #include <kmessagebox.h>
 #include <kstandarddirs.h>
 #include <kapplication.h>
@@ -65,19 +66,22 @@
 
 #include <kdepimmacros.h>
 
+#include <dcopclient.h>
+#include <dcopref.h>
+
 using namespace KCal;
 
 namespace {
 
 class KMInvitationFormatterHelper : public KCal::InvitationFormatterHelper
 {
-  public: 
+  public:
     KMInvitationFormatterHelper( KMail::Interface::BodyPart *bodyPart ) : mBodyPart( bodyPart ) {}
     virtual QString generateLinkURL( const QString &id ) { return mBodyPart->makeLink( id ); }
   private:
     KMail::Interface::BodyPart *mBodyPart;
 };
-    
+
 class Formatter : public KMail::Interface::BodyPartFormatter
 {
   public:
@@ -190,7 +194,7 @@ class UrlHandler : public KMail::Interface::BodyPartURLHandler
 
     }
 
-    void setStatusOnMyself( Incidence* incidence, Attendee* myself, 
+    void setStatusOnMyself( Incidence* incidence, Attendee* myself,
                             Attendee::PartStat status, const QString &receiver ) const
     {
       Attendee* newMyself = 0;
@@ -213,18 +217,20 @@ class UrlHandler : public KMail::Interface::BodyPartURLHandler
         incidence->addAttendee( newMyself );
     }
 
-    bool mail( Incidence* incidence, KMail::Callback& callback ) const
+    bool mail( Incidence* incidence, KMail::Callback& callback, const QString &status ) const
     {
+      //status is accepted/tentative/declined
       ICalFormat format;
       format.setTimeZone( KPimPrefs::timezone(), false );
       QString msg = format.createScheduleMessage( incidence,
                                                   Scheduler::Reply );
+      kdDebug() << "scheduler::REPly=" << Scheduler::Reply << endl;
       QString subject;
       if ( !incidence->summary().isEmpty() )
         subject = i18n( "Answer: %1" ).arg( incidence->summary() );
       else
         subject = i18n( "Answer: Incidence with no summary" );
-      return callback.mailICal( incidence->organizer().fullName(), msg, subject );
+      return callback.mailICal( incidence->organizer().fullName(), msg, subject, status );
     }
 
     bool saveFile( const QString& receiver, const QString& iCal,
@@ -239,10 +245,38 @@ class UrlHandler : public KMail::Interface::BodyPartURLHandler
       }
       ts->setEncoding( QTextStream::UnicodeUTF8 );
       (*ts) << receiver << '\n' << iCal;
+      file.close();
+
+      // Now ensure that korganizer is running; otherwise start it, to prevent surprises
+      // (https://intevation.de/roundup/kolab/issue758)
+      QString error;
+      QCString dcopService;
+      int result = KDCOPServiceStarter::self()->findServiceFor( "DCOP/Organizer", QString::null, QString::null, &error, &dcopService );
+      if ( result == 0 ) {
+        // OK, so korganizer (or kontact) is running. Now ensure the object we want is available
+        // [that's not the case when kontact was already running, but korganizer not loaded into it...]
+        static const char* const dcopObjectId = "KOrganizerIface";
+        QCString dummy;
+        if ( !kapp->dcopClient()->findObject( dcopService, dcopObjectId, "", QByteArray(), dummy, dummy ) ) {
+          DCOPRef ref( dcopService, dcopService ); // talk to the KUniqueApplication or its kontact wrapper
+          DCOPReply reply = ref.call( "load()" );
+          if ( reply.isValid() && (bool)reply ) {
+            kdDebug() << "Loaded " << dcopService << " successfully" << endl;
+            Q_ASSERT( kapp->dcopClient()->findObject( dcopService, dcopObjectId, "", QByteArray(), dummy, dummy ) );
+          } else
+            kdWarning() << "Error loading " << dcopService << endl;
+        }
+
+        // We don't do anything with it, we just need it to be running so that it handles
+        // the incoming directory.
+      }
+      else
+        kdWarning() << "Couldn't start DCOP/Organizer: " << dcopService << " " << error << endl;
+
       return true;
     }
 
-    bool handleInvitation( const QString& iCal, Attendee::PartStat status, 
+    bool handleInvitation( const QString& iCal, Attendee::PartStat status,
                            KMail::Callback &callback ) const
     {
       bool ok = true;
@@ -267,7 +301,7 @@ class UrlHandler : public KMail::Interface::BodyPartURLHandler
       Attendee *myself = findMyself( incidence, receiver );
       if ( ( myself && myself->RSVP() ) || heuristicalRSVP( incidence ) ) {
         setStatusOnMyself( incidence, myself, status, receiver );
-        ok =  mail( incidence, callback );
+        ok =  mail( incidence, callback, dir );
       } else {
         ( new KMDeleteMsgCommand( callback.getMsg()->getMsgSerNum() ) )->start();
       }
@@ -286,21 +320,25 @@ class UrlHandler : public KMail::Interface::BodyPartURLHandler
                       const QString &path, KMail::Callback& c ) const
     {
       QString iCal = part->asText();
-
+      bool result = false;
       if ( path == "accept" )
-        return handleInvitation( iCal, Attendee::Accepted, c );
+        result = handleInvitation( iCal, Attendee::Accepted, c );
       if ( path == "accept_conditionally" )
-        return handleInvitation( iCal, Attendee::Tentative, c );
+        result = handleInvitation( iCal, Attendee::Tentative, c );
       if ( path == "ignore" )
-        return handleIgnore( iCal, c );
+        result = handleIgnore( iCal, c );
       if ( path == "decline" )
-        return handleInvitation( iCal, Attendee::Declined, c );
-      if ( path == "reply" || path == "cancel" )
+        result = handleInvitation( iCal, Attendee::Declined, c );
+      if ( path == "reply" || path == "cancel" ) {
         // These should just be saved with their type as the dir
-        if ( saveFile( "Receiver Not Searched", iCal, path ) )
+        if ( saveFile( "Receiver Not Searched", iCal, path ) ) {
           ( new KMDeleteMsgCommand( c.getMsg()->getMsgSerNum() ) )->start();
-
-      return false;
+          result = true;
+        }
+      }
+      if ( result )
+        c.closeIfSecondaryWindow();
+      return result;
     }
 
     bool handleContextMenuRequest( KMail::Interface::BodyPart *,
